CREATE TABLE version (
  version varchar(32) NOT NULL
);

INSERT INTO version VALUES ('6.0.008');

CREATE TABLE account (
  account_id varchar(32) NOT NULL ,
  customer_name varchar(50) ,
  expiration_time timestamp ,
  serial_key varchar(50) NOT NULL ,
  account_conf blob,
  PRIMARY KEY  (account_id)
) ;

CREATE TABLE schedule_task (
  task_id int NOT NULL ,
  account_id varchar(32) NOT NULL ,
  computer_id varchar(64) NOT NULL ,
  group_name varchar(255) NOT NULL ,
  command varchar(255) NOT NULL ,
  next_run timestamp NOT NULL ,
  granularity int NOT NULL ,
  units int NOT NULL ,
  PRIMARY KEY  (task_id)
);

CREATE TABLE computer (
  account_id varchar(32) NOT NULL ,
  computer_id varchar(64) NOT NULL ,
  computer_name varchar(32) ,
  computer_type varchar(20) ,
  parent_group varchar(255) NOT NULL ,
  inventory_xml blob,
  inventory_time timestamp ,
  update_time timestamp ,
  last_access timestamp ,
  ip_address varchar(16) ,
  description varchar(255) ,
  username varchar(32) ,
  location varchar(255) ,
  location_idx  int,
  building varchar(32),
  floor varchar(32) ,
  cubic varchar(32) ,
  catalog_number varchar(64),
  supplier int,
  maintenance_supplier int,
  company_serial varchar(64),
  external_serial varchar(64),
  monitor varchar(64),
  monitor_serial varchar(64),
  collection_type int,
  collection_params blob,
  cust_list1 int,
  cust_list2 int,
  cust_text1 varchar(100),
  cust_text2 varchar(100),
  cust_notes blob,
  cust_int1 int,
  cust_int2 int,
  parent_asset varchar(64),
  department int,
  company int,
  disable char(1),
  manual_asset char(1),
  purchase_cost int,
  purchase_currency int,
  agent_version varchar(60),
  PRIMARY KEY  (account_id,computer_id)
) ;

CREATE TABLE computer_attributes (
  account_id varchar(32) NOT NULL ,
  computer_id varchar(64) NOT NULL ,
  cpu_vendor varchar(100) ,
  cpu_model varchar(100) ,
  cpu_speed int ,
  bios_type varchar(100) ,
  display_adapter varchar(100) ,
  display_memory int ,
  display_resolution varchar(100) ,
  os_type varchar(100) ,
  os_version varchar(100) ,
  os_service_pack varchar(100) ,
  memory_physical BIGINT ,
  serial varchar(64),
  model varchar(64) ,
  manufacturer varchar(32) ,
  purchase_date timestamp,
  warranty_expiration timestamp,
  last_maintenance timestamp,
  last_page_count int,
  maintenance_page_count int ,
  disks_size int,
  disks_count int,
  mem_banks int,
  occupied_mem_banks int,
  free_mem_banks int,
  cpu_count int,
  os_name varchar(100),
  os_platform varchar(64),
  PRIMARY KEY  (account_id,computer_id)
);

CREATE TABLE computer_changes (
  account_id varchar(32) NOT NULL ,
  computer_id varchar(64) NOT NULL ,
  change_time timestamp NOT NULL ,
  change_type varchar(32) NOT NULL ,
  change_sub_type varchar(32) NOT NULL ,
  change_description blob NOT NULL,
  log_id int
) ;

CREATE TABLE computer_group (
  account_id varchar(32) NOT NULL ,
  group_name varchar(150) NOT NULL ,
  parent_group_name varchar(255) NOT NULL ,
  group_description varchar(100) ,
  group_level int ,
  PRIMARY KEY  (account_id,group_name)
) ;

CREATE TABLE computer_lists (
  account_id varchar(32) NOT NULL ,
  computer_id varchar(64) NOT NULL ,
  list_type varchar(32) NOT NULL ,
  list_value varchar(100) NOT NULL,
  list_display varchar(100)
) ;

CREATE TABLE computer_log (
  log_id int NOT NULL ,
  account_id varchar(32) NOT NULL ,
  computer_id varchar(64) NOT NULL ,
  log_time timestamp NOT NULL ,
  log_type varchar(32) NOT NULL ,
  log_sub_type varchar(32) NOT NULL ,
  log_description blob NOT NULL,
  ext_reference int ,
  user_name varchar(64) ,
  ext_reference2 int ,
  PRIMARY KEY  (log_id)
) ;

CREATE GENERATOR COMPUTER_LOG_SEQ ;

CREATE TABLE computer_users (
  account_id varchar(32) NOT NULL ,
  computer_id varchar(64) NOT NULL ,
  user_name varchar(64) NOT NULL ,
  full_name varchar(250) ,
  email_address varchar(64) ,
  PRIMARY KEY  (account_id,computer_id,user_name)
) ;

CREATE TABLE event (
  account_id varchar(32) NOT NULL ,
  computer_id varchar(32) NOT NULL ,
  log_type varchar(32) NOT NULL ,
  event_time timestamp NOT NULL ,
  record_number int NOT NULL ,
  event_id int NOT NULL ,
  event_type varchar(20) NOT NULL ,
  event_source varchar(32) NOT NULL ,
  event_category varchar(32) ,
  event_username varchar(32) ,
  event_domain varchar(32) ,
  event_computer varchar(32) ,
  event_description varchar(250) ,
  event_binary blob,
  event_char_data blob,
  PRIMARY KEY  (account_id,computer_id,log_type,event_time,record_number)
) ;

CREATE TABLE login_log (
  log_time timestamp ,
  account_id varchar(32) ,
  user_name varchar(64) ,
  status varchar(32) ,
  ip_address varchar(32)
) ;

CREATE TABLE messages (
  account_id varchar(32) NOT NULL ,
  user_name varchar(64) NOT NULL ,
  sent_time timestamp NOT NULL ,
  sender varchar(32) ,
  recv_flag int NOT NULL ,
  msg blob,
  msgid varchar(64),
  PRIMARY KEY  (account_id,user_name,sent_time)
) ;

CREATE TABLE problem_type (
  account_id varchar(32) NOT NULL ,
  problem_type varchar(32) NOT NULL ,
  problem_sub_type varchar(32) NOT NULL ,
  route varchar(32) ,
  desc_template blob,
  third_level_category varchar(32) NOT NULL ,
  PRIMARY KEY  (account_id,problem_type,problem_sub_type,third_level_category)
) ;

CREATE TABLE service_req (
  id int NOT NULL ,
  account_id varchar(32) NOT NULL ,
  computer_id varchar(64) NOT NULL ,
  problem_type varchar(32) ,
  problem_sub_type varchar(32) ,
  title varchar(200) ,
  description blob,
  status int ,
  contact blob,
  responsibility varchar(32) ,
  urgency int ,
  priority int ,
  notes blob,
  resolution blob,
  solution blob,
  insert_time timestamp ,
  update_time timestamp ,
  close_time timestamp ,
  update_user varchar(64) ,
  version int NOT NULL ,
  knowledge_base int NOT NULL ,
  submit_user varchar(64) ,
  submit_user_type smallint NOT NULL ,
  request_user varchar(64) ,
  request_user_type smallint NOT NULL ,
  due_date timestamp ,
  location int ,
  parent_link int,
  escalation int,
  third_level_category varchar(32) ,
  assigned_group varchar(64),
  timers_update_time timestamp,
  timer1 bigint,
  timer2 bigint,
  timer3 bigint,
  timer4 bigint,
  timer5 bigint,
  cust_list1 int,
  cust_list2 int,
  cust_text1 varchar(100),
  cust_text2 varchar(100),
  cust_notes blob,
  cust_int1 int,
  cust_int2 int,
  cc varchar(250),
  project_id int,
  task_id int,
  PRIMARY KEY  (id)
) ;

CREATE GENERATOR service_req_seq ;

create index service_req_ind_1 on service_req (status );

CREATE TABLE service_req_history (
  id int NOT NULL ,
  account_id varchar(32) NOT NULL ,
  computer_id varchar(64) NOT NULL ,
  problem_type varchar(32) ,
  problem_sub_type varchar(32) ,
  title varchar(200) ,
  description blob,
  status int ,
  contact blob,
  responsibility varchar(32) ,
  urgency int ,
  priority int ,
  notes blob,
  resolution blob,
  solution blob,
  insert_time timestamp ,
  update_time timestamp ,
  close_time timestamp ,
  update_user varchar(64) ,
  version int NOT NULL ,
  knowledge_base int NOT NULL ,
  submit_user varchar(64) ,
  submit_user_type smallint NOT NULL ,
  request_user varchar(64) ,
  request_user_type smallint NOT NULL ,
  due_date timestamp ,
  location int ,
  parent_link int,
  escalation int,
  third_level_category varchar(32) ,
  assigned_group varchar(64),
  timers_update_time timestamp,
  timer1 bigint,
  timer2 bigint,
  timer3 bigint,
  timer4 bigint,
  timer5 bigint,
  cust_list1 int,
  cust_list2 int,
  cust_text1 varchar(100),
  cust_text2 varchar(100),
  cust_notes blob,
  cust_int1 int,
  cust_int2 int,
  cc varchar(250),
  project_id int,
  task_id int,
  PRIMARY KEY  (account_id,id,version)
) ;

CREATE TABLE sysaid_user (
  user_name varchar(64) NOT NULL ,
  account_id varchar(32) NOT NULL ,
  user_password varchar(32) NOT NULL ,
  first_name varchar(40) ,
  last_name varchar(50) ,
  main_user char(1) ,
  email_address varchar(64) ,
  sms_number varchar(100) ,
  ip_address varchar(32) ,
  user_conf blob,
  phone varchar(32) ,
  cell_phone varchar(32) ,
  notes varchar(255) ,
  location int ,
  car_number varchar(32) ,
  building varchar(32) ,
  floor varchar(32) ,
  cubic varchar(32) ,
  administrator char(1),
  manager char(1),
  version int default 0,
  cust_list1 int,
  cust_list2 int,
  cust_text1 varchar(100),
  cust_text2 varchar(100),
  cust_notes blob,
  cust_int1 int,
  cust_int2 int,
  department int,
  company int,
  disable char(1),
  expiration_time timestamp,
  PRIMARY KEY (user_name)
) ;

CREATE TABLE work_report (
  id int NOT NULL ,
  service_req_id int ,
  account_id varchar(32) ,
  user_name varchar(64) ,
  from_time timestamp ,
  to_time timestamp ,
  description varchar(4000) ,
  cust_list1 int,
  cust_list2 int,
  cust_text1 varchar(100),
  cust_text2 varchar(100),
  cust_notes blob,
  cust_int1 int,
  cust_int2 int,
  cust_int3 int,
  cust_int4 int,
  cust_date1 timestamp,
  cust_date2 timestamp,
  PRIMARY KEY  (id)
);

CREATE GENERATOR work_report_seq ;

CREATE TABLE cust_values (
  account_id varchar(32) NOT NULL ,
  list_name varchar(32) NOT NULL ,
  value_key int NOT NULL ,
  value_caption varchar(100) NOT NULL ,
  value_class int,
  PRIMARY KEY  (account_id,list_name,value_key)
) ;

INSERT INTO cust_values VALUES ('account', 'priority', 1, 'Highest',0);
INSERT INTO cust_values VALUES ('account', 'priority', 2, 'Very High',0);
INSERT INTO cust_values VALUES ('account', 'priority', 3, 'High',0);
INSERT INTO cust_values VALUES ('account', 'priority', 4, 'Normal',0);
INSERT INTO cust_values VALUES ('account', 'priority', 5, 'Low',0);
INSERT INTO cust_values VALUES ('account', 'projectCats', 1, 'Application Implementation',0);
INSERT INTO cust_values VALUES ('account', 'projectCats', 2, 'Integration',0);
INSERT INTO cust_values VALUES ('account', 'projectCats', 3, 'Test',0);
INSERT INTO cust_values VALUES ('account', 'projectCats', 4, 'Upgrade',0);
INSERT INTO cust_values VALUES ('account', 'projectCats', 5, 'Infrastructure',0);
INSERT INTO cust_values VALUES ('account', 'projectStatuses', 1, 'Planned',0);
INSERT INTO cust_values VALUES ('account', 'projectStatuses', 2, 'Specification',0);
INSERT INTO cust_values VALUES ('account', 'projectStatuses', 3, 'Design',0);
INSERT INTO cust_values VALUES ('account', 'projectStatuses', 4, 'Implementation',0);
INSERT INTO cust_values VALUES ('account', 'projectStatuses', 5, 'Test',0);
INSERT INTO cust_values VALUES ('account', 'projectStatuses', 6, 'Deployment',0);
INSERT INTO cust_values VALUES ('account', 'projectStatuses', 7, 'Maintenance',0);
INSERT INTO cust_values VALUES ('account', 'status', 1, 'New',0);
INSERT INTO cust_values VALUES ('account', 'status', 2, 'Open',0);
INSERT INTO cust_values VALUES ('account', 'status', 3, 'Closed',1);
INSERT INTO cust_values VALUES ('account', 'status', 4, 'Verified closed',1);
INSERT INTO cust_values VALUES ('account', 'status', 5, 'Pending',0);
INSERT INTO cust_values VALUES ('account', 'status', 6, 'Postponed',0);
INSERT INTO cust_values VALUES ('account', 'status', 7, 'Deleted',2);
INSERT INTO cust_values VALUES ('account', 'taskCats', 1, 'Specification',0);
INSERT INTO cust_values VALUES ('account', 'taskCats', 2, 'Test',0);
INSERT INTO cust_values VALUES ('account', 'taskCats', 3, 'Design',0);
INSERT INTO cust_values VALUES ('account', 'taskCats', 4, 'Implementation',0);
INSERT INTO cust_values VALUES ('account', 'taskCats', 5, 'Support',0);
INSERT INTO cust_values VALUES ('account', 'taskCats', 6, 'Installation',0);
INSERT INTO cust_values VALUES ('account', 'taskCats', 7, 'Upgrade',0);
INSERT INTO cust_values VALUES ('account', 'taskCats', 8, 'Backup',0);
INSERT INTO cust_values VALUES ('account', 'taskStatuses', 1, 'Not started',0);
INSERT INTO cust_values VALUES ('account', 'taskStatuses', 2, 'In progress',0);
INSERT INTO cust_values VALUES ('account', 'taskStatuses', 3, 'Finished',0);
INSERT INTO cust_values VALUES ('account', 'urgency', 1, 'Urgent',0);
INSERT INTO cust_values VALUES ('account', 'urgency', 2, 'Very High',0);
INSERT INTO cust_values VALUES ('account', 'urgency', 3, 'High',0);
INSERT INTO cust_values VALUES ('account', 'urgency', 4, 'Normal',0);
INSERT INTO cust_values VALUES ('account', 'urgency', 5, 'Low',0);
INSERT INTO cust_values VALUES ('account', 'userRoles', 1, 'Project Manager',0);
INSERT INTO cust_values VALUES ('account', 'userRoles', 2, 'Team Leader',0);
INSERT INTO cust_values VALUES ('account', 'userRoles', 3, 'Team Member',0);
INSERT INTO cust_values VALUES ('account', 'userRoles', 4, 'Tester',0);
INSERT INTO cust_values VALUES ('account', 'survey', 1, 'Poor',0);
INSERT INTO cust_values VALUES ('account', 'survey', 2, 'Fair',0);
INSERT INTO cust_values VALUES ('account', 'survey', 3, 'Good',0);
INSERT INTO cust_values VALUES ('account', 'survey', 4, 'Very Good',0);
INSERT INTO cust_values VALUES ('account', 'survey', 5, 'Excellent',0);
INSERT INTO cust_values VALUES ('account', 'currencyList', 1, 'USD',0);
INSERT INTO cust_values VALUES ('account', 'currencyList', 2, 'EUR',0);

CREATE TABLE list_view (
  account_id varchar(32) NOT NULL ,
  list_name varchar(32) NOT NULL ,
  list_view_name varchar(32) NOT NULL ,
  user_name varchar(64) NOT NULL ,
  list_conf blob,
  PRIMARY KEY  (account_id,list_name,list_view_name,user_name)
) ;



CREATE TABLE service_req_log (
  log_id int NOT NULL ,
  account_id varchar(32) NOT NULL ,
  service_req_id int NOT NULL ,
  log_time timestamp NOT NULL ,
  log_type varchar(32) NOT NULL ,
  log_description varchar(1000) NOT NULL,
  ext_reference int NOT NULL ,
  user_name varchar(64) NOT NULL ,
  PRIMARY KEY  (log_id)
) ;

create generator service_req_log_seq;

CREATE TABLE user2asset (
  account_id varchar(32) NOT NULL ,
  user_name varchar(64) NOT NULL ,
  computer_id varchar(64) NOT NULL  ,
  PRIMARY KEY  (account_id,user_name,computer_id)
);

create table service_req_data (
  id int NOT NULL,
  account_id varchar(32) NOT NULL ,
  screen_capture blob ,
  PRIMARY KEY  (account_id,id)
);

create table software (
  software_id int NOT NULL ,
  account_id varchar(32) NOT NULL ,
  product_name varchar(100) NOT NULL ,
  version varchar(32) ,
  vendor varchar(60) ,
  licenses int ,
  purchase_date timestamp,
  support_expiration timestamp,
  notes blob,
  company int,
  supplier int default 0,
  cust_list1 int,
  cust_list2 int,
  cust_text1 varchar(100),
  cust_text2 varchar(100),
  cust_notes blob,
  cust_int1 int,
  cust_int2 int,
  PRIMARY KEY  (software_id)
);

create generator software_seq;

create table software2install_name (
  account_id varchar(32) NOT NULL ,
  software_id int NOT NULL,
  install_name varchar(100) NOT NULL,
  PRIMARY KEY  (software_id,install_name)
);

create table asset_catalog(
  account_id varchar(32) NOT NULL ,
  catalog_number varchar(64) NOT NULL,
  name varchar(100) NOT NULL ,
  model varchar(64) ,
  manufacturer varchar(64) ,
  supplier_id int,
  notes blob,
  PRIMARY KEY  (account_id,catalog_number)
);

create table supplier(
  supplier_id int NOT NULL ,
  account_id varchar(32) NOT NULL ,
  name varchar(100) NOT NULL ,
  address blob,
  phone varchar(32),
  fax  varchar(32),
  email_address varchar(64),
  notes blob,
  mobile varchar(32),
  phone2 varchar(32),
  contact_name varchar(64),
  account_number varchar(64),
  add cust_list1 int,
  cust_list2 int,
  cust_text1 varchar(100),
  cust_text2 varchar(100),
  cust_notes blob,
  cust_int1 int,
  cust_int2 int,
  PRIMARY KEY  (supplier_id)
);

create generator supplier_seq;

CREATE TABLE faq (
  account_id varchar(32) NOT NULL ,
  id int NOT NULL ,
  title varchar(200),
  question blob ,
  answer blob ,
  category varchar(32) ,
  sub_category varchar(32),
  third_level_category varchar(32),
  kb char(1),
  faq char(1),   
  update_time timestamp,
  PRIMARY KEY  (account_id,id)
) ;

create table service_req_files (
  id int NOT NULL,
  account_id varchar(32) NOT NULL ,
  file_id varchar(64) NOT NULL,
  file_name varchar(255),
  file_date timestamp,
  file_content blob ,
  PRIMARY KEY  (account_id,id,file_id )
);

create table service_req_msg (
  id int NOT NULL,
  account_id varchar(32) NOT NULL ,
  msg_time timestamp NOT NULL ,
  from_user varchar(64) ,
  to_user varchar(64) ,
  method varchar(10),
  subject varchar(400),
  msgid varchar(32),
  msg_body blob,
  PRIMARY KEY  (account_id,id,msg_time)
);

CREATE INDEX service_req_msg_idx1 ON service_req_msg(id,msgid);

CREATE TABLE commands (
    account_id varchar(32) NOT NULL,
    command varchar(100) NOT NULL,
    PRIMARY KEY (account_id, command)
);

CREATE TABLE user_groups (
  account_id varchar(32) NOT NULL,
  group_name varchar(64) NOT NULL,
  group_type int NOT NULL,
  PRIMARY KEY  (account_id,group_name )
);

CREATE TABLE user2group (
  account_id varchar(32) NOT NULL,
  group_name varchar(64) NOT NULL,
  user_name varchar(64) NOT NULL,
  PRIMARY KEY  (account_id,group_name,user_name )
);

CREATE TABLE project (
  id int NOT NULL ,
  account_id varchar(32) NOT NULL,
  version int NOT NULL,
  category int,
  title varchar(100) ,
  description blob,
  status int ,
  notes blob,
  start_time timestamp,
  end_time timestamp,
  raw_estimation int,
  request_group varchar(64),
  manager varchar(64),
  assigned_group varchar(64),
  cust_list1 int,
  cust_list2 int,
  cust_text1 varchar(100),
  cust_text2 varchar(100),
  cust_notes blob,
  cust_int1 int,
  cust_int2 int,
  company int,
  PRIMARY KEY  (id )
);

CREATE GENERATOR project_seq ;

CREATE TABLE project_history (
  id int NOT NULL ,
  account_id varchar(32) NOT NULL,
  version int NOT NULL,
  category int,
  title varchar(100) ,
  description blob,
  status int ,
  notes blob,
  start_time timestamp,
  end_time timestamp,
  raw_estimation int,
  request_group varchar(64),
  manager varchar(64),
  assigned_group varchar(64),
  cust_list1 int,
  cust_list2 int,
  cust_text1 varchar(100),
  cust_text2 varchar(100),
  cust_notes blob,
  cust_int1 int,
  cust_int2 int,
  company int,
  PRIMARY KEY  (id,version )
);

CREATE TABLE project_log (
  log_id int NOT NULL ,
  account_id varchar(32) NOT NULL ,
  project_id int NOT NULL ,
  log_time timestamp NOT NULL ,
  log_type varchar(32) NOT NULL ,
  log_description blob NOT NULL,
  ext_reference int NOT NULL,
  user_name varchar(64) NOT NULL,
  PRIMARY KEY  (log_id)
) ;

CREATE GENERATOR project_log_seq ;

create table project_users (
  id int NOT NULL,
  account_id varchar(32) NOT NULL ,
  user_name varchar(64) NOT NULL,
  user_role int,
  PRIMARY KEY  (account_id,id,user_name )
);

create table project_files (
  id int NOT NULL,
  account_id varchar(32) NOT NULL ,
  file_id varchar(64) NOT NULL,
  file_name varchar(255),
  file_content blob ,
  file_date TIMESTAMP,
  PRIMARY KEY  (account_id,id,file_id )
);

CREATE TABLE task (
  id int NOT NULL,
  account_id varchar(32) NOT NULL,
  version int NOT NULL,
  project_id int,
  category int,
  title varchar(100) ,
  description blob,
  status int ,
  notes blob,
  progress int,
  start_time timestamp,
  end_time timestamp,
  estimation int,
  cust_list1 int,
  cust_list2 int,
  cust_text1 varchar(100),
  cust_text2 varchar(100),
  cust_notes blob,
  cust_int1 int,
  cust_int2 int,
  task_order int default 0,
  PRIMARY KEY  (id )
);

CREATE GENERATOR task_seq ;

CREATE TABLE task_history (
  id int NOT NULL,
  account_id varchar(32) NOT NULL,
  version int NOT NULL,
  project_id int,
  category int,
  title varchar(100) ,
  description blob,
  status int ,
  notes blob,
  progress int,
  start_time timestamp,
  end_time timestamp,
  estimation int,
  cust_list1 int,
  cust_list2 int,
  cust_text1 varchar(100),
  cust_text2 varchar(100),
  cust_notes blob,
  cust_int1 int,
  cust_int2 int,
  task_order int default 0,
  PRIMARY KEY  (id,version )
);

CREATE TABLE task_log (
  log_id int NOT NULL ,
  account_id varchar(32) NOT NULL ,
  task_id int NOT NULL ,
  log_time timestamp NOT NULL ,
  log_type varchar(32) NOT NULL ,
  log_description blob NOT NULL,
  ext_reference int NOT NULL,
  user_name varchar(64) NOT NULL,
  PRIMARY KEY  (log_id)
) ;

CREATE GENERATOR task_log_seq ;

create table task_users (
  id int NOT NULL,
  account_id varchar(32) NOT NULL ,
  user_name varchar(64) NOT NULL,
  user_role int,
  PRIMARY KEY  (account_id,id,user_name )
);

CREATE TABLE task_activities (
  id int NOT NULL ,
  task_id int ,
  account_id varchar(32) ,
  user_name varchar(64) ,
  from_time timestamp ,
  to_time timestamp ,
  description varchar(255) ,
  activity_status int,
  PRIMARY KEY  (id)
);

CREATE GENERATOR task_activities_seq ;

create table task_files (
  id int NOT NULL,
  account_id varchar(32) NOT NULL ,
  file_id varchar(64) NOT NULL,
  file_name varchar(255),
  file_content blob ,
  file_date TIMESTAMP,
  PRIMARY KEY  (account_id,id,file_id )
);

CREATE TABLE asset_types (
  account_id varchar(32) NOT NULL ,
  computer_type varchar(20) NOT NULL ,
  caption varchar(20) NOT NULL ,
  file_name varchar(255),
  default_file_name varchar(255),
  PRIMARY KEY  (account_id,computer_type )
);

insert into asset_types values ('account','Laptop','Laptop','laptop_32.png','laptop_32.png' );
insert into asset_types values ('account','Other','Other','other_32.png','other.gif' );
insert into asset_types values ('account','PDA','PDA','pda_32.png','pda.gif' );
insert into asset_types values ('account','Printer','Printer','printer_32.png','printer.gif' );
insert into asset_types values ('account','Server','Server','server_32.png','server.gif' );
insert into asset_types values ('account','Workstation','Workstation','workstation_32.png','workstation.gif' );

insert into commands (account_id,command) values ('account','Inventory');
insert into commands (account_id,command) values ('account','Upgrade');

CREATE TABLE company (
  company_id int NOT NULL ,
  account_id varchar(32) NOT NULL,
  company_name varchar(100) ,
  address varchar(100) ,
  address2 varchar(100) ,
  city varchar(32),
  state varchar(32),
  zip varchar(32),
  country varchar(32),
  phone varchar(64),
  fax varchar(64),
  notes blob,
  cust_list1 int,
  cust_list2 int,
  cust_text1 varchar(100),
  cust_text2 varchar(100),
  cust_notes blob,
  cust_int1 int,
  cust_int2 int,
  expiration_time timestamp,
  PRIMARY KEY  (company_id )
);

create table monitor_templates (
  account_id varchar(32) NOT NULL,template_name varchar (64) NOT NULL,
  is_server char(1) NOT NULL,
  check_type varchar(32) NOT NULL,
  check_name varchar(64) NOT NULL,
  protocol varchar(32),
  port_num int,
  url_path varchar(255),
  expression varchar(255),
  update_type varchar(32),
  warning_at int,
  warning_notification varchar(64),
  error_at int,
  error_notification varchar(64),
  PRIMARY KEY  (account_id,template_name,check_type,check_name,is_server));

create table monitoring_conf(
  account_id varchar(32) NOT NULL ,
  computer_id varchar(64) NOT NULL,
  is_server char(1) NOT NULL,
  template_name varchar(32) default '',
  notification varchar(64),
  alert int default 0,
  sr_sent int,
  mail_sent int,
  sms_sent int,
  PRIMARY KEY  (account_id,computer_id));

create table monitor_embed_data(
  account_id varchar(32) NOT NULL,
  computer_id varchar (64) NOT NULL,
  is_server char(1) NOT NULL,
  check_type varchar(32) NOT NULL,
  check_name varchar(64) NOT NULL,
  protocol varchar(32),
  port_num int,
  url_path varchar(255),
  expression varchar(255),
  update_type varchar(32),
  warning_at int,
  warning_notification varchar(64),
  error_at int,
  error_notification varchar(64),
  idx_day int,
  idx_week int,
  idx_month int,
  idx_year int,
  time_day timestamp,
  time_week timestamp,
  time_month timestamp,
  time_year timestamp,
  warn_sr_sent int,
  warn_mail_sent int,
  warn_sms_sent int,
  err_sr_sent int ,
  err_mail_sent int ,
  err_sms_sent int ,
  alert int default 0,
  PRIMARY KEY  (account_id,computer_id,check_type,check_name));

create table services_day_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(64) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table services_week_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(64) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table services_month_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(64) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table services_year_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(64) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table processes_day_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(64) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table processes_week_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(64) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table processes_month_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(64) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table processes_year_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(64) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table performance_day_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(64) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table performance_week_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(64) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table performance_month_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(64) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table performance_year_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(64) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table comp_update_day_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(64) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table comp_update_week_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(64) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table comp_update_month_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(64) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table comp_update_year_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(64) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table network_day_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(64) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table network_week_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(64) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table network_month_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(64) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table network_year_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(64) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));
  
create index COMPUTER_LISTS_IDX1 on computer_lists(account_id,computer_id,list_type);

CREATE GENERATOR company_seq ;

CREATE TABLE news (
  news_id int NOT NULL,
  account_id varchar(32) NOT NULL ,
  present char(1),
  title varchar(100),
  description varchar(4000),
  administrator char(1),
  urgency char(1),
  insert_time TIMESTAMP,
  PRIMARY KEY  (news_id) );

CREATE GENERATOR news_seq ;

CREATE TABLE satisfaction_survey (
	account_id    	VARCHAR(32) NOT NULL,
	sr_id         	int NOT NULL,
	answer        	int,
	comments      	VARCHAR(255),
	update_time   	TIMESTAMP,
	responsibility	VARCHAR(32),
    PRIMARY KEY (account_id, sr_id) );

 drop external function substr;
 declare EXTERNAL FUNCTION substr CSTRING(32000), SMALLINT, SMALLINT RETURNS CSTRING(32000) FREE_IT ENTRY_POINT 'IB_UDF_substr' MODULE_NAME 'ib_udf';

 create index COMPUTER_LISTS_IDX2  on computer_lists (list_value);

 create table computer_files (
   id varchar(64) NOT NULL,
   account_id varchar(32) NOT NULL ,
   file_id varchar(64) NOT NULL,
   file_name varchar(255),
   file_date timestamp,
   file_content blob ,
   PRIMARY KEY  (account_id,id,file_id )
 );

create table software_files (
  id int NOT NULL,
  account_id varchar(32) NOT NULL ,
  file_id varchar(64) NOT NULL,
  file_name varchar(255),
  file_date timestamp,
  file_content blob ,
  PRIMARY KEY  (account_id,id,file_id )
);

 create table computer_links (
   id varchar(64) NOT NULL,
   account_id varchar(32) NOT NULL ,
   file_id varchar(64) NOT NULL,
   link varchar(255) NOT NULL,
   file_name varchar(255),
   file_date timestamp,
   PRIMARY KEY  (account_id,id,file_id )
 );

create table sysaid_user_routing (
  account_id varchar(32) NOT NULL ,
  user_name varchar(64) NOT NULL,
  take_over_user varchar(64) NOT NULL ,
  PRIMARY KEY  (account_id,user_name )
);