CREATE TABLE account (
  account_id varchar(32) NOT NULL default '',
  customer_name varchar(64) default NULL,
  expiration_time datetime default NULL,
  serial_key varchar(64) NOT NULL default '',
  account_conf mediumtext,
  assets int,end_users int,
  admins int,
  managers int default 1,
  alert_monitor bool,
  task bool,
  monitoring int default -1,
  report_design bool default 0,
  css bool default 0,
  css_free bool default 0,
  sr int default 100,
  attachments int default 4,
  cmdb bool default 0,
  maintanance_expiration datetime,
  enable bool default 1,
  paid bool default 0,
  version int default 0,
  css_demo bool default 0,
  max_inactive_interval int default 0,
  cookie_support bool default 0,
  sysaid_version varchar(64) default '',
  change_mgmt int default 0,
  password_services int default 0,
  sla bool default 0,
  backup_time datetime default NULL,
  sysaid_edition int default 1,
  product_type int default 1,
  send_automatic_notifications_from_modifier bool default 0,
  account_create_date datetime default NULL,
  concurrent_remote_control_sessions int default 2,
  concurrent_remote_access_sessions int default 1,
  escalation_rules int default 0,
  custom_fields int default 0,
  remote_access bool default 0,
  agents int default 0,
  css_always_turn_admin_to_agent bool default 1,
  is_db_backup bool default 0,
  backup_url varchar(255),
  patch_management_assets int default 0,
  package int default -1,
  bi_admins int DEFAULT 0,
  PRIMARY KEY  (account_id)
);

CREATE TABLE schedule_task (
  task_id int(11) NOT NULL default '0',
  account_id varchar(32) NOT NULL default '',
  computer_id varchar(64) NOT NULL default '',
  group_name varchar(255) NOT NULL default '',
  command varchar(255) NOT NULL default '',
  next_run datetime NOT NULL,
  granularity int(11) NOT NULL default '0',
  units int(11) NOT NULL default '0',
  discovery_service_name varchar(64),
  start_ip_range varchar(64),
  end_ip_range varchar(64),
  exclude_ip_list varchar(255),
  schedule char(1),
  snmp_version int(11),
  community_string varchar(64),
  community_password varchar(64),
  domain varchar(255),
  agent_settings mediumtext,
  filter_sql mediumtext,
  filter_xml mediumtext,
  credentials_id int(11),
  agent_settings_id int(11),
  name varchar(255),
  upgrade_non_responsive numeric(1,0) default 0,
  upgrade_existing numeric(1,0) default 0,
  PRIMARY KEY  (task_id)
) ;

insert into schedule_task (task_id,account_id, group_name, command, next_run, granularity, units) values (1,'account','\\','Inventory',DATE_ADD(CURDATE(), INTERVAL '1 01:05 ' DAY_MINUTE),3,1);
insert into schedule_task (task_id,account_id, group_name, command, next_run, granularity, units) values (2,'account','\\','Upgrade',DATE_ADD(CURDATE(), INTERVAL '1 01:55 ' DAY_MINUTE),2,1);

CREATE TABLE index_consumer_properties(consumer_amount int not null default 1);

INSERT INTO index_consumer_properties (consumer_amount)VALUES(1);

CREATE TABLE index_consumer_account (
  account_id varchar(32) COLLATE utf8_unicode_ci NOT NULL default '',
  processed tinyint(4) NOT NULL default '0',
  processed_update_time datetime,
  consumer_process_id int,
  index_valid tinyint(4) NOT NULL default '1',
  backup_valid tinyint(4) NOT NULL default '0',
  PRIMARY KEY  (account_id)
);

INSERT INTO index_consumer_account (account_id) SELECT account_id FROM account;



-- Performance logging default configuration flags
-- for now it is valid only for cloud environment
-- This table is in comment so we will not receive errors due to different number of tables between different databases
-- create table performance_logger_default_config (
--         config_name varchar(100) not null,
--         config_value smallint not null,
--         primary key (config_name)
-- );
-- insert into performance_logger_default_config (config_name, config_value) values ('PERFORMANCE_LOGGER_IS_ACTIVE', 1);
-- insert into performance_logger_default_config (config_name, config_value) values ('PERFORMANCE_LOGGER_MIN_DURATION_MILLIS_TO_LOG', 2);
-- insert into performance_logger_default_config (config_name, config_value) values ('PERFORMANCE_STAT_SREDIT_LOAD_ANALYTICS', 1);
-- insert into performance_logger_default_config (config_name, config_value) values ('PERFORMANCE_STAT_SREDIT_SAVE_ANALYTICS', 1);
-- insert into performance_logger_default_config (config_name, config_value) values ('PERFORMANCE_STAT_SREDIT_CATEGORY_ANALYTICS', 1);
-- insert into performance_logger_default_config (config_name, config_value) values ('PERFORMANCE_STAT_HELPDESK_LOAD_ANALYTICS', 1);
-- insert into performance_logger_default_config (config_name, config_value) values ('PERFORMANCE_STAT_SREDIT_TAB_LOAD_ANALYTICS', 1);
-- insert into performance_logger_default_config (config_name, config_value) values ('PERFORMANCE_STAT_TRIGGER_ON_LOAD_ANALYTICS', 1);
-- insert into performance_logger_default_config (config_name, config_value) values ('PERFORMANCE_STAT_TRIGGER_BEFORE_SAVE_ANALYTICS', 1);
-- insert into performance_logger_default_config (config_name, config_value) values ('PERFORMANCE_STAT_TRIGGER_AFTER_SAVE_ANALYTICS', 1);
-- insert into performance_logger_default_config (config_name, config_value) values ('PERFORMANCE_STAT_TRIGGER_ADDON_AFTER_SAVE_ANALYTICS', 1);
-- insert into performance_logger_default_config (config_name, config_value) values ('PERFORMANCE_STAT_WFJOE_INITIAL_LOAD', 1);
-- insert into performance_logger_default_config (config_name, config_value) values ('PERFORMANCE_STAT_WFJOE_DESIGN_UPDATE_TIME', 1);
-- insert into performance_logger_default_config (config_name, config_value) values ('PERFORMANCE_LOGGER_WIDGETS_IS_ACTIVE', 0);
-- insert into performance_logger_default_config (config_name, config_value) values ('PERFORMANCE_STAT_WIDGET_ACTIVE_SRS_BY_PRIORITY_SIDE_PANEL_ANALYTICS', 0);
-- insert into performance_logger_default_config (config_name, config_value) values ('PERFORMANCE_STAT_WIDGET_ACTIVE_SRS_BY_TIME_ELAPSED_SIDE_PANEL_ANALYTICS', 0);
-- insert into performance_logger_default_config (config_name, config_value) values ('PERFORMANCE_STAT_WIDGET_BREACH_OF_AGREEMENT_SIDE_PANEL_ANALYTICS', 0);
-- insert into performance_logger_default_config (config_name, config_value) values ('PERFORMANCE_STAT_WIDGET_RECENTLY_MODIFIED_SOFTWARE_PRODUCTS_SIDE_PANEL_ANALYTICS', 0);
-- insert into performance_logger_default_config (config_name, config_value) values ('PERFORMANCE_STAT_WIDGET_RELEVANT_KBS_SIDE_PANEL_ANALYTICS', 0);
-- insert into performance_logger_default_config (config_name, config_value) values ('PERFORMANCE_STAT_WIDGET_REQUEST_USER_SRS_SIDE_PANEL_ANALYTICS', 0);
-- insert into performance_logger_default_config (config_name, config_value) values ('PERFORMANCE_STAT_WIDGET_SIMILAR_SRS_ADMIN_BY_CATEGORY_SIDE_PANEL_ANALYTICS', 0);
-- insert into performance_logger_default_config (config_name, config_value) values ('PERFORMANCE_STAT_WIDGET_SIMILAR_SRS_BY_SUB_CATEGORY_SIDE_PANEL_ANALYTICS', 0);
-- insert into performance_logger_default_config (config_name, config_value) values ('PERFORMANCE_STAT_WIDGET_SRS_CLOSED_TODAY_SIDE_PANEL_ANALYTICS', 0);
-- insert into performance_logger_default_config (config_name, config_value) values ('PERFORMANCE_STAT_WIDGET_SRS_GROUP_CLOSED_TODAY_SIDE_PANEL_ANALYTICS', 0);
-- insert into performance_logger_default_config (config_name, config_value) values ('PERFORMANCE_STAT_WIDGET_UNASSIGNED_SRS_SIDE_PANEL_ANALYTICS', 0);
-- insert into performance_logger_default_config (config_name, config_value) values ('PERFORMANCE_STAT_WIDGET_TIMER_1_SIDE_PANEL_ANALYTICS', 0);
-- insert into performance_logger_default_config (config_name, config_value) values ('PERFORMANCE_STAT_WIDGET_TIMER_2_SIDE_PANEL_ANALYTICS', 0);
-- insert into performance_logger_default_config (config_name, config_value) values ('PERFORMANCE_STAT_WIDGET_TIMER_3_SIDE_PANEL_ANALYTICS', 0);
-- insert into performance_logger_default_config (config_name, config_value) values ('PERFORMANCE_STAT_WIDGET_TIMER_4_SIDE_PANEL_ANALYTICS', 0);
-- insert into performance_logger_default_config (config_name, config_value) values ('PERFORMANCE_STAT_WIDGET_TIMER_5_SIDE_PANEL_ANALYTICS', 0);
-- insert into performance_logger_default_config (config_name, config_value) values ('PERFORMANCE_STAT_WIDGET_TIMER_6_SIDE_PANEL_ANALYTICS', 0);
-- insert into performance_logger_default_config (config_name, config_value) values ('PERFORMANCE_STAT_WIDGET_TIMER_7_SIDE_PANEL_ANALYTICS', 0);
-- insert into performance_logger_default_config (config_name, config_value) values ('PERFORMANCE_STAT_WIDGET_TIMER_8_SIDE_PANEL_ANALYTICS', 0);
-- insert into performance_logger_default_config (config_name, config_value) values ('PERFORMANCE_STAT_WIDGET_TIMER_9_SIDE_PANEL_ANALYTICS', 0);
-- insert into performance_logger_default_config (config_name, config_value) values ('PERFORMANCE_STAT_WIDGET_TIMER_10_SIDE_PANEL_ANALYTICS', 0);

CREATE TABLE version (
  version varchar(64) NOT NULL default ''
) ;

INSERT INTO version VALUES ('20.1.259');
