CREATE TABLE version (
  version varchar(32) NOT NULL
);

INSERT INTO version VALUES ('9.0.092');

CREATE TABLE account (
  account_id varchar(32) NOT NULL ,
  customer_name varchar(64) ,
  expiration_time TIMESTAMP ,
  serial_key varchar(64) NOT NULL ,
  account_conf clob,
  version int NOT NULL,
  PRIMARY KEY  (account_id)
) ;

CREATE TABLE schedule_task (
  task_id int NOT NULL ,
  account_id varchar(32) NOT NULL ,
  computer_id varchar(64) NOT NULL ,
  group_name varchar(255) NOT NULL ,
  command varchar(255) NOT NULL ,
  next_run TIMESTAMP NOT NULL ,
  granularity int NOT NULL ,
  units int NOT NULL ,
  discovery_service_name varchar(64) ,
  start_ip_range varchar(64) ,
  end_ip_range varchar(64) ,
  exclude_ip_list varchar(255) ,
  schedule char(1) ,
  snmp_version int,
  community_string varchar(64) ,
  community_password varchar(64) ,
  domain varchar(255) ,
  agent_settings varchar(4000) ,
  filter_sql varchar(4000)  ,
  filter_xml clob,
  PRIMARY KEY  (task_id)
);


insert into schedule_task (task_id,account_id, group_name, command, next_run, granularity, units, computer_id) values (1,'account','\','Inventory',TIMESTAMP(CURRENT_DATE, TIME('01:05:00')) ,3,1,'');
insert into schedule_task (task_id,account_id, group_name, command, next_run, granularity, units, computer_id) values (2,'account','\','Upgrade',TIMESTAMP(CURRENT_DATE, TIME('01:55:00')),2,1,'');

CREATE TABLE computer (
  account_id varchar(32) NOT NULL ,
  computer_id varchar(64) NOT NULL ,
  computer_name varchar(64) ,
  computer_type varchar(64) ,
  parent_group varchar(255) NOT NULL ,
  inventory_xml clob,
  inventory_time TIMESTAMP ,
  update_time TIMESTAMP ,
  ip_address varchar(64) ,
  description varchar(255) ,
  username varchar(64) ,
  location varchar(255) ,
  location_idx  int,
  building varchar(64),
  floor varchar(64),
  cubic varchar(64),
  catalog_number varchar(64),
  supplier int,
  maintenance_supplier int,
  company_serial varchar(64),
  external_serial varchar(64),
  monitor varchar(64),
  monitor_serial varchar(64),
  collection_type int,
  collection_params clob,
  cust_list1 int,
  cust_list2 int,
  cust_text1 varchar(255),
  cust_text2 varchar(255),
  cust_notes clob,
  cust_int1 int,
  cust_int2 int,
  parent_asset varchar(64),
  department int,
  company int,
  company_backup int default 0,
  disable char(1),
  manual_asset char(1),
  purchase_cost float,
  purchase_currency int,
  agent_version varchar(64),
  cust_date1 TIMESTAMP,
  cust_date2 TIMESTAMP,
  last_access TIMESTAMP,
  last_remote_access TIMESTAMP,
  last_remote_host varchar(64),
  version int NOT NULL,
  snmp_cust_text_1 varchar(255),
  snmp_cust_text_2 varchar(255),
  snmp_cust_text_3 varchar(255),
  snmp_cust_text_4 varchar(255),
  snmp_cust_text_5 varchar(255),
  snmp_cust_text_6 varchar(255),
  snmp_cust_text_7 varchar(255),
  snmp_cust_text_8 varchar(255),
  snmp_cust_text_9 varchar(255),
  snmp_cust_text_10 varchar(255),
  snmp_cust_text_11 varchar(255),
  snmp_cust_text_12 varchar(255),
  snmp_cust_text_13 varchar(255),
  snmp_cust_text_14 varchar(255),
  snmp_cust_text_15 varchar(255),
  snmp_cust_text_16 varchar(255),
  snmp_cust_text_17 varchar(255),
  snmp_cust_text_18 varchar(255),
  snmp_cust_text_19 varchar(255),
  snmp_cust_text_20 varchar(255),
  packets_in float default 0,
  packets_out float default 0,
  mac_address varchar(255),
  last_boot TIMESTAMP,
  track_asset int default 0,
  first_access TIMESTAMP,
  device_status int default 0,
  device_policy int default 0,
  device_ownership int default 0,
  device_imei varchar(255),
  device_icc varchar(255),
  device_home_carrier varchar(255),
  device_current_carrier varchar(255),
  device_phone_number varchar(64),
  device_push varchar(255),
  ios_push_magic varchar(255),
  ios_unlock_token clob,
  designated_rds varchar(64),
  PRIMARY KEY  (account_id,computer_id)
) ;

create index computer_disable_idx_1 on computer (account_id,disable);
create index computer_idx_type_2 on computer(collection_type,computer_id);

CREATE TABLE computer_attributes (
  account_id varchar(32) NOT NULL ,
  computer_id varchar(64) NOT NULL ,
  cpu_vendor varchar(255) ,
  cpu_model varchar(255) ,
  cpu_speed int ,
  bios_type varchar(255) ,
  display_adapter varchar(255) ,
  display_memory int ,
  display_resolution varchar(255) ,
  os_type varchar(255) ,
  os_version varchar(255) ,
  os_service_pack varchar(255) ,
  memory_physical bigint ,
  serial varchar(64),
  model varchar(64) ,
  manufacturer varchar(64) ,
  purchase_date TIMESTAMP,
  warranty_expiration TIMESTAMP,
  last_maintenance TIMESTAMP,
  last_page_count int,
  maintenance_page_count int,
  disks_size int,
  disks_count int,
  mem_banks int,
  occupied_mem_banks int,
  free_mem_banks int,
  cpu_count int,
  os_name varchar(255),
  os_platform varchar(64),
  PRIMARY KEY  (account_id,computer_id)
);

CREATE TABLE computer_changes (
  account_id varchar(32) NOT NULL ,
  computer_id varchar(64) NOT NULL ,
  change_time TIMESTAMP NOT NULL ,
  change_type varchar(64) NOT NULL ,
  change_sub_type varchar(64) NOT NULL ,
  change_description clob NOT NULL,
  log_id int
) ;

CREATE TABLE computer_group (
  account_id varchar(32) NOT NULL ,
  group_name varchar(255) NOT NULL ,
  parent_group_name varchar(255) NOT NULL ,
  group_description varchar(255) ,
  group_level int ,
  PRIMARY KEY  (account_id,group_name)
) ;

CREATE TABLE computer_lists (
  account_id varchar(32) NOT NULL ,
  computer_id varchar(64) NOT NULL ,
  list_type varchar(64) NOT NULL ,
  value varchar(255) NOT NULL,
  list_display varchar(255),
  version varchar(255),
  license varchar(255)
) ;

CREATE TABLE computer_log (
  log_id int NOT NULL generated by default as identity,
  account_id varchar(32) NOT NULL ,
  computer_id varchar(64) NOT NULL ,
  log_time TIMESTAMP NOT NULL ,
  log_type varchar(64) NOT NULL ,
  log_sub_type varchar(64) NOT NULL ,
  log_description clob NOT NULL,
  ext_reference int ,
  user_name varchar(64) ,
  ext_reference2 int ,
  PRIMARY KEY  (log_id)
) ;



CREATE TABLE computer_users (
  account_id varchar(32) NOT NULL ,
  computer_id varchar(64) NOT NULL ,
  user_name varchar(64) NOT NULL ,
  full_name varchar(255) ,
  email_address varchar(64) ,
  PRIMARY KEY  (account_id,computer_id,user_name)
) ;

CREATE TABLE event (
  account_id varchar(32) NOT NULL ,
  computer_id varchar(64) NOT NULL ,
  log_type varchar(64) NOT NULL ,
  event_time TIMESTAMP NOT NULL ,
  record_number int NOT NULL ,
  event_id int NOT NULL ,
  event_type varchar(64) NOT NULL ,
  event_source varchar(64) NOT NULL ,
  event_category varchar(64) ,
  event_username varchar(64) ,
  event_domain varchar(64) ,
  event_computer varchar(64) ,
  event_description varchar(255) ,
  event_binary blob,
  event_char_data clob,
  PRIMARY KEY  (account_id,computer_id,log_type,event_time,record_number)
) ;

CREATE TABLE login_log (
  log_time TIMESTAMP ,
  account_id varchar(32) ,
  user_name varchar(64) ,
  status varchar(64) ,
  ip_address varchar(64)
) ;

CREATE TABLE messages (
  account_id varchar(32) NOT NULL ,
  user_name varchar(64) NOT NULL ,
  sent_time TIMESTAMP NOT NULL ,
  sender varchar(64) ,
  recv_flag int NOT NULL ,
  msg clob,
  msgid varchar(64),
  service_request_id int,
  display_to_user char(1) default 'Y',
  PRIMARY KEY  (account_id,user_name,sent_time)
) ;

CREATE TABLE problem_type (
  account_id varchar(32) NOT NULL ,
  problem_type varchar(64) NOT NULL ,
  problem_sub_type varchar(64) NOT NULL ,
  route varchar(64) ,
  desc_template clob,
  third_level_category varchar(64) NOT NULL ,
  module_relevance int default 1023,
  incident_template int,
  request_template int,
  change_template int,
  problem_template int,
  PRIMARY KEY  (account_id,problem_type,problem_sub_type,third_level_category)
) ;

CREATE TABLE service_req (
  id int NOT NULL generated by default as identity,
  account_id varchar(32) NOT NULL ,
  computer_id varchar(64) NOT NULL ,
  ci_id int,
  problem_type varchar(64) ,
  problem_sub_type varchar(64) ,
  title varchar(255) ,
  description clob,
  workaround clob,
  known_error char(1) default 'N',
  status int ,
  contact clob,
  responsibility varchar(64) ,
  urgency int ,
  priority int ,
  notes clob,
  resolution clob,
  solution clob,
  insert_time TIMESTAMP ,
  update_time TIMESTAMP ,
  close_time TIMESTAMP ,
  update_user varchar(64) ,
  version int NOT NULL ,
  knowledge_base int NOT NULL ,
  submit_user varchar(64) ,
  submit_user_type int NOT NULL ,
  request_user varchar(64) ,
  request_user_type int NOT NULL ,
  responsible_manager varchar(64) ,
  email_account varchar(64) ,
  due_date TIMESTAMP ,
  location int ,
  parent_link int,
  escalation int,
  third_level_category varchar(64),
  assigned_group varchar(64),
  timers_update_time TIMESTAMP,
  timer1 bigint,
  timer2 bigint,
  timer3 bigint,
  timer4 bigint,
  timer5 bigint,
  timer6 bigint,
  timer7 bigint,
  timer8 bigint,
  timer9 bigint,
  timer10 bigint,
  cust_list1 int,
  cust_list2 int,
  cust_text1 varchar(255),
  cust_text2 varchar(255),
  cust_notes clob,
  cust_int1 int,
  cust_int2 int,
  cc varchar(255),
  project_id int,
  task_id int,
  sr_type int default 1,
  full_name varchar(255),
  cust_date1 TIMESTAMP,
  cust_date2 TIMESTAMP,
  source int default 0,
  sr_sub_type int,
  followup_planned_date TIMESTAMP,
  followup_actual_date TIMESTAMP,
  followup_user varchar(64),
  followup_text clob,
  success_rating int,
  reopen_counter int,
  assign_counter int,
  max_support_level int,
  current_support_level int,
  agreement  int default 0,
  survey_status int default  0,
  impact int default 0,
  change_category int default 0,
  archive int default 0,
  closure_information int default 0,
  visible_to_eu char(1) default 'N',
  sr_class varchar(255),
  PRIMARY KEY  (id)
) ;


create index service_req_ind_1 on service_req (status );
create index service_req_ind_3 on service_req (account_id, sr_type, status);
create index service_req_ind_4 on service_req (account_id, sr_type);
create index service_req_ind_5 on service_req(account_id,parent_link);
create index service_req_ind_6 on service_req(account_id,archive);

CREATE TABLE service_req_history (
  id int NOT NULL ,
  account_id varchar(32) NOT NULL ,
  computer_id varchar(64) NOT NULL ,
  ci_id int,
  problem_type varchar(64) ,
  problem_sub_type varchar(64) ,
  title varchar(255) ,
  description clob,
  workaround clob,
  known_error char(1) default 'N',
  status int ,
  contact clob,
  responsibility varchar(64) ,
  urgency int ,
  priority int ,
  notes clob,
  resolution clob,
  solution clob,
  insert_time TIMESTAMP ,
  update_time TIMESTAMP ,
  close_time TIMESTAMP ,
  update_user varchar(64) ,
  version int NOT NULL ,
  knowledge_base int NOT NULL ,
  submit_user varchar(64) ,
  submit_user_type int NOT NULL ,
  request_user varchar(64) ,
  request_user_type int NOT NULL ,
  responsible_manager varchar(64) ,
  email_account varchar(64) ,
  due_date TIMESTAMP ,
  location int ,
  parent_link int,
  escalation int,
  third_level_category varchar(64),
  assigned_group varchar(64),
  timers_update_time TIMESTAMP,
  timer1 bigint,
  timer2 bigint,
  timer3 bigint,
  timer4 bigint,
  timer5 bigint,
  timer6 bigint,
  timer7 bigint,
  timer8 bigint,
  timer9 bigint,
  timer10 bigint,
  cust_list1 int,
  cust_list2 int,
  cust_text1 varchar(255),
  cust_text2 varchar(255),
  cust_notes clob,
  cust_int1 int,
  cust_int2 int,
  cc varchar(255),
  project_id int,
  task_id int,
  sr_type int default 1,
  full_name varchar(255),
  cust_date1 TIMESTAMP,
  cust_date2 TIMESTAMP,
  source int default 0,
  sr_sub_type int,
  followup_planned_date TIMESTAMP,
  followup_actual_date TIMESTAMP,
  followup_user varchar(64),
  followup_text clob,
  success_rating int,
  reopen_counter int,
  assign_counter int,
  max_support_level int,
  current_support_level int,
  agreement  int default 0,
  survey_status int default  0,
  impact int default 0,
  change_category int default 0,
  archive int default 0,
  closure_information int default 0,
  visible_to_eu char(1),
  sr_class varchar(255),
  PRIMARY KEY  (account_id,id,version)
) ;

CREATE TABLE sr_sub_type (
  account_id varchar(32) NOT NULL ,
  sr_type int NOT NULL,
  sr_sub_type int NOT NULL generated by default as identity,
  sub_type_name varchar(255) NOT NULL,
  sub_type_class varchar(255),
  sub_type_form_view clob,
  end_user_view clob,
  PRIMARY KEY (account_id,sr_type,sr_sub_type)
);

CREATE TABLE sub_tab_views (
  account_id varchar(32) NOT NULL,
  id int NOT NULL generated by default as identity,
  name varchar(64),
  caption varchar(64),
  sub_tab_view clob,
  PRIMARY KEY (id)
);

create table sr_sub_tab (
  account_id varchar(32) NOT NULL,
  sr_id int NOT NULL,
  tab_name varchar(64) NOT NULL,
  sub_tab_id int NOT NULL,
  sub_tab_order int NOT NULL,
  assigned_to varchar(64),
  submit_user varchar(64),
  insert_time TIMESTAMP default NULL,
  due_date TIMESTAMP default NULL,
  title varchar(255) default NULL,
  description clob,
  notes clob,
  proposed_delivery_date TIMESTAMP default NULL,
  proposed_version varchar(64),
  complexity int,
  severity int,
  urgency int,
  priority int,
  status int,
  active int,
  auto_complete char(1),
  on_complete_change_status int,
  notification_id varchar(255),
  notification_method varchar(64) ,
  duration float,
  resources_required_in_days float,
  ci_id int,
  cab_meeting_reference varchar(64),
  percent_completed int,
  cust_int1 int,
  cust_int2 int,
  cust_int3 int,
  cust_int4 int,
  cust_int5 int,
  cust_int6 int,
  cust_int7 int,
  cust_int8 int,
  cust_int9 int,
  cust_int10 int,
  cust_text1 varchar(255),
  cust_text2 varchar(255),
  cust_text3 varchar(255),
  cust_text4 varchar(255),
  cust_text5 varchar(255),
  cust_text6 varchar(255),
  cust_text7 varchar(255),
  cust_text8 varchar(255),
  cust_text9 varchar(255),
  cust_text10 varchar(255),
  cust_date1 TIMESTAMP,
  cust_date2 TIMESTAMP,
  cust_date3 TIMESTAMP,
  cust_date4 TIMESTAMP,
  cust_date5 TIMESTAMP,
  cust_date6 TIMESTAMP,
  cust_date7 TIMESTAMP,
  cust_date8 TIMESTAMP,
  cust_date9 TIMESTAMP,
  cust_date10 TIMESTAMP,
  cust_list1 int,
  cust_list2 int,
  cust_list3 int,
  cust_list4 int,
  cust_list5 int,
  cust_list6 int,
  cust_list7 int,
  cust_list8 int,
  cust_list9 int,
  cust_list10 int,
  cust_notes1 clob,
  cust_notes2 clob,
  cust_notes3 clob,
  cust_notes4 clob,
  cust_notes5 clob,
  cust_notes6 clob,
  cust_notes7 clob,
  cust_notes8 clob,
  cust_notes9 clob,
  cust_notes10 clob,
  task_id int,
  project_id int,
  assigned_group varchar(64),
  location int,
  completed_time TIMESTAMP,
  enabled_time TIMESTAMP,
  company int,
  company_backup int default 0,
  modify_time TIMESTAMP,
  policy_compliance char(1),
  budgeted char(1),
  approved char(1),
  user_acceptance char(1),
  hardware_costs float,
  software_costs float,
  installation_costs float,
  training_costs float,
  maintenance_costs float,
  total_costs float,
  internal_manpower_in_hours float,
  total_expected_downtime_hours float,
  department int,
  expected_downtime_start TIMESTAMP,
  expected_downtime_end TIMESTAMP,
  impact int,reopened varchar(255),
  cust_float1 float,
  cust_float2 float,
  cust_float3 float,
  cust_float4 float,
  cust_float5 float,
  cust_float6 float,
  cust_float7 float,
  cust_float8 float,
  cust_float9 float,
  cust_float10 float,
  version int NOT NULL default 0,
  allow_pdf varchar(1),
  update_user varchar(64),
  reopened_note clob,
  and_condition varchar(1),
  additional_user varchar(64),
  on_activate_change_status int,
 PRIMARY KEY(account_id,sr_id,tab_name,sub_tab_order)
);

CREATE INDEX sr_sub_tab_assigned_to ON sr_sub_tab(sr_id,assigned_to,status,sub_tab_order);

CREATE TABLE sr_sub_tab_history (
  account_id varchar(32) NOT NULL,
  sr_id int NOT NULL,
  tab_name varchar(64) NOT NULL,
  sub_tab_id int NOT NULL,
  sub_tab_order int NOT NULL,
  assigned_to varchar(64),
  submit_user varchar(64),
  insert_time TIMESTAMP default NULL,
  due_date TIMESTAMP default NULL,
  title varchar(255) default NULL,
  description clob,
  notes clob,
  proposed_delivery_date TIMESTAMP default NULL,
  proposed_version varchar(64),
  complexity int,
  severity int,
  urgency int,
  priority int,
  status int,
  active int,
  auto_complete char(1),
  on_complete_change_status int default NULL,
  notification_id varchar(255),
  notification_method varchar(64),
  duration float,
  resources_required_in_days float,
  ci_id int,
  cab_meeting_reference varchar(64),
  percent_completed int,
  cust_int1 int,
  cust_int2 int,
  cust_int3 int,
  cust_int4 int,
  cust_int5 int,
  cust_int6 int,
  cust_int7 int,
  cust_int8 int,
  cust_int9 int,
  cust_int10 int,
  cust_text1 varchar(255),
  cust_text2 varchar(255),
  cust_text3 varchar(255),
  cust_text4 varchar(255),
  cust_text5 varchar(255),
  cust_text6 varchar(255),
  cust_text7 varchar(255),
  cust_text8 varchar(255),
  cust_text9 varchar(255),
  cust_text10 varchar(255),
  cust_date1 TIMESTAMP,
  cust_date2 TIMESTAMP,
  cust_date3 TIMESTAMP,
  cust_date4 TIMESTAMP,
  cust_date5 TIMESTAMP,
  cust_date6 TIMESTAMP,
  cust_date7 TIMESTAMP,
  cust_date8 TIMESTAMP,
  cust_date9 TIMESTAMP,
  cust_date10 TIMESTAMP,
  cust_list1 int,
  cust_list2 int,
  cust_list3 int,
  cust_list4 int,
  cust_list5 int,
  cust_list6 int,
  cust_list7 int,
  cust_list8 int,
  cust_list9 int,
  cust_list10 int,
  cust_notes1 clob,
  cust_notes2 clob,
  cust_notes3 clob,
  cust_notes4 clob,
  cust_notes5 clob,
  cust_notes6 clob,
  cust_notes7 clob,
  cust_notes8 clob,
  cust_notes9 clob,
  cust_notes10 clob,
  task_id int,
  project_id int,
  assigned_group varchar(64),
  location int,
  completed_time TIMESTAMP,
  enabled_time TIMESTAMP,
  company int,
  company_backup int default 0,
  modify_time TIMESTAMP,
  policy_compliance char(1),
  budgeted char(1),
  approved char(1),
  user_acceptance char(1),
  hardware_costs float,
  software_costs float,
  installation_costs float,
  training_costs float,
  maintenance_costs float,
  total_costs float,
  internal_manpower_in_hours float,
  total_expected_downtime_hours float,
  department int,
  expected_downtime_start TIMESTAMP,
  expected_downtime_end TIMESTAMP,
  impact int,
  reopened varchar(255),
  cust_float1 float,
  cust_float2 float,
  cust_float3 float,
  cust_float4 float,
  cust_float5 float,
  cust_float6 float,
  cust_float7 float,
  cust_float8 float,
  cust_float9 float,
  cust_float10 float,
  version int NOT NULL default 0,
  change_time TIMESTAMP,
  changed_by varchar(64),
  allow_pdf varchar(1),
  update_user varchar(64),
  reopened_note clob,
  and_condition varchar(1),
  additional_user varchar(64),
  on_activate_change_status int,
  PRIMARY KEY(account_id,sr_id,tab_name,sub_tab_order,version)
);


create table sr_tab_dependences (
  account_id varchar(32) NOT NULL,
  sr_id int NOT NULL,
  tab_name varchar(64) NOT NULL,
  sub_tab_order int NOT NULL,
  depends_on_tab varchar(64),
  depends_on_sub int,
  dependent_method varchar(64),
  add_depends varchar(255),
  filter_expression varchar(4000),
  filter_sql varchar(4000)
);

create index sr_tab_depends_idx1 on sr_tab_dependences(account_id,sr_id,tab_name,sub_tab_order);

create table sr_sub_tab_files (
  id varchar(64) NOT NULL default '',
  account_id varchar(32) NOT NULL,
  file_id varchar(64) NOT NULL,
  file_name varchar(255),
  file_date TIMESTAMP,
  file_content blob,
  real_file_name varchar(255),
  PRIMARY KEY  (account_id,id,file_id )
);

create table sr_sub_tab_links (
  id varchar(64) NOT NULL default '',
  account_id varchar(32) NOT NULL,
  file_id varchar(64) NOT NULL,
  link varchar(255) NOT NULL,
  file_name varchar(255),
  file_date TIMESTAMP,
  PRIMARY KEY  (account_id,id,file_id )
);

CREATE TABLE sysaid_user (
  user_name varchar(64) NOT NULL ,
  account_id varchar(32) NOT NULL ,
  password varchar(64) NOT NULL ,
  first_name varchar(64) ,
  last_name varchar(64) ,
  main_user char(1) ,
  email_address varchar(64) ,
  sms_number varchar(255) ,
  ip_address varchar(64) ,
  user_conf clob,
  phone varchar(64) ,
  cell_phone varchar(64) ,
  notes varchar(255) ,
  location int ,
  car_number varchar(64) ,
  building varchar(64) ,
  floor varchar(64) ,
  cubic varchar(64) ,
  administrator char(1),
  manager char(1),
  version int default 0,
  cust_list1 int,
  cust_list2 int,
  cust_text1 varchar(255),
  cust_text2 varchar(255),
  cust_notes clob,
  cust_int1 int,
  cust_int2 int,
  department int,
  company int,
  company_backup int default 0,
  disable char(1),
  expiration_time TIMESTAMP,
  cust_date1 TIMESTAMP,
  cust_date2 TIMESTAMP,
  history_version int NOT NULL,
  ldap int NOT NULL default 0,
  check_ldap int default 0,
  email_notifications char(1) default 'Y',
  permissions_by_groups char(1),
  user_manager_name varchar(64) default NULL,
  chat_nick_name varchar(64),
  enable_login_to_eup char(1) default '1',
  agreement  int default 0,
  display_name varchar(64),
  secondary_email varchar(64) default NULL,
  my_photo_url varchar(64) default NULL,
  sr_email_notif_condition clob,
  login_user varchar(64),
  login_domain varchar(64),
  login_guid varchar(64),
  calculated_user_name varchar(255),
  calculated_user_name_upper varchar(255),
  locale varchar(64),
  timezone varchar(64),
  charset varchar(64),
  login_user_upper varchar(64),
  user_name_upper varchar(64),
  PRIMARY KEY (user_name)
) ;

create index sysaid_user_idx_1 on sysaid_user (calculated_user_name_upper);
create index sysaid_user_idx_2 on sysaid_user (login_user,login_domain);
create index sysaid_user_idx_3 on sysaid_user (disable,administrator);
create index sysaid_user_idx_4 on sysaid_user (login_guid);
create index sysaid_user_idx_5 on sysaid_user (user_name_upper);
create index sysaid_user_idx_6 on sysaid_user (login_user_upper,login_domain);


CREATE TABLE sysaid_user_history (
  user_name varchar(64) NOT NULL ,
  account_id varchar(32) NOT NULL ,
  password varchar(64) NOT NULL ,
  first_name varchar(64) ,
  last_name varchar(64) ,
  main_user char(1) ,
  email_address varchar(64) ,
  sms_number varchar(255) ,
  ip_address varchar(64) ,
  user_conf clob,
  phone varchar(64) ,
  cell_phone varchar(64) ,
  notes varchar(255) ,
  location int ,
  car_number varchar(64) ,
  building varchar(64) ,
  floor varchar(64) ,
  cubic varchar(64) ,
  administrator char(1),
  manager char(1),
  version int default 0,
  cust_list1 int,
  cust_list2 int,
  cust_text1 varchar(255),
  cust_text2 varchar(255),
  cust_notes clob,
  cust_int1 int,
  cust_int2 int,
  department int,
  company int,
  company_backup int default 0,
  disable char(1),
  expiration_time TIMESTAMP,
  cust_date1 TIMESTAMP,
  cust_date2 TIMESTAMP,
  history_version int NOT NULL,
  ldap int NOT NULL default 0,
  check_ldap int default 0,
  change_time TIMESTAMP,
  changed_by varchar(64),
  email_notifications char(1) default 'Y',
  permissions_by_groups char(1),
  user_manager_name varchar(64) default NULL,
  chat_nick_name varchar(64),
  enable_login_to_eup char(1) default '1',
  agreement  int default 0,
  display_name varchar(64),
  secondary_email varchar(64) default NULL,
  my_photo_url varchar(64) default NULL,
  sr_email_notif_condition clob,
  login_user varchar(64),
  login_domain varchar(64),
  login_guid varchar(64),
  calculated_user_name varchar(255),
  calculated_user_name_upper varchar(255),
  locale varchar(64),
  timezone varchar(64),
  charset varchar(64),
  login_user_upper varchar(64),
  user_name_upper varchar(64),
  PRIMARY KEY (user_name,history_version)
);

CREATE TABLE work_report (
  id int NOT NULL generated by default as identity,
  service_req_id int ,
  account_id varchar(32) ,
  user_name varchar(64) ,
  from_time TIMESTAMP ,
  to_time TIMESTAMP ,
  description clob ,
  cust_list1 int,
  cust_list2 int,
  cust_text1 varchar(255),
  cust_text2 varchar(255),
  cust_notes clob,
  cust_int1 int,
  cust_int2 int,
  cust_int3 int,
  cust_int4 int,
  cust_date1 timestamp,
  cust_date2 timestamp,
  ci_id int,
  PRIMARY KEY  (id)
);



CREATE TABLE cust_values (
  account_id varchar(32) NOT NULL ,
  list_name varchar(64) NOT NULL ,
  value_key int NOT NULL ,
  value_caption varchar(255) NOT NULL ,
  value_class int,
  module_relevance int default 1023,
  valid_for_user_group varchar(255) ,
  PRIMARY KEY  (account_id,list_name,value_key)
) ;

CREATE TABLE sort_cust_values (
  account_id varchar(32) NOT NULL ,
  list_name varchar(64) NOT NULL ,
  sort_by varchar(64) ,
  PRIMARY KEY  (account_id,list_name)
) ;

INSERT INTO cust_values VALUES ('account', 'priority', 1, 'Highest',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'priority', 2, 'Very High',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'priority', 3, 'High',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'priority', 4, 'Normal',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'priority', 5, 'Low',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'projectStatuses', 1, 'Planned',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'projectStatuses', 2, 'Specification',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'projectStatuses', 3, 'Design',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'projectStatuses', 4, 'Implementation',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'projectStatuses', 5, 'Test',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'projectStatuses', 6, 'Deployment',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'projectStatuses', 7, 'Maintenance',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'status', 1, 'New',0,14,null);
INSERT INTO cust_values VALUES ('account', 'status', 2, 'Open',0,2,null);
INSERT INTO cust_values VALUES ('account', 'status', 3, 'Closed',1,2,null);
INSERT INTO cust_values VALUES ('account', 'status', 4, 'Verified closed',1,2,null);
INSERT INTO cust_values VALUES ('account', 'status', 5, 'Pending',0,2,null);
INSERT INTO cust_values VALUES ('account', 'status', 6, 'Postponed',0,2,null);
INSERT INTO cust_values VALUES ('account', 'status', 7, 'Deleted',2,2,null);
INSERT INTO cust_values VALUES ('account', 'taskCats', 1, 'Specification',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'taskCats', 2, 'Test',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'taskCats', 3, 'Design',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'taskCats', 4, 'Implementation',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'taskCats', 5, 'Support',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'taskCats', 6, 'Installation',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'taskCats', 7, 'Upgrade',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'taskCats', 8, 'Backup',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'taskStatuses', 1, 'Not started',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'taskStatuses', 2, 'In progress',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'taskStatuses', 3, 'Finished',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'urgency', 1, 'Urgent',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'urgency', 2, 'Very High',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'urgency', 3, 'High',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'urgency', 4, 'Normal',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'urgency', 5, 'Low',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'userRoles', 1, 'Project Manager',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'userRoles', 2, 'Team Leader',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'userRoles', 3, 'Team Member',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'userRoles', 4, 'Tester',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'survey', 1, 'Poor',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'survey', 2, 'Fair',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'survey', 3, 'Good',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'survey', 4, 'Very Good',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'survey', 5, 'Excellent',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'currencyList', 1, 'USD',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'currencyList', 2, 'EUR',0,1023,null);
INSERT INTO cust_values VALUES ('account','CIStatus',1,'Active',0,1023,null);
INSERT INTO cust_values VALUES ('account','CIStatus',2,'Deleted',2,1023,null);
INSERT INTO cust_values VALUES ('account','CIStatus',3,'Under Testing Environment',0,1023,null);
INSERT INTO cust_values VALUES ('account','CIStatus',4,'In Production',0,1023,null);
INSERT INTO cust_values VALUES ('account','CIStatus',5,'Inactive',1,1023,null);
INSERT INTO cust_values VALUES ('account', 'changeCategory', 1, 'Minor',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'changeCategory', 2, 'Significant',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'changeCategory', 3, 'Major',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'closureInformation', 1, 'Solved (Permanently)',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'closureInformation', 2, 'Solved (Work Around)',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'closureInformation', 3, 'Solved On-site',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'closureInformation', 4, 'Solved Remotely',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'closureInformation', 5, 'Not Solved (Not Reproducible)',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'closureInformation', 6, 'Not Solved (Too Costly)',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'closureInformation', 7, 'Closed/Resolved by Requester',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'deviceOwnership', 1, 'Employee Owned',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'deviceOwnership', 2, 'Corporate Owned',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'deviceStatus', 1, 'Enrolled',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'deviceStatus', 2, 'Not enrolled',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'deviceStatus', 3, 'Revoked by Admin',0,1023,null);
INSERT INTO cust_values VALUES ('account', 'deviceStatus', 4, 'Revoked by End-User',0,1023,null);



CREATE TABLE list_view (
  account_id varchar(32) NOT NULL ,
  list_name varchar(64) NOT NULL ,
  list_view_name varchar(64) NOT NULL ,
  user_name varchar(64) NOT NULL ,
  list_conf clob,
  enable_delete char(1) default 'Y',
  version int default 0,
  PRIMARY KEY  (account_id,list_name,list_view_name,user_name)
) ;



CREATE TABLE service_req_log (
  log_id int NOT NULL generated by default as identity,
  account_id varchar(32) NOT NULL ,
  service_req_id int NOT NULL ,
  log_time TIMESTAMP NOT NULL ,
  log_type varchar(64) NOT NULL ,
  log_description clob NOT NULL,
  ext_reference int NOT NULL,
  user_name varchar(64) NOT NULL,
  PRIMARY KEY  (log_id)
) ;



CREATE TABLE user2asset (
  account_id varchar(32) NOT NULL ,
  user_name varchar(64) NOT NULL ,
  computer_id varchar(64) NOT NULL  ,
  PRIMARY KEY  (account_id,user_name,computer_id)
);

create table service_req_data (
  id int NOT NULL,
  account_id varchar(32) NOT NULL ,
  screen_capture blob ,
  PRIMARY KEY  (account_id,id)
);

create table software (
  software_id int NOT NULL generated by default as identity,
  account_id varchar(32) NOT NULL ,
  product_name varchar(255) NOT NULL ,
  version varchar(64) ,
  vendor varchar(64) ,
  licenses int ,
  purchase_date TIMESTAMP,
  support_expiration TIMESTAMP,
  notes clob,
  company int,
  company_backup int default 0,
  supplier int default 0 ,
  cust_list1 int ,
  cust_list2 int ,
  cust_text1 varchar(255) ,
  cust_text2 varchar(255) ,
  cust_notes clob ,
  cust_int1 int ,
  cust_int2 int ,
  cust_date1 TIMESTAMP,
  cust_date2 TIMESTAMP,
  history_version int NOT NULL,
  freeware varchar(1),
  exceedlic_installed int default 0,
  PRIMARY KEY  (software_id)
);

create table software2install_name (
  account_id varchar(32) NOT NULL ,
  software_id int NOT NULL,
  install_name varchar(255) NOT NULL,
  PRIMARY KEY  (software_id,install_name)
);

create table asset_catalog(
  account_id varchar(32) NOT NULL ,
  catalog_number varchar(64) NOT NULL,
  name varchar(255) NOT NULL ,
  model varchar(64) ,
  manufacturer varchar(64) ,
  supplier_id int,
  notes clob,
  cust_date1 TIMESTAMP,
  cust_date2 TIMESTAMP,
  version int NOT NULL,
  PRIMARY KEY  (account_id,catalog_number)
);

create table supplier(
  supplier_id int NOT NULL generated by default as identity,
  account_id varchar(32) NOT NULL ,
  name varchar(255) NOT NULL ,
  address clob,
  phone varchar(64),
  fax  varchar(64),
  email_address varchar(64),
  notes clob,
  mobile varchar(64),
  phone2 varchar(64),
  contact_name varchar(64),
  account_number varchar(64),
  cust_list1 int,
  cust_list2 int,
  cust_text1 varchar(255),
  cust_text2 varchar(255),
  cust_notes clob,
  cust_int1 int,
  cust_int2 int,
  cust_date1 TIMESTAMP,
  cust_date2 TIMESTAMP,
  version int NOT NULL,
  PRIMARY KEY  (supplier_id)
);


CREATE TABLE faq (
  account_id varchar(32) NOT NULL ,
  id int NOT NULL,
  title varchar(255),
  question clob,
  answer clob,
  category varchar(64),
  sub_category varchar(64),
  third_level_category varchar(64),
  kb char(1),
  faq char(1),
  update_time TIMESTAMP,
  admin_topic_views int NOT NULL default 0,
  user_topic_views int NOT NULL default 0,
  created_on TIMESTAMP,
  created_by varchar(64),
  update_by varchar(64),
  enable_expire int,
  expire_date TIMESTAMP,
  keywords varchar(255) default '',
  publish int,
  voteYes int default 0,
  voteNo int default 0,
  PRIMARY KEY  (account_id,id)
);

CREATE TABLE faq_tags (
  id int,
  tag varchar(255) default ''
);
create index faq_tags_ind_1 on faq_tags(id);
create index faq_tags_ind_2 on faq_tags(tag);

create table service_req_files (
  id int NOT NULL,
  account_id varchar(32) NOT NULL ,
  file_id varchar(64) NOT NULL,
  file_name varchar(255),
  file_date  TIMESTAMP,
  chat_session_id int,
  file_content blob (100M),
  real_file_name varchar(255),
  PRIMARY KEY  (account_id,id,file_id )
);

create table service_req_msg (
  id int NOT NULL,
  account_id varchar(32) NOT NULL ,
  msg_time TIMESTAMP NOT NULL ,
  from_user varchar(64) ,
  to_user varchar(255) ,
  cc_user varchar(255),
  method varchar(64),
  subject clob,
  msgid varchar(64),
  msg_body clob,
  PRIMARY KEY  (account_id,id,msg_time)
);

CREATE INDEX service_req_msg_idx1 ON service_req_msg(id,msgid);

CREATE TABLE commands (
    account_id varchar(32) NOT NULL ,
    command varchar(255) NOT NULL ,
    PRIMARY KEY (account_id, command)
);

CREATE TABLE user_groups (
  account_id varchar(32) NOT NULL,
  group_name varchar(64) NOT NULL,
  group_type int NOT NULL,
  support_level int NOT NULL default 0,
  permission clob,
  display_group char(1) default 'Y',
  PRIMARY KEY  (account_id,group_name )
);

create index user_groups_idx_1 on user_groups (group_name,group_type);
create index user_groups_idx_2 on user_groups (display_group);


CREATE TABLE user2group (
  account_id varchar(32) NOT NULL,
  group_name varchar(64) NOT NULL,
  user_name varchar(64) NOT NULL,
  PRIMARY KEY  (account_id,group_name,user_name )
);

CREATE TABLE project (
  id int NOT NULL generated by default as identity,
  account_id varchar(32) NOT NULL,
  version int NOT NULL,
  category int,
  title varchar(255) ,
  description clob,
  status int ,
  notes clob,
  start_time TIMESTAMP,
  end_time TIMESTAMP,
  raw_estimation int,
  request_group varchar(64),
  manager varchar(64),
  assigned_group varchar(64),
  cust_list1 int,
  cust_list2 int,
  cust_text1 varchar(255),
  cust_text2 varchar(255),
  cust_notes clob,
  cust_int1 int,
  cust_int2 int,
  company int,
  company_backup int default 0,
  incidentTitle varchar(255),
  cust_date1 TIMESTAMP,
  cust_date2 TIMESTAMP,
  progress int,
  PRIMARY KEY  (id )
);

CREATE TABLE project_history (
  id int NOT NULL ,
  account_id varchar(32) NOT NULL,
  version int NOT NULL,
  category int,
  title varchar(255) ,
  description clob,
  status int ,
  notes clob,
  start_time TIMESTAMP,
  end_time TIMESTAMP,
  raw_estimation int,
  request_group varchar(64),
  manager varchar(64),
  assigned_group varchar(64),
  cust_list1 int,
  cust_list2 int,
  cust_text1 varchar(255),
  cust_text2 varchar(255),
  cust_notes clob,
  cust_int1 int,
  cust_int2 int,
  company int,
  company_backup int default 0,
  incidentTitle varchar(255),
  cust_date1 TIMESTAMP,
  cust_date2 TIMESTAMP,
  progress int,
  PRIMARY KEY  (id,version )
);

CREATE TABLE project_log (
  log_id int NOT NULL generated by default as identity,
  account_id varchar(32) NOT NULL ,
  project_id int NOT NULL ,
  log_time TIMESTAMP NOT NULL ,
  log_type varchar(64) NOT NULL ,
  log_description clob NOT NULL,
  ext_reference int NOT NULL,
  user_name varchar(64) NOT NULL,
  PRIMARY KEY  (log_id)
) ;

create table project_users (
  id int NOT NULL,
  account_id varchar(32) NOT NULL ,
  user_name varchar(64) NOT NULL,
  user_role int,
  PRIMARY KEY  (account_id,id,user_name )
);

create table project_files (
  id int NOT NULL,
  account_id varchar(32) NOT NULL ,
  file_id varchar(64) NOT NULL,
  file_name varchar(255),
  file_content blob ,
  file_date TIMESTAMP,
  real_file_name varchar(255),
  PRIMARY KEY  (account_id,id,file_id )
);

CREATE TABLE task (
  id int NOT NULL generated by default as identity,
  account_id varchar(32) NOT NULL,
  version int NOT NULL,
  project_id int,
  category int,
  title varchar(255) ,
  description clob,
  status int ,
  notes clob,
  progress int,
  start_time TIMESTAMP,
  end_time TIMESTAMP,
  estimation int,
  cust_list1 int,
  cust_list2 int,
  cust_text1 varchar(255),
  cust_text2 varchar(255),
  cust_notes clob,
  cust_int1 int,
  cust_int2 int,
  task_order int default 0,
  notification varchar(64),
  cust_date1 TIMESTAMP,
  cust_date2 TIMESTAMP,
  ci_id int,
  task_dependency int,
  task_dependency_type int,
  PRIMARY KEY  (id )
);

CREATE TABLE task_history (
  id int NOT NULL,
  account_id varchar(32) NOT NULL,
  version int NOT NULL,
  project_id int,
  category int,
  title varchar(255) ,
  description clob,
  status int ,
  notes clob,
  progress int,
  start_time TIMESTAMP,
  end_time TIMESTAMP,
  estimation int,
  cust_list1 int,
  cust_list2 int,
  cust_text1 varchar(255),
  cust_text2 varchar(255),
  cust_notes clob,
  cust_int1 int,
  cust_int2 int,
  task_order int default 0,
  notification varchar(64),
  cust_date1 TIMESTAMP,
  cust_date2 TIMESTAMP,
  ci_id int,
  task_dependency int,
  task_dependency_type int,
  PRIMARY KEY  (id,version )
);

CREATE TABLE task_log (
  log_id int NOT NULL generated by default as identity,
  account_id varchar(32) NOT NULL ,
  task_id int NOT NULL ,
  log_time TIMESTAMP NOT NULL ,
  log_type varchar(64) NOT NULL ,
  log_description clob NOT NULL,
  ext_reference int NOT NULL,
  user_name varchar(64) NOT NULL,
  PRIMARY KEY  (log_id)
) ;

create table task_users (
  id int NOT NULL,
  account_id varchar(32) NOT NULL ,
  user_name varchar(64) NOT NULL,
  user_role int,
  PRIMARY KEY  (account_id,id,user_name )
);

CREATE TABLE task_activities (
  id int NOT NULL generated by default as identity,
  task_id int ,
  account_id varchar(32) ,
  user_name varchar(64) ,
  from_time TIMESTAMP ,
  to_time TIMESTAMP ,
  description varchar(4000) ,
  activity_status int,
  ci_id int,
  PRIMARY KEY  (id)
);

create table task_files (
  id int NOT NULL,
  account_id varchar(32) NOT NULL ,
  file_id varchar(64) NOT NULL,
  file_name varchar(255),
  file_content blob ,
  file_date TIMESTAMP,
  real_file_name varchar(255),
  PRIMARY KEY  (account_id,id,file_id )
);

CREATE TABLE asset_types (
  account_id varchar(32) NOT NULL ,
  computer_type varchar(64) NOT NULL ,
  caption varchar(64) NOT NULL ,
  file_name varchar(255),
  default_file_name varchar(255),
  ci_sub_type_id int,
  PRIMARY KEY  (account_id,computer_type )
);

insert into asset_types values ('account','Laptop','Laptop','laptop_32.png','laptop_32.png',1 );
insert into asset_types values ('account','PDA','Smartphone','pda_32.png','pda_32.png',2 );
insert into asset_types values ('account','Printer','Printer','printer_32.png','printer.gif',3 );
insert into asset_types values ('account','Server','Server','server_32.png','server.gif',4 );
insert into asset_types values ('account','Workstation','Workstation','workstation_32.png','workstation.gif',5 );
insert into asset_types values ('account','Switch','Switch','switch_32.png','switch_32.png',6 );
insert into asset_types values ('account','Router','Router','router_32.png','router_32.png',7 );
insert into asset_types values ('account','DHCP Server','DHCP Server','dhcp_server_32.png','dhcp_server_32.png',8 );
insert into asset_types values ('account','Other SNMP Device','Other SNMP Device','snmp_device_32.png','snmp_device_32.png',9 );
insert into asset_types values ('account','Other','Other','other_32.png','other.gif',10 );
insert into asset_types values ('account','Tablet','Tablet','tablet_32.png','tablet_32.png',11 );

insert into commands (account_id,command) values ('account','Inventory');
insert into commands (account_id,command) values ('account','Upgrade');

CREATE TABLE company (
  company_id int NOT NULL generated by default as identity,
  account_id varchar(32) NOT NULL,
  company_name varchar(255) ,
  address varchar(255) ,
  address2 varchar(255) ,
  city varchar(64),
  state varchar(64),
  zip varchar(64),
  country varchar(64),
  phone varchar(64),
  fax varchar(64),
  notes clob,
  cust_list1 int,
  cust_list2 int,
  cust_text1 varchar(255),
  cust_text2 varchar(255),
  cust_notes clob,
  cust_int1 int,
  cust_int2 int,
  expiration_time TIMESTAMP,
  cust_date1 TIMESTAMP,
  cust_date2 TIMESTAMP,
  version int NOT NULL,
  agreement  int default 0,
  agreement_start TIMESTAMP,
  agreement_end TIMESTAMP,
  logo_file_name varchar(64),
  PRIMARY KEY  (company_id )
);

create index company_idx_1 on company (company_name);

create table monitor_templates (
  account_id varchar(32) NOT NULL,template_name varchar (64) NOT NULL,
  is_server char(1) NOT NULL,
  check_type varchar(32) NOT NULL,
  check_name varchar(200) NOT NULL,
  protocol varchar(64),
  port_num int,
  url_path varchar(255),
  expression varchar(255),
  update_type varchar(64),
  warning_at int,
  warning_notification varchar(64),
  error_at int,
  error_notification varchar(64),
  PRIMARY KEY  (account_id,template_name,check_type,check_name,is_server));

create table monitoring_conf(
  account_id varchar(32) NOT NULL ,
  computer_id varchar(64) NOT NULL,
  is_server char(1) NOT NULL,
  template_name varchar(64) default '',
  notification varchar(64),
  alert int default 0,
  sr_sent int,
  mail_sent int,
  sms_sent int,
  monitoring_enabled char(1) default '1',
  PRIMARY KEY  (account_id,computer_id));

create table monitor_embed_data(
  account_id varchar(32) NOT NULL,
  computer_id varchar (64) NOT NULL,
  is_server char(1) NOT NULL,
  check_type varchar(32) NOT NULL,
  check_name varchar(200) NOT NULL,
  protocol varchar(64),
  port_num int,
  url_path varchar(255),
  expression varchar(255),
  update_type varchar(64),
  warning_at int,
  warning_notification varchar(64),
  error_at int,
  error_notification varchar(64),
  idx_day int,
  idx_week int,
  idx_month int,
  idx_year int,
  time_day timestamp,
  time_week timestamp,
  time_month timestamp,
  time_year timestamp,
  warn_sr_sent int,
  warn_mail_sent int,
  warn_sms_sent int,
  err_sr_sent int ,
  err_mail_sent int ,
  err_sms_sent int ,
  alert int default 0,
  extra_data varchar(255),
  predefined_check int,
  PRIMARY KEY  (account_id,computer_id,check_type,check_name));

create index monitor_embed_data_idx1 on monitor_embed_data(computer_id,check_type,check_name);

create table services_day_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(64) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table services_week_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(64) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table services_month_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(64) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table services_year_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(64) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table processes_day_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(64) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table processes_week_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(64) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table processes_month_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(64) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table processes_year_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(64) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table performance_day_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(64) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table performance_week_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(64) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table performance_month_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(64) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table performance_year_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(64) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table comp_update_day_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(64) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table comp_update_week_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(64) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table comp_update_month_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(64) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table comp_update_year_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(64) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table network_day_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(200) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table network_week_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(200) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table network_month_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(200) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table network_year_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(200) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table asset_data_day_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(200) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table asset_data_week_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(200) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table asset_data_month_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(200) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table asset_data_year_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(200) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table network_activity_day_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(255) NOT NULL,
  idx int NOT NULL,
  check_value_1 float,
  check_value_2 float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table network_activity_week_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(255) NOT NULL,
  idx int NOT NULL,
  check_value_1 float,
  check_value_2 float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table network_activity_month_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(255) NOT NULL,
  idx int NOT NULL,
  check_value_1 float,
  check_value_2 float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table network_activity_year_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(255) NOT NULL,
  idx int NOT NULL,
  check_value_1 float,
  check_value_2 float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table customized_day_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(255) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table customized_week_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(255) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table customized_month_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(255) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table customized_year_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(255) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table url_day_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(200) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table url_week_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(200) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table url_month_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(200) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table url_year_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  check_name varchar(200) NOT NULL,
  idx int NOT NULL,
  check_value float,
  upd_time timestamp,
  PRIMARY KEY(account_id,computer_id,check_name,idx));

create table url_embed_data(
  check_name varchar(200) NOT NULL,
  url_path varchar(255),
  expression varchar(255),
  retries int,
  error_at int,
  error_notification varchar(64),
  idx_day int,
  idx_week int,
  idx_month int,
  idx_year int,
  time_day timestamp,
  time_week timestamp,
  time_month timestamp,
  time_year timestamp,
  err_sr_sent int ,
  err_mail_sent int ,
  err_sms_sent int ,
  alert int default 0,
  extra_data varchar(255),
  PRIMARY KEY (check_name));

create table monitor_events (
  id int NOT NULL generated by default as identity,
  severity int NOT NULL,
  source varchar(255),
  source_name varchar(255),
  monitor_type varchar(64),
  monitor_target varchar(255),
  port_num int,
  url_path varchar(255),
  category varchar(64),
  upd_time timestamp,
  check_value float,
  expression varchar(255),
  warning_threshold int,
  warning_notification varchar(64),
  error_threshold int,
  error_notification varchar(64),
  check_value1 float,
  check_value2 float,
  port_name varchar(64),
  PRIMARY KEY (id));

create index monitor_events_idx1 on monitor_events(upd_time desc);
create index monitor_events_idx2 on monitor_events(source,monitor_type);

create table predefined_services_check (
  id int NOT NULL generated by default as identity,
  name varchar(64),
  display_name varchar(64),
  notification varchar(64),
  is_monitor int,
  PRIMARY KEY (id));

INSERT INTO predefined_services_check (id,name,display_name) VALUES (1,'DHCPServer','DHCP Server');
INSERT INTO predefined_services_check (id,name,display_name) VALUES (2,'DNS','DNS Server');
INSERT INTO predefined_services_check (id,name,display_name) VALUES (3,'dmserver','Disk Manager');
INSERT INTO predefined_services_check (id,name,display_name) VALUES (4,'Eventlog','Event Log');
INSERT INTO predefined_services_check (id,name,display_name) VALUES (5,'NtFrs','File Replication Service');
INSERT INTO predefined_services_check (id,name,display_name) VALUES (6,'msftpsvc','FTP');
INSERT INTO predefined_services_check (id,name,display_name) VALUES (7,'IAS','IAS');
INSERT INTO predefined_services_check (id,name,display_name) VALUES (8,'IISADMIN','IIS');
INSERT INTO predefined_services_check (id,name,display_name) VALUES (9,'Messenger','Messenger');
INSERT INTO predefined_services_check (id,name,display_name) VALUES (10,'MySql','MySQL');
INSERT INTO predefined_services_check (id,name,display_name) VALUES (11,'Netlogon','Net Logon');
INSERT INTO predefined_services_check (id,name,display_name) VALUES (12,'Spooler','Print Spooler');
INSERT INTO predefined_services_check (id,name,display_name) VALUES (13,'RpcSs','RPC');
INSERT INTO predefined_services_check (id,name,display_name) VALUES (14,'SMTPSVC','SMTP');
INSERT INTO predefined_services_check (id,name,display_name) VALUES (15,'TapiSrv','Telephony');
INSERT INTO predefined_services_check (id,name,display_name) VALUES (16,'TlntSrv','Telnet');

alter table predefined_services_check alter column id restart with 100;


create table predefined_network_check (
  id int NOT NULL generated by default as identity,
  name varchar(64),
  port int,
  notification varchar(64),
  is_monitor int,
  PRIMARY KEY (id));

INSERT INTO predefined_network_check (id,name,port) VALUES (1,'Ping',null);
INSERT INTO predefined_network_check (id,name,port) VALUES (2,'DNS',53);
INSERT INTO predefined_network_check (id,name,port) VALUES (3,'FTP',21);
INSERT INTO predefined_network_check (id,name,port) VALUES (4,'HTTP',80);
INSERT INTO predefined_network_check (id,name,port) VALUES (5,'HTTPS',443);
INSERT INTO predefined_network_check (id,name,port) VALUES (6,'IMAP',143);
INSERT INTO predefined_network_check (id,name,port) VALUES (7,'Kerberos',88);
INSERT INTO predefined_network_check (id,name,port) VALUES (8,'LDAP',389);
INSERT INTO predefined_network_check (id,name,port) VALUES (9,'MSSQL',1433);
INSERT INTO predefined_network_check (id,name,port) VALUES (10,'MYSQL',3306);
INSERT INTO predefined_network_check (id,name,port) VALUES (11,'Oracle',1521);
INSERT INTO predefined_network_check (id,name,port) VALUES (12,'POP',110);
INSERT INTO predefined_network_check (id,name,port) VALUES (13,'RPC',135);
INSERT INTO predefined_network_check (id,name,port) VALUES (14,'SMTP',25);
INSERT INTO predefined_network_check (id,name,port) VALUES (15,'SSH',22);
INSERT INTO predefined_network_check (id,name,port) VALUES (16,'Telnet',23);
INSERT INTO predefined_network_check (id,name,port) VALUES (17,'VNC',5900);
INSERT INTO predefined_network_check (id,name,port) VALUES (18,'WebLogic',7001);
alter table predefined_network_check alter column id restart with 100;


create index COMPUTER_LISTS_IDX1 on computer_lists(account_id,computer_id,list_type);

CREATE FUNCTION DATEDIFF(FromDate Timestamp,ToDate Timestamp) RETURNS BIGINT
PARAMETER STYLE JAVA NO SQL LANGUAGE JAVA
EXTERNAL NAME 'com.ilient.server.Helper.sqlDateDiff';

CREATE FUNCTION ROUND(param1 double) RETURNS double
PARAMETER STYLE JAVA NO SQL LANGUAGE JAVA
EXTERNAL NAME 'com.ilient.server.Helper.sqlRound'
RETURNS NULL ON NULL INPUT;

CREATE TABLE news (
  news_id int NOT NULL generated by default as identity,
  account_id varchar(32) NOT NULL ,
  present char(1),
  title varchar(255),
  description clob,
  administrator char(1),
  urgency char(1),
  insert_time TIMESTAMP,
  company int default 0,
  company_backup int default 0,
  assigned_group varchar(64) default '0',
  PRIMARY KEY  (news_id) );

CREATE TABLE satisfaction_survey (
	account_id    	varchar(32) NOT NULL,
	sr_id         	int NOT NULL,
	answer        	int,
	comments      	VARCHAR(255),
	update_time   	TIMESTAMP,
	responsibility	varchar(64),
	question_id int default 1 NOT NULL,
    PRIMARY KEY (account_id, sr_id,question_id) );

create index COMPUTER_LISTS_IDX2  on computer_lists (value asc);

create table computer_files (
  id varchar(64) NOT NULL,
  account_id varchar(32) NOT NULL ,
  file_id varchar(64) NOT NULL,
  file_name varchar(255),
  file_date  TIMESTAMP,
  file_content blob (100M),
  real_file_name varchar(255),
  PRIMARY KEY  (account_id,id,file_id )
);

create table software_files (
  id int NOT NULL,
  account_id varchar(32) NOT NULL ,
  file_id varchar(64) NOT NULL,
  file_name varchar(255),
  file_date  TIMESTAMP,
  file_content blob (100M),
  real_file_name varchar(255),
  PRIMARY KEY  (account_id,id,file_id )
);

create table computer_links (
  id varchar(64) NOT NULL,
  account_id varchar(32) NOT NULL ,
  file_id varchar(64) NOT NULL,
  link varchar(255) NOT NULL,
  file_name varchar(255),
  file_date  TIMESTAMP,
  PRIMARY KEY  (account_id,id,file_id )
);

create table sysaid_user_routing (
  account_id varchar(32) NOT NULL ,
  user_name varchar(64) NOT NULL,
  take_over_user varchar(64) NOT NULL ,
  PRIMARY KEY  (account_id,user_name )
);


CREATE TABLE ci_attributes (
  id int NOT NULL generated by default as identity,
  account_id varchar(32) NOT NULL ,
  ci_name varchar(64) NOT NULL ,
  serial varchar(64) ,
  ci_type int ,
  location int ,
  owner varchar(64) ,
  owner_group varchar(64) ,
  company int ,
  company_backup int default 0,
  supplier int ,
  supply_date TIMESTAMP ,
  accept_date TIMESTAMP ,
  status int ,
  priority int ,
  notes clob,
  import_item_id varchar(64) ,
  import_item_type int,
  history_version int NOT NULL ,
  ci_cust_text_1 varchar(64) ,
  ci_cust_text_2 varchar(64) ,
  ci_cust_text_3 varchar(64) ,
  ci_cust_text_4 varchar(64) ,
  ci_cust_text_5 varchar(64) ,
  ci_cust_text_6 varchar(64) ,
  ci_cust_text_7 varchar(64) ,
  ci_cust_text_8 varchar(64) ,
  ci_cust_text_9 varchar(64) ,
  ci_cust_text_10 varchar(64) ,
  ci_cust_text_11 varchar(64) ,
  ci_cust_text_12 varchar(64) ,
  ci_cust_text_13 varchar(64) ,
  ci_cust_text_14 varchar(64) ,
  ci_cust_text_15 varchar(64) ,
  ci_cust_text_16 varchar(64) ,
  ci_cust_text_17 varchar(64) ,
  ci_cust_text_18 varchar(64) ,
  ci_cust_text_19 varchar(64) ,
  ci_cust_text_20 varchar(64) ,
  ci_cust_text_21 varchar(64) ,
  ci_cust_text_22 varchar(64) ,
  ci_cust_text_23 varchar(64) ,
  ci_cust_text_24 varchar(64) ,
  ci_cust_text_25 varchar(64) ,
  ci_cust_text_26 varchar(64) ,
  ci_cust_text_27 varchar(64) ,
  ci_cust_text_28 varchar(64) ,
  ci_cust_text_29 varchar(64) ,
  ci_cust_text_30 varchar(64) ,
  ci_cust_text_31 varchar(64) ,
  ci_cust_text_32 varchar(64) ,
  ci_cust_text_33 varchar(64) ,
  ci_cust_text_34 varchar(64) ,
  ci_cust_text_35 varchar(64) ,
  ci_cust_text_36 varchar(64) ,
  ci_cust_text_37 varchar(64) ,
  ci_cust_text_38 varchar(64) ,
  ci_cust_text_39 varchar(64) ,
  ci_cust_text_40 varchar(64) ,
  ci_cust_text_41 varchar(64) ,
  ci_cust_text_42 varchar(64) ,
  ci_cust_text_43 varchar(64) ,
  ci_cust_text_44 varchar(64) ,
  ci_cust_text_45 varchar(64) ,
  ci_cust_text_46 varchar(64) ,
  ci_cust_text_47 varchar(64) ,
  ci_cust_text_48 varchar(64) ,
  ci_cust_text_49 varchar(64) ,
  ci_cust_text_50 varchar(64) ,
  ci_cust_long_text_1 clob ,
  ci_cust_long_text_2 clob ,
  ci_cust_long_text_3 clob ,
  ci_cust_long_text_4 clob ,
  ci_cust_long_text_5 clob ,
  ci_cust_long_text_6 clob ,
  ci_cust_long_text_7 clob ,
  ci_cust_long_text_8 clob ,
  ci_cust_long_text_9 clob ,
  ci_cust_long_text_10 clob ,
  ci_cust_long_text_11 clob ,
  ci_cust_long_text_12 clob ,
  ci_cust_long_text_13 clob ,
  ci_cust_long_text_14 clob ,
  ci_cust_long_text_15 clob ,
  ci_cust_long_text_16 clob ,
  ci_cust_long_text_17 clob ,
  ci_cust_long_text_18 clob ,
  ci_cust_long_text_19 clob ,
  ci_cust_long_text_20 clob ,
  ci_cust_long_text_21 clob ,
  ci_cust_long_text_22 clob ,
  ci_cust_long_text_23 clob ,
  ci_cust_long_text_24 clob ,
  ci_cust_long_text_25 clob ,
  ci_cust_long_text_26 clob ,
  ci_cust_long_text_27 clob ,
  ci_cust_long_text_28 clob ,
  ci_cust_long_text_29 clob ,
  ci_cust_long_text_30 clob ,
  ci_cust_long_text_31 clob ,
  ci_cust_long_text_32 clob ,
  ci_cust_long_text_33 clob ,
  ci_cust_long_text_34 clob ,
  ci_cust_long_text_35 clob ,
  ci_cust_long_text_36 clob ,
  ci_cust_long_text_37 clob ,
  ci_cust_long_text_38 clob ,
  ci_cust_long_text_39 clob ,
  ci_cust_long_text_40 clob ,
  ci_cust_long_text_41 clob ,
  ci_cust_long_text_42 clob ,
  ci_cust_long_text_43 clob ,
  ci_cust_long_text_44 clob ,
  ci_cust_long_text_45 clob ,
  ci_cust_long_text_46 clob ,
  ci_cust_long_text_47 clob ,
  ci_cust_long_text_48 clob ,
  ci_cust_long_text_49 clob ,
  ci_cust_long_text_50 clob ,
  ci_cust_date_1 TIMESTAMP ,
  ci_cust_date_2 TIMESTAMP ,
  ci_cust_date_3 TIMESTAMP ,
  ci_cust_date_4 TIMESTAMP ,
  ci_cust_date_5 TIMESTAMP ,
  ci_cust_date_6 TIMESTAMP ,
  ci_cust_date_7 TIMESTAMP ,
  ci_cust_date_8 TIMESTAMP ,
  ci_cust_date_9 TIMESTAMP ,
  ci_cust_date_10 TIMESTAMP ,
  ci_cust_date_11 TIMESTAMP ,
  ci_cust_date_12 TIMESTAMP ,
  ci_cust_date_13 TIMESTAMP ,
  ci_cust_date_14 TIMESTAMP ,
  ci_cust_date_15 TIMESTAMP ,
  ci_cust_date_16 TIMESTAMP ,
  ci_cust_date_17 TIMESTAMP ,
  ci_cust_date_18 TIMESTAMP ,
  ci_cust_date_19 TIMESTAMP ,
  ci_cust_date_20 TIMESTAMP ,
  ci_cust_date_21 TIMESTAMP ,
  ci_cust_date_22 TIMESTAMP ,
  ci_cust_date_23 TIMESTAMP ,
  ci_cust_date_24 TIMESTAMP ,
  ci_cust_date_25 TIMESTAMP ,
  ci_cust_date_26 TIMESTAMP ,
  ci_cust_date_27 TIMESTAMP ,
  ci_cust_date_28 TIMESTAMP ,
  ci_cust_date_29 TIMESTAMP ,
  ci_cust_date_30 TIMESTAMP ,
  ci_cust_date_31 TIMESTAMP ,
  ci_cust_date_32 TIMESTAMP ,
  ci_cust_date_33 TIMESTAMP ,
  ci_cust_date_34 TIMESTAMP ,
  ci_cust_date_35 TIMESTAMP ,
  ci_cust_date_36 TIMESTAMP ,
  ci_cust_date_37 TIMESTAMP ,
  ci_cust_date_38 TIMESTAMP ,
  ci_cust_date_39 TIMESTAMP ,
  ci_cust_date_40 TIMESTAMP ,
  ci_cust_date_41 TIMESTAMP ,
  ci_cust_date_42 TIMESTAMP ,
  ci_cust_date_43 TIMESTAMP ,
  ci_cust_date_44 TIMESTAMP ,
  ci_cust_date_45 TIMESTAMP ,
  ci_cust_date_46 TIMESTAMP ,
  ci_cust_date_47 TIMESTAMP ,
  ci_cust_date_48 TIMESTAMP ,
  ci_cust_date_49 TIMESTAMP ,
  ci_cust_date_50 TIMESTAMP ,
  ci_cust_list_1 int ,
  ci_cust_list_2 int ,
  ci_cust_list_3 int ,
  ci_cust_list_4 int ,
  ci_cust_list_5 int ,
  ci_cust_list_6 int ,
  ci_cust_list_7 int ,
  ci_cust_list_8 int ,
  ci_cust_list_9 int ,
  ci_cust_list_10 int ,
  ci_cust_list_11 int ,
  ci_cust_list_12 int ,
  ci_cust_list_13 int ,
  ci_cust_list_14 int ,
  ci_cust_list_15 int ,
  ci_cust_list_16 int ,
  ci_cust_list_17 int ,
  ci_cust_list_18 int ,
  ci_cust_list_19 int ,
  ci_cust_list_20 int ,
  ci_cust_list_21 int ,
  ci_cust_list_22 int ,
  ci_cust_list_23 int ,
  ci_cust_list_24 int ,
  ci_cust_list_25 int ,
  ci_cust_list_26 int ,
  ci_cust_list_27 int ,
  ci_cust_list_28 int ,
  ci_cust_list_29 int ,
  ci_cust_list_30 int ,
  ci_cust_list_31 int ,
  ci_cust_list_32 int ,
  ci_cust_list_33 int ,
  ci_cust_list_34 int ,
  ci_cust_list_35 int ,
  ci_cust_list_36 int ,
  ci_cust_list_37 int ,
  ci_cust_list_38 int ,
  ci_cust_list_39 int ,
  ci_cust_list_40 int ,
  ci_cust_list_41 int ,
  ci_cust_list_42 int ,
  ci_cust_list_43 int ,
  ci_cust_list_44 int ,
  ci_cust_list_45 int ,
  ci_cust_list_46 int ,
  ci_cust_list_47 int ,
  ci_cust_list_48 int ,
  ci_cust_list_49 int ,
  ci_cust_list_50 int ,
  ci_cust_int_1 int ,
  ci_cust_int_2 int ,
  ci_cust_int_3 int ,
  ci_cust_int_4 int ,
  ci_cust_int_5 int ,
  ci_cust_int_6 int ,
  ci_cust_int_7 int ,
  ci_cust_int_8 int ,
  ci_cust_int_9 int ,
  ci_cust_int_10 int ,
  ci_cust_int_11 int ,
  ci_cust_int_12 int ,
  ci_cust_int_13 int ,
  ci_cust_int_14 int ,
  ci_cust_int_15 int ,
  ci_cust_int_16 int ,
  ci_cust_int_17 int ,
  ci_cust_int_18 int ,
  ci_cust_int_19 int ,
  ci_cust_int_20 int ,
  ci_cust_int_21 int ,
  ci_cust_int_22 int ,
  ci_cust_int_23 int ,
  ci_cust_int_24 int ,
  ci_cust_int_25 int ,
  ci_cust_int_26 int ,
  ci_cust_int_27 int ,
  ci_cust_int_28 int ,
  ci_cust_int_29 int ,
  ci_cust_int_30 int ,
  ci_cust_int_31 int ,
  ci_cust_int_32 int ,
  ci_cust_int_33 int ,
  ci_cust_int_34 int ,
  ci_cust_int_35 int ,
  ci_cust_int_36 int ,
  ci_cust_int_37 int ,
  ci_cust_int_38 int ,
  ci_cust_int_39 int ,
  ci_cust_int_40 int ,
  ci_cust_int_41 int ,
  ci_cust_int_42 int ,
  ci_cust_int_43 int ,
  ci_cust_int_44 int ,
  ci_cust_int_45 int ,
  ci_cust_int_46 int ,
  ci_cust_int_47 int ,
  ci_cust_int_48 int ,
  ci_cust_int_49 int ,
  ci_cust_int_50 int ,
  problem_type varchar(64) ,
  problem_sub_type varchar(64) ,
  third_level_category varchar(64),
  ci_sub_type int default 0,
  PRIMARY KEY  (id)
) ;


CREATE TABLE ci_history (
  id int NOT NULL ,
  account_id varchar(32) NOT NULL ,
  ci_name varchar(64) NOT NULL ,
  serial varchar(64) ,
  ci_type int ,
  location int ,
  owner varchar(64) ,
  owner_group varchar(64) ,
  company int ,
  company_backup int default 0,
  supplier int ,
  supply_date TIMESTAMP ,
  accept_date TIMESTAMP ,
  status int ,
  priority int ,
  notes clob,
  import_desc varchar(255) ,
  history_version int NOT NULL ,
  ci_cust_text_1 varchar(64) ,
  ci_cust_text_2 varchar(64) ,
  ci_cust_text_3 varchar(64) ,
  ci_cust_text_4 varchar(64) ,
  ci_cust_text_5 varchar(64) ,
  ci_cust_text_6 varchar(64) ,
  ci_cust_text_7 varchar(64) ,
  ci_cust_text_8 varchar(64) ,
  ci_cust_text_9 varchar(64) ,
  ci_cust_text_10 varchar(64) ,
  ci_cust_text_11 varchar(64) ,
  ci_cust_text_12 varchar(64) ,
  ci_cust_text_13 varchar(64) ,
  ci_cust_text_14 varchar(64) ,
  ci_cust_text_15 varchar(64) ,
  ci_cust_text_16 varchar(64) ,
  ci_cust_text_17 varchar(64) ,
  ci_cust_text_18 varchar(64) ,
  ci_cust_text_19 varchar(64) ,
  ci_cust_text_20 varchar(64) ,
  ci_cust_text_21 varchar(64) ,
  ci_cust_text_22 varchar(64) ,
  ci_cust_text_23 varchar(64) ,
  ci_cust_text_24 varchar(64) ,
  ci_cust_text_25 varchar(64) ,
  ci_cust_text_26 varchar(64) ,
  ci_cust_text_27 varchar(64) ,
  ci_cust_text_28 varchar(64) ,
  ci_cust_text_29 varchar(64) ,
  ci_cust_text_30 varchar(64) ,
  ci_cust_text_31 varchar(64) ,
  ci_cust_text_32 varchar(64) ,
  ci_cust_text_33 varchar(64) ,
  ci_cust_text_34 varchar(64) ,
  ci_cust_text_35 varchar(64) ,
  ci_cust_text_36 varchar(64) ,
  ci_cust_text_37 varchar(64) ,
  ci_cust_text_38 varchar(64) ,
  ci_cust_text_39 varchar(64) ,
  ci_cust_text_40 varchar(64) ,
  ci_cust_text_41 varchar(64) ,
  ci_cust_text_42 varchar(64) ,
  ci_cust_text_43 varchar(64) ,
  ci_cust_text_44 varchar(64) ,
  ci_cust_text_45 varchar(64) ,
  ci_cust_text_46 varchar(64) ,
  ci_cust_text_47 varchar(64) ,
  ci_cust_text_48 varchar(64) ,
  ci_cust_text_49 varchar(64) ,
  ci_cust_text_50 varchar(64) ,
  ci_cust_long_text_1 clob ,
  ci_cust_long_text_2 clob ,
  ci_cust_long_text_3 clob ,
  ci_cust_long_text_4 clob ,
  ci_cust_long_text_5 clob ,
  ci_cust_long_text_6 clob ,
  ci_cust_long_text_7 clob ,
  ci_cust_long_text_8 clob ,
  ci_cust_long_text_9 clob ,
  ci_cust_long_text_10 clob ,
  ci_cust_long_text_11 clob ,
  ci_cust_long_text_12 clob ,
  ci_cust_long_text_13 clob ,
  ci_cust_long_text_14 clob ,
  ci_cust_long_text_15 clob ,
  ci_cust_long_text_16 clob ,
  ci_cust_long_text_17 clob ,
  ci_cust_long_text_18 clob ,
  ci_cust_long_text_19 clob ,
  ci_cust_long_text_20 clob ,
  ci_cust_long_text_21 clob ,
  ci_cust_long_text_22 clob ,
  ci_cust_long_text_23 clob ,
  ci_cust_long_text_24 clob ,
  ci_cust_long_text_25 clob ,
  ci_cust_long_text_26 clob ,
  ci_cust_long_text_27 clob ,
  ci_cust_long_text_28 clob ,
  ci_cust_long_text_29 clob ,
  ci_cust_long_text_30 clob ,
  ci_cust_long_text_31 clob ,
  ci_cust_long_text_32 clob ,
  ci_cust_long_text_33 clob ,
  ci_cust_long_text_34 clob ,
  ci_cust_long_text_35 clob ,
  ci_cust_long_text_36 clob ,
  ci_cust_long_text_37 clob ,
  ci_cust_long_text_38 clob ,
  ci_cust_long_text_39 clob ,
  ci_cust_long_text_40 clob ,
  ci_cust_long_text_41 clob ,
  ci_cust_long_text_42 clob ,
  ci_cust_long_text_43 clob ,
  ci_cust_long_text_44 clob ,
  ci_cust_long_text_45 clob ,
  ci_cust_long_text_46 clob ,
  ci_cust_long_text_47 clob ,
  ci_cust_long_text_48 clob ,
  ci_cust_long_text_49 clob ,
  ci_cust_long_text_50 clob ,
  ci_cust_date_1 TIMESTAMP ,
  ci_cust_date_2 TIMESTAMP ,
  ci_cust_date_3 TIMESTAMP ,
  ci_cust_date_4 TIMESTAMP ,
  ci_cust_date_5 TIMESTAMP ,
  ci_cust_date_6 TIMESTAMP ,
  ci_cust_date_7 TIMESTAMP ,
  ci_cust_date_8 TIMESTAMP ,
  ci_cust_date_9 TIMESTAMP ,
  ci_cust_date_10 TIMESTAMP ,
  ci_cust_date_11 TIMESTAMP ,
  ci_cust_date_12 TIMESTAMP ,
  ci_cust_date_13 TIMESTAMP ,
  ci_cust_date_14 TIMESTAMP ,
  ci_cust_date_15 TIMESTAMP ,
  ci_cust_date_16 TIMESTAMP ,
  ci_cust_date_17 TIMESTAMP ,
  ci_cust_date_18 TIMESTAMP ,
  ci_cust_date_19 TIMESTAMP ,
  ci_cust_date_20 TIMESTAMP ,
  ci_cust_date_21 TIMESTAMP ,
  ci_cust_date_22 TIMESTAMP ,
  ci_cust_date_23 TIMESTAMP ,
  ci_cust_date_24 TIMESTAMP ,
  ci_cust_date_25 TIMESTAMP ,
  ci_cust_date_26 TIMESTAMP ,
  ci_cust_date_27 TIMESTAMP ,
  ci_cust_date_28 TIMESTAMP ,
  ci_cust_date_29 TIMESTAMP ,
  ci_cust_date_30 TIMESTAMP ,
  ci_cust_date_31 TIMESTAMP ,
  ci_cust_date_32 TIMESTAMP ,
  ci_cust_date_33 TIMESTAMP ,
  ci_cust_date_34 TIMESTAMP ,
  ci_cust_date_35 TIMESTAMP ,
  ci_cust_date_36 TIMESTAMP ,
  ci_cust_date_37 TIMESTAMP ,
  ci_cust_date_38 TIMESTAMP ,
  ci_cust_date_39 TIMESTAMP ,
  ci_cust_date_40 TIMESTAMP ,
  ci_cust_date_41 TIMESTAMP ,
  ci_cust_date_42 TIMESTAMP ,
  ci_cust_date_43 TIMESTAMP ,
  ci_cust_date_44 TIMESTAMP ,
  ci_cust_date_45 TIMESTAMP ,
  ci_cust_date_46 TIMESTAMP ,
  ci_cust_date_47 TIMESTAMP ,
  ci_cust_date_48 TIMESTAMP ,
  ci_cust_date_49 TIMESTAMP ,
  ci_cust_date_50 TIMESTAMP ,
  ci_cust_list_1 int ,
  ci_cust_list_2 int ,
  ci_cust_list_3 int ,
  ci_cust_list_4 int ,
  ci_cust_list_5 int ,
  ci_cust_list_6 int ,
  ci_cust_list_7 int ,
  ci_cust_list_8 int ,
  ci_cust_list_9 int ,
  ci_cust_list_10 int ,
  ci_cust_list_11 int ,
  ci_cust_list_12 int ,
  ci_cust_list_13 int ,
  ci_cust_list_14 int ,
  ci_cust_list_15 int ,
  ci_cust_list_16 int ,
  ci_cust_list_17 int ,
  ci_cust_list_18 int ,
  ci_cust_list_19 int ,
  ci_cust_list_20 int ,
  ci_cust_list_21 int ,
  ci_cust_list_22 int ,
  ci_cust_list_23 int ,
  ci_cust_list_24 int ,
  ci_cust_list_25 int ,
  ci_cust_list_26 int ,
  ci_cust_list_27 int ,
  ci_cust_list_28 int ,
  ci_cust_list_29 int ,
  ci_cust_list_30 int ,
  ci_cust_list_31 int ,
  ci_cust_list_32 int ,
  ci_cust_list_33 int ,
  ci_cust_list_34 int ,
  ci_cust_list_35 int ,
  ci_cust_list_36 int ,
  ci_cust_list_37 int ,
  ci_cust_list_38 int ,
  ci_cust_list_39 int ,
  ci_cust_list_40 int ,
  ci_cust_list_41 int ,
  ci_cust_list_42 int ,
  ci_cust_list_43 int ,
  ci_cust_list_44 int ,
  ci_cust_list_45 int ,
  ci_cust_list_46 int ,
  ci_cust_list_47 int ,
  ci_cust_list_48 int ,
  ci_cust_list_49 int ,
  ci_cust_list_50 int ,
  ci_cust_int_1 int ,
  ci_cust_int_2 int ,
  ci_cust_int_3 int ,
  ci_cust_int_4 int ,
  ci_cust_int_5 int ,
  ci_cust_int_6 int ,
  ci_cust_int_7 int ,
  ci_cust_int_8 int ,
  ci_cust_int_9 int ,
  ci_cust_int_10 int ,
  ci_cust_int_11 int ,
  ci_cust_int_12 int ,
  ci_cust_int_13 int ,
  ci_cust_int_14 int ,
  ci_cust_int_15 int ,
  ci_cust_int_16 int ,
  ci_cust_int_17 int ,
  ci_cust_int_18 int ,
  ci_cust_int_19 int ,
  ci_cust_int_20 int ,
  ci_cust_int_21 int ,
  ci_cust_int_22 int ,
  ci_cust_int_23 int ,
  ci_cust_int_24 int ,
  ci_cust_int_25 int ,
  ci_cust_int_26 int ,
  ci_cust_int_27 int ,
  ci_cust_int_28 int ,
  ci_cust_int_29 int ,
  ci_cust_int_30 int ,
  ci_cust_int_31 int ,
  ci_cust_int_32 int ,
  ci_cust_int_33 int ,
  ci_cust_int_34 int ,
  ci_cust_int_35 int ,
  ci_cust_int_36 int ,
  ci_cust_int_37 int ,
  ci_cust_int_38 int ,
  ci_cust_int_39 int ,
  ci_cust_int_40 int ,
  ci_cust_int_41 int ,
  ci_cust_int_42 int ,
  ci_cust_int_43 int ,
  ci_cust_int_44 int ,
  ci_cust_int_45 int ,
  ci_cust_int_46 int ,
  ci_cust_int_47 int ,
  ci_cust_int_48 int ,
  ci_cust_int_49 int ,
  ci_cust_int_50 int ,
  relation_changes clob,
  change_time TIMESTAMP,
  changed_by varchar(64),
  problem_type varchar(64) ,
  problem_sub_type varchar(64) ,
  third_level_category varchar(64),
  ci_sub_type int default 0,
  PRIMARY KEY  (id,history_version)
) ;

CREATE TABLE ci_type (
  id int NOT NULL generated by default as identity,
  account_id varchar(32) NOT NULL ,
  ci_type_name varchar(64) NOT NULL ,
  description clob,
  predefined varchar(1),
  PRIMARY KEY  (id)
) ;
alter table ci_type alter column id restart with 100;

INSERT INTO ci_type (id,account_id,ci_type_name,description,predefined) VALUES (1,'account','Asset','System Asset (Workstation,Server,Laptop,Printer,PDA,Other)','1');
INSERT INTO ci_type (id,account_id,ci_type_name,description,predefined) VALUES (2,'account','Software Product','','1');
INSERT INTO ci_type (id,account_id,ci_type_name,description,predefined) VALUES (3,'account','Catalog','System Asset Catalog','1');
INSERT INTO ci_type (id,account_id,ci_type_name,description,predefined) VALUES (4,'account','System Software','','0');
INSERT INTO ci_type (id,account_id,ci_type_name,description,predefined) VALUES (5,'account','Network Component','','0');
INSERT INTO ci_type (id,account_id,ci_type_name,description,predefined) VALUES (6,'account','Business Process','','0');
INSERT INTO ci_type (id,account_id,ci_type_name,description,predefined) VALUES (7,'account','Application','','0');
INSERT INTO ci_type (id,account_id,ci_type_name,description,predefined) VALUES (8,'account','Physical Database','','0');

CREATE TABLE ci_sub_type (
  id int NOT NULL generated by default as identity,
  account_id varchar(32) NOT NULL ,
  ci_type_id int NOT NULL ,
  caption varchar(64) NOT NULL ,
  file_name varchar(255),
  PRIMARY KEY (id)
);
alter table ci_sub_type alter column id restart with 100;

insert into ci_sub_type (id,account_id,ci_type_id,caption,file_name) values (1,'account',1,'Laptop','laptop_32.png');
insert into ci_sub_type (id,account_id,ci_type_id,caption,file_name) values (2,'account',1,'Smartphone','pda_32.png');
insert into ci_sub_type (id,account_id,ci_type_id,caption,file_name) values (3,'account',1,'Printer','printer_32.png');
insert into ci_sub_type (id,account_id,ci_type_id,caption,file_name) values (4,'account',1,'Server','server_32.png');
insert into ci_sub_type (id,account_id,ci_type_id,caption,file_name) values (5,'account',1,'Workstation','workstation_32.png');
insert into ci_sub_type (id,account_id,ci_type_id,caption,file_name) values (6,'account',1,'Switch','switch_32.png');
insert into ci_sub_type (id,account_id,ci_type_id,caption,file_name) values (7,'account',1,'Router','router_32.png');
insert into ci_sub_type (id,account_id,ci_type_id,caption,file_name) values (8,'account',1,'DHCP Server','dhcp_server_32.png');
insert into ci_sub_type (id,account_id,ci_type_id,caption,file_name) values (9,'account',1,'Other SNMP Device','snmp_device_32.png');
insert into ci_sub_type (id,account_id,ci_type_id,caption,file_name) values (10,'account',1,'Other','other_32.png');
insert into ci_sub_type (id,account_id,ci_type_id,caption,file_name) values (11,'account',1,'Tablet','tablet_32.png');

CREATE TABLE ci_relation (
  src int NOT NULL,
  dest int NOT NULL,
  ci_relation_type int NOT NULL,
  PRIMARY KEY  (src, dest, ci_relation_type)
) ;

CREATE TABLE ci_relation_type (
  id int NOT NULL generated by default as identity,
  account_id varchar(32) NOT NULL ,
  relation_name varchar(64) NOT NULL ,
  opposite_relation_name varchar(64),
  predefined varchar(1),
  PRIMARY KEY  (id)
) ;
alter table ci_relation_type alter column id restart with 100;

INSERT INTO ci_relation_type (id,account_id,relation_name,opposite_relation_name,predefined) VALUES (1,'account','Consists','Part of','1');
INSERT INTO ci_relation_type (id,account_id,relation_name,opposite_relation_name,predefined) VALUES (2,'account','Installed on','Contains SW','1');
INSERT INTO ci_relation_type (id,account_id,relation_name,opposite_relation_name,predefined) VALUES (3,'account','Used by','Uses','0');
INSERT INTO ci_relation_type (id,account_id,relation_name,opposite_relation_name,predefined) VALUES (4,'account','Connected to','Connected to','0');
INSERT INTO ci_relation_type (id,account_id,relation_name,opposite_relation_name,predefined) VALUES (5,'account','Accessed by','Can access','0');
INSERT INTO ci_relation_type (id,account_id,relation_name,opposite_relation_name,predefined) VALUES (6,'account','Hosts','Hosted on','1');

CREATE TABLE ci_template (
  account_id varchar(32) NOT NULL ,
  template_name varchar(64) NOT NULL ,
  ci_type int ,
  location int ,
  owner varchar(64) ,
  owner_group varchar(64) ,
  company int ,
  company_backup int default 0,
  supplier int ,
  supply_date TIMESTAMP ,
  accept_date TIMESTAMP ,
  status int ,
  priority int ,
  notes clob,
  ci_cust_text_1 varchar(64) ,
  ci_cust_text_2 varchar(64) ,
  ci_cust_text_3 varchar(64) ,
  ci_cust_text_4 varchar(64) ,
  ci_cust_text_5 varchar(64) ,
  ci_cust_text_6 varchar(64) ,
  ci_cust_text_7 varchar(64) ,
  ci_cust_text_8 varchar(64) ,
  ci_cust_text_9 varchar(64) ,
  ci_cust_text_10 varchar(64) ,
  ci_cust_text_11 varchar(64) ,
  ci_cust_text_12 varchar(64) ,
  ci_cust_text_13 varchar(64) ,
  ci_cust_text_14 varchar(64) ,
  ci_cust_text_15 varchar(64) ,
  ci_cust_text_16 varchar(64) ,
  ci_cust_text_17 varchar(64) ,
  ci_cust_text_18 varchar(64) ,
  ci_cust_text_19 varchar(64) ,
  ci_cust_text_20 varchar(64) ,
  ci_cust_text_21 varchar(64) ,
  ci_cust_text_22 varchar(64) ,
  ci_cust_text_23 varchar(64) ,
  ci_cust_text_24 varchar(64) ,
  ci_cust_text_25 varchar(64) ,
  ci_cust_text_26 varchar(64) ,
  ci_cust_text_27 varchar(64) ,
  ci_cust_text_28 varchar(64) ,
  ci_cust_text_29 varchar(64) ,
  ci_cust_text_30 varchar(64) ,
  ci_cust_text_31 varchar(64) ,
  ci_cust_text_32 varchar(64) ,
  ci_cust_text_33 varchar(64) ,
  ci_cust_text_34 varchar(64) ,
  ci_cust_text_35 varchar(64) ,
  ci_cust_text_36 varchar(64) ,
  ci_cust_text_37 varchar(64) ,
  ci_cust_text_38 varchar(64) ,
  ci_cust_text_39 varchar(64) ,
  ci_cust_text_40 varchar(64) ,
  ci_cust_text_41 varchar(64) ,
  ci_cust_text_42 varchar(64) ,
  ci_cust_text_43 varchar(64) ,
  ci_cust_text_44 varchar(64) ,
  ci_cust_text_45 varchar(64) ,
  ci_cust_text_46 varchar(64) ,
  ci_cust_text_47 varchar(64) ,
  ci_cust_text_48 varchar(64) ,
  ci_cust_text_49 varchar(64) ,
  ci_cust_text_50 varchar(64) ,
  ci_cust_long_text_1 clob ,
  ci_cust_long_text_2 clob ,
  ci_cust_long_text_3 clob ,
  ci_cust_long_text_4 clob ,
  ci_cust_long_text_5 clob ,
  ci_cust_long_text_6 clob ,
  ci_cust_long_text_7 clob ,
  ci_cust_long_text_8 clob ,
  ci_cust_long_text_9 clob ,
  ci_cust_long_text_10 clob ,
  ci_cust_long_text_11 clob ,
  ci_cust_long_text_12 clob ,
  ci_cust_long_text_13 clob ,
  ci_cust_long_text_14 clob ,
  ci_cust_long_text_15 clob ,
  ci_cust_long_text_16 clob ,
  ci_cust_long_text_17 clob ,
  ci_cust_long_text_18 clob ,
  ci_cust_long_text_19 clob ,
  ci_cust_long_text_20 clob ,
  ci_cust_long_text_21 clob ,
  ci_cust_long_text_22 clob ,
  ci_cust_long_text_23 clob ,
  ci_cust_long_text_24 clob ,
  ci_cust_long_text_25 clob ,
  ci_cust_long_text_26 clob ,
  ci_cust_long_text_27 clob ,
  ci_cust_long_text_28 clob ,
  ci_cust_long_text_29 clob ,
  ci_cust_long_text_30 clob ,
  ci_cust_long_text_31 clob ,
  ci_cust_long_text_32 clob ,
  ci_cust_long_text_33 clob ,
  ci_cust_long_text_34 clob ,
  ci_cust_long_text_35 clob ,
  ci_cust_long_text_36 clob ,
  ci_cust_long_text_37 clob ,
  ci_cust_long_text_38 clob ,
  ci_cust_long_text_39 clob ,
  ci_cust_long_text_40 clob ,
  ci_cust_long_text_41 clob ,
  ci_cust_long_text_42 clob ,
  ci_cust_long_text_43 clob ,
  ci_cust_long_text_44 clob ,
  ci_cust_long_text_45 clob ,
  ci_cust_long_text_46 clob ,
  ci_cust_long_text_47 clob ,
  ci_cust_long_text_48 clob ,
  ci_cust_long_text_49 clob ,
  ci_cust_long_text_50 clob ,
  ci_cust_date_1 TIMESTAMP ,
  ci_cust_date_2 TIMESTAMP ,
  ci_cust_date_3 TIMESTAMP ,
  ci_cust_date_4 TIMESTAMP ,
  ci_cust_date_5 TIMESTAMP ,
  ci_cust_date_6 TIMESTAMP ,
  ci_cust_date_7 TIMESTAMP ,
  ci_cust_date_8 TIMESTAMP ,
  ci_cust_date_9 TIMESTAMP ,
  ci_cust_date_10 TIMESTAMP ,
  ci_cust_date_11 TIMESTAMP ,
  ci_cust_date_12 TIMESTAMP ,
  ci_cust_date_13 TIMESTAMP ,
  ci_cust_date_14 TIMESTAMP ,
  ci_cust_date_15 TIMESTAMP ,
  ci_cust_date_16 TIMESTAMP ,
  ci_cust_date_17 TIMESTAMP ,
  ci_cust_date_18 TIMESTAMP ,
  ci_cust_date_19 TIMESTAMP ,
  ci_cust_date_20 TIMESTAMP ,
  ci_cust_date_21 TIMESTAMP ,
  ci_cust_date_22 TIMESTAMP ,
  ci_cust_date_23 TIMESTAMP ,
  ci_cust_date_24 TIMESTAMP ,
  ci_cust_date_25 TIMESTAMP ,
  ci_cust_date_26 TIMESTAMP ,
  ci_cust_date_27 TIMESTAMP ,
  ci_cust_date_28 TIMESTAMP ,
  ci_cust_date_29 TIMESTAMP ,
  ci_cust_date_30 TIMESTAMP ,
  ci_cust_date_31 TIMESTAMP ,
  ci_cust_date_32 TIMESTAMP ,
  ci_cust_date_33 TIMESTAMP ,
  ci_cust_date_34 TIMESTAMP ,
  ci_cust_date_35 TIMESTAMP ,
  ci_cust_date_36 TIMESTAMP ,
  ci_cust_date_37 TIMESTAMP ,
  ci_cust_date_38 TIMESTAMP ,
  ci_cust_date_39 TIMESTAMP ,
  ci_cust_date_40 TIMESTAMP ,
  ci_cust_date_41 TIMESTAMP ,
  ci_cust_date_42 TIMESTAMP ,
  ci_cust_date_43 TIMESTAMP ,
  ci_cust_date_44 TIMESTAMP ,
  ci_cust_date_45 TIMESTAMP ,
  ci_cust_date_46 TIMESTAMP ,
  ci_cust_date_47 TIMESTAMP ,
  ci_cust_date_48 TIMESTAMP ,
  ci_cust_date_49 TIMESTAMP ,
  ci_cust_date_50 TIMESTAMP ,
  ci_cust_list_1 int ,
  ci_cust_list_2 int ,
  ci_cust_list_3 int ,
  ci_cust_list_4 int ,
  ci_cust_list_5 int ,
  ci_cust_list_6 int ,
  ci_cust_list_7 int ,
  ci_cust_list_8 int ,
  ci_cust_list_9 int ,
  ci_cust_list_10 int ,
  ci_cust_list_11 int ,
  ci_cust_list_12 int ,
  ci_cust_list_13 int ,
  ci_cust_list_14 int ,
  ci_cust_list_15 int ,
  ci_cust_list_16 int ,
  ci_cust_list_17 int ,
  ci_cust_list_18 int ,
  ci_cust_list_19 int ,
  ci_cust_list_20 int ,
  ci_cust_list_21 int ,
  ci_cust_list_22 int ,
  ci_cust_list_23 int ,
  ci_cust_list_24 int ,
  ci_cust_list_25 int ,
  ci_cust_list_26 int ,
  ci_cust_list_27 int ,
  ci_cust_list_28 int ,
  ci_cust_list_29 int ,
  ci_cust_list_30 int ,
  ci_cust_list_31 int ,
  ci_cust_list_32 int ,
  ci_cust_list_33 int ,
  ci_cust_list_34 int ,
  ci_cust_list_35 int ,
  ci_cust_list_36 int ,
  ci_cust_list_37 int ,
  ci_cust_list_38 int ,
  ci_cust_list_39 int ,
  ci_cust_list_40 int ,
  ci_cust_list_41 int ,
  ci_cust_list_42 int ,
  ci_cust_list_43 int ,
  ci_cust_list_44 int ,
  ci_cust_list_45 int ,
  ci_cust_list_46 int ,
  ci_cust_list_47 int ,
  ci_cust_list_48 int ,
  ci_cust_list_49 int ,
  ci_cust_list_50 int ,
  ci_cust_int_1 int ,
  ci_cust_int_2 int ,
  ci_cust_int_3 int ,
  ci_cust_int_4 int ,
  ci_cust_int_5 int ,
  ci_cust_int_6 int ,
  ci_cust_int_7 int ,
  ci_cust_int_8 int ,
  ci_cust_int_9 int ,
  ci_cust_int_10 int ,
  ci_cust_int_11 int ,
  ci_cust_int_12 int ,
  ci_cust_int_13 int ,
  ci_cust_int_14 int ,
  ci_cust_int_15 int ,
  ci_cust_int_16 int ,
  ci_cust_int_17 int ,
  ci_cust_int_18 int ,
  ci_cust_int_19 int ,
  ci_cust_int_20 int ,
  ci_cust_int_21 int ,
  ci_cust_int_22 int ,
  ci_cust_int_23 int ,
  ci_cust_int_24 int ,
  ci_cust_int_25 int ,
  ci_cust_int_26 int ,
  ci_cust_int_27 int ,
  ci_cust_int_28 int ,
  ci_cust_int_29 int ,
  ci_cust_int_30 int ,
  ci_cust_int_31 int ,
  ci_cust_int_32 int ,
  ci_cust_int_33 int ,
  ci_cust_int_34 int ,
  ci_cust_int_35 int ,
  ci_cust_int_36 int ,
  ci_cust_int_37 int ,
  ci_cust_int_38 int ,
  ci_cust_int_39 int ,
  ci_cust_int_40 int ,
  ci_cust_int_41 int ,
  ci_cust_int_42 int ,
  ci_cust_int_43 int ,
  ci_cust_int_44 int ,
  ci_cust_int_45 int ,
  ci_cust_int_46 int ,
  ci_cust_int_47 int ,
  ci_cust_int_48 int ,
  ci_cust_int_49 int ,
  ci_cust_int_50 int ,
  problem_type varchar(64) ,
  problem_sub_type varchar(64) ,
  third_level_category varchar(64),
  ci_sub_type int default 0,
  PRIMARY KEY  (account_id, template_name, ci_type)
) ;

CREATE TABLE audit_log (
  id int NOT NULL generated by default as identity,
  account_id varchar(32) NOT NULL,
  audit_date  TIMESTAMP,
  audit_module int,
  audit_sub_module int,
  audit_type int,
  audit_sub_type int,
  audit_severity int,
  user_name varchar(64) NOT NULL,
  audit_info varchar(4000),
  max_line_id int default 0,
  PRIMARY KEY  (id )
 );

CREATE TABLE ci_files (
  id int NOT NULL,
  account_id varchar(32) NOT NULL ,
  file_id varchar(64) NOT NULL,
  file_name varchar(255),
  file_date  TIMESTAMP, file_content blob (100M),
  real_file_name varchar(255),
  PRIMARY KEY  (account_id,id,file_id )
  );

CREATE TABLE ci_links (
  id int NOT NULL,
  account_id varchar(32) NOT NULL ,
  file_id varchar(64) NOT NULL,
  link varchar(255) NOT NULL,
  file_name varchar(255),
  file_date  TIMESTAMP,
  PRIMARY KEY  (account_id,id,file_id )
);

CREATE TABLE ci_template_links (
  template_name varchar(64) NOT NULL ,
  ci_type int ,
  account_id varchar(32) NOT NULL ,
  file_id varchar(64) NOT NULL,
  link varchar(255) NOT NULL,
  file_name varchar(255),
  file_date  TIMESTAMP,
  PRIMARY KEY  (account_id,template_name,ci_type,file_id )
);

CREATE TABLE quick_list (
  account_id varchar(32) NOT NULL ,
  sr_id int NOT NULL,
  quick_name varchar(255)  ,
  quick_class varchar(255)  ,
  quick_visible char(1),
  PRIMARY KEY (account_id, sr_id)
);

CREATE TABLE asset_catalog_files (
  id varchar(64) NOT NULL,
  account_id varchar(32) NOT NULL ,
  file_id varchar(64) NOT NULL,
  file_name varchar(255),
  file_date  TIMESTAMP,
  file_content blob (100M),
  real_file_name varchar(255),
  PRIMARY KEY  (account_id,id,file_id )
);

CREATE TABLE supplier_files (
  id int NOT NULL,
  account_id varchar(32) NOT NULL ,
  file_id varchar(64) NOT NULL,
  file_name varchar(255),
  file_date  TIMESTAMP,
  file_content blob (100M),
  real_file_name varchar(255),
  PRIMARY KEY  (account_id,id,file_id )
);

CREATE TABLE sysaid_user_files (
  id varchar(64) NOT NULL,
  account_id varchar(32) NOT NULL ,
  file_id varchar(64) NOT NULL,
  file_name varchar(255),
  file_date  TIMESTAMP,
  file_content blob (100M),
  real_file_name varchar(255),
  PRIMARY KEY  (account_id,id,file_id )
);

CREATE TABLE company_files (
  id int NOT NULL,
  account_id varchar(32) NOT NULL ,
  file_id varchar(64) NOT NULL,
  file_name varchar(255),
  file_date  TIMESTAMP,
  file_content blob (100M),
  real_file_name varchar(255),
  PRIMARY KEY  (account_id,id,file_id )
);

CREATE TABLE service_req_links (
  id int NOT NULL,
  account_id varchar(32) NOT NULL ,
  file_id varchar(64) NOT NULL,
  link varchar(255) NOT NULL,
  file_name varchar(255),
  file_date  TIMESTAMP,
  PRIMARY KEY  (account_id,id,file_id )
);

CREATE TABLE sysaid_item_links (
  account_id varchar(32) NOT NULL ,
  item_id varchar(64) NOT NULL,
  item_type int NOT NULL,
  linked_item_id varchar(64) NOT NULL,
  linked_item_type int NOT NULL,
  is_main_linked_item varchar(1),
  cause_item  varchar(64),
  PRIMARY KEY  (account_id,item_id,item_type,linked_item_id,linked_item_type)
);


CREATE TABLE linked_service_req (
  account_id varchar(32) NOT NULL ,
  id1 int NOT NULL,
  id2 int NOT NULL,
  PRIMARY KEY  (account_id,id1,id2)
);

CREATE TABLE project_links (
  id int NOT NULL,
  account_id varchar(32) NOT NULL ,
  file_id varchar(64) NOT NULL,
  link varchar(255) NOT NULL,
  file_name varchar(255),
  file_date  TIMESTAMP,
  PRIMARY KEY  (account_id,id,file_id )
);

CREATE TABLE task_links (
  id int NOT NULL,
  account_id varchar(32) NOT NULL ,
  file_id varchar(64) NOT NULL,
  link varchar(255) NOT NULL,
  file_name varchar(255),
  file_date  TIMESTAMP,
  PRIMARY KEY  (account_id,id,file_id )
);

CREATE TABLE asset_catalog_links (
  id varchar(64) NOT NULL,
  account_id varchar(32) NOT NULL ,
  file_id varchar(64) NOT NULL,
  link varchar(255) NOT NULL,
  file_name varchar(255),
  file_date  TIMESTAMP,
  PRIMARY KEY  (account_id,id,file_id )
);

CREATE TABLE software_links (
  id int NOT NULL,
  account_id varchar(32) NOT NULL ,
  file_id varchar(64) NOT NULL,
  link varchar(255) NOT NULL,
  file_name varchar(255),
  file_date  TIMESTAMP,
  PRIMARY KEY  (account_id,id,file_id )
);

CREATE TABLE supplier_links (
  id int NOT NULL,
  account_id varchar(32) NOT NULL ,
  file_id varchar(64) NOT NULL,
  link varchar(255) NOT NULL,
  file_name varchar(255),
  file_date  TIMESTAMP,
  PRIMARY KEY  (account_id,id,file_id )
);

CREATE TABLE sysaid_user_links (
  id varchar(64) NOT NULL,
  account_id varchar(32) NOT NULL ,
  file_id varchar(64) NOT NULL,
  link varchar(255) NOT NULL,
  file_name varchar(255),
  file_date  TIMESTAMP,
  PRIMARY KEY  (account_id,id,file_id )
);

CREATE TABLE company_links (
  id int NOT NULL,
  account_id varchar(32) NOT NULL ,
  file_id varchar(64) NOT NULL,
  link varchar(255) NOT NULL,
  file_name varchar(255),
  file_date  TIMESTAMP,
  PRIMARY KEY  (account_id,id,file_id )
);

CREATE TABLE asset_catalog_history(
  account_id varchar(32) NOT NULL ,
  catalog_number varchar(64) NOT NULL,
  name varchar(255) NOT NULL ,
  model varchar(64) ,
  manufacturer varchar(64) ,
  supplier_id int,
  notes clob,
  cust_date1 TIMESTAMP,
  cust_date2 TIMESTAMP,
  version int NOT NULL,
  change_time TIMESTAMP,
  changed_by varchar(64),
  PRIMARY KEY  (account_id,catalog_number,version)
);

CREATE TABLE software_history (
  software_id int NOT NULL generated by default as identity,
  account_id varchar(32) NOT NULL ,
  product_name varchar(255) NOT NULL ,
  version varchar(64) ,
  vendor varchar(64) ,
  licenses int ,
  purchase_date TIMESTAMP,
  support_expiration TIMESTAMP,
  notes clob,
  company int,
  company_backup int default 0,
  supplier int default 0 ,
  cust_list1 int ,
  cust_list2 int ,
  cust_text1 varchar(255) ,
  cust_text2 varchar(255) ,
  cust_notes clob ,
  cust_int1 int ,
  cust_int2 int ,
  cust_date1 TIMESTAMP,
  cust_date2 TIMESTAMP,
  history_version int NOT NULL,
  change_time TIMESTAMP,
  changed_by varchar(64),
  freeware varchar(1),
  exceedlic_installed int default 0,
  PRIMARY KEY  (software_id,history_version)
);

CREATE TABLE supplier_history(
  supplier_id int NOT NULL generated by default as identity,
  account_id varchar(32) NOT NULL ,
  name varchar(255) NOT NULL ,
  address clob,
  phone varchar(64),
  fax  varchar(64),
  email_address varchar(64),
  notes clob,
  mobile varchar(64),
  phone2 varchar(64),
  contact_name varchar(64),
  account_number varchar(64),
  cust_list1 int,
  cust_list2 int,
  cust_text1 varchar(255),
  cust_text2 varchar(255),
  cust_notes clob,
  cust_int1 int,
  cust_int2 int,
  cust_date1 TIMESTAMP,
  cust_date2 TIMESTAMP,
  version int NOT NULL,
  change_time TIMESTAMP,
  changed_by varchar(64),
  PRIMARY KEY  (supplier_id,version)
);

CREATE TABLE computer_history (
  account_id varchar(32) NOT NULL ,
  computer_id varchar(64) NOT NULL ,
  computer_name varchar(64) ,
  computer_type varchar(64) ,
  parent_group varchar(255) NOT NULL ,
  inventory_xml clob,
  inventory_time TIMESTAMP ,
  update_time TIMESTAMP ,
  ip_address varchar(64) ,
  description varchar(255) ,
  username varchar(64) ,
  location varchar(255) ,
  location_idx  int,
  building varchar(64),
  floor varchar(64),
  cubic varchar(64),
  catalog_number varchar(64),
  supplier int,
  maintenance_supplier int,
  company_serial varchar(64),
  external_serial varchar(64),
  monitor varchar(64),
  monitor_serial varchar(64),
  collection_type int,
  collection_params clob,
  cust_list1 int,
  cust_list2 int,
  cust_text1 varchar(255),
  cust_text2 varchar(255),
  cust_notes clob,
  cust_int1 int,
  cust_int2 int,
  parent_asset varchar(64),
  department int,
  company int,
  company_backup int default 0,
  disable char(1),
  manual_asset char(1),
  purchase_cost float,
  purchase_currency int,
  agent_version varchar(64),
  cust_date1 TIMESTAMP,
  cust_date2 TIMESTAMP,
  version int NOT NULL,
  change_time TIMESTAMP,
  changed_by varchar(64),
  snmp_cust_text_1 varchar(255),
  snmp_cust_text_2 varchar(255),
  snmp_cust_text_3 varchar(255),
  snmp_cust_text_4 varchar(255),
  snmp_cust_text_5 varchar(255),
  snmp_cust_text_6 varchar(255),
  snmp_cust_text_7 varchar(255),
  snmp_cust_text_8 varchar(255),
  snmp_cust_text_9 varchar(255),
  snmp_cust_text_10 varchar(255),
  snmp_cust_text_11 varchar(255),
  snmp_cust_text_12 varchar(255),
  snmp_cust_text_13 varchar(255),
  snmp_cust_text_14 varchar(255),
  snmp_cust_text_15 varchar(255),
  snmp_cust_text_16 varchar(255),
  snmp_cust_text_17 varchar(255),
  snmp_cust_text_18 varchar(255),
  snmp_cust_text_19 varchar(255),
  snmp_cust_text_20 varchar(255),
  packets_in float default 0,
  packets_out float default 0,
  mac_address varchar(255),
  last_boot TIMESTAMP,
  track_asset int default 0,
  first_access TIMESTAMP,
  device_status int default 0,
  device_policy int default 0,
  device_ownership int default 0,
  device_imei varchar(255),
  device_icc varchar(255),
  device_home_carrier varchar(255),
  device_current_carrier varchar(255),
  device_phone_number varchar(64),
  device_push varchar(255),
  ios_push_magic varchar(255),
  ios_unlock_token clob,
  designated_rds varchar(64),
  PRIMARY KEY  (account_id,computer_id,version)
);

CREATE TABLE computer_attributes_history (
  account_id varchar(32) NOT NULL ,
  computer_id varchar(64) NOT NULL ,
  cpu_vendor varchar(255) ,
  cpu_model varchar(255) ,
  cpu_speed int ,
  bios_type varchar(255) ,
  display_adapter varchar(255) ,
  display_memory int ,
  display_resolution varchar(255) ,
  os_type varchar(255) ,
  os_version varchar(255) ,
  os_service_pack varchar(255) ,
  memory_physical bigint ,
  serial varchar(64),
  model varchar(64) ,
  manufacturer varchar(64) ,
  purchase_date TIMESTAMP,
  warranty_expiration TIMESTAMP,
  last_maintenance TIMESTAMP,
  last_page_count int,
  maintenance_page_count int,
  disks_size int,
  disks_count int,
  mem_banks int,
  occupied_mem_banks int,
  free_mem_banks int,
  cpu_count int,
  os_name varchar(255),
  os_platform varchar(64),
  version int NOT NULL,
  PRIMARY KEY  (account_id,computer_id,version)
);

CREATE TABLE company_history (
  company_id int NOT NULL generated by default as identity,
  account_id varchar(32) NOT NULL,
  company_name varchar(255) ,
  address varchar(255) ,
  address2 varchar(255) ,
  city varchar(64),
  state varchar(64),
  zip varchar(64),
  country varchar(64),
  phone varchar(64),
  fax varchar(64),
  notes clob,
  cust_list1 int,
  cust_list2 int,
  cust_text1 varchar(255),
  cust_text2 varchar(255),
  cust_notes clob,
  cust_int1 int,
  cust_int2 int,
  expiration_time TIMESTAMP,
  cust_date1 TIMESTAMP,
  cust_date2 TIMESTAMP,
  version int NOT NULL,
  change_time TIMESTAMP,
  changed_by varchar(64),
  agreement  int default 0,
  agreement_start TIMESTAMP,
  agreement_end TIMESTAMP,
  logo_file_name varchar(64),
  PRIMARY KEY  (company_id,version )
);

CREATE TABLE discovery_service (
  id int NOT NULL generated by default as identity,
  discovery_service_name varchar(64) NOT NULL default '',
  create_date TIMESTAMP,
  upgrade_date TIMESTAMP,
  last_connection_date TIMESTAMP,
  description varchar(255),
  ip_address varchar(64),
  location varchar(64),
  version varchar(64) NOT NULL default '',
  owner varchar(64),
  domain varchar(255),
  windows char(1),
  rds_url varchar(255),
  client_version varchar(64),
  PRIMARY KEY  (id)
) ;


CREATE TABLE customized_snmp_oids (
  id int NOT NULL generated by default as identity,
  oid varchar(255) NOT NULL,
  display_name varchar(255) NOT NULL,
  mapped_field int,
  filter_name varchar(255),
  filter_expression varchar(255),
  filter_node clob,
  is_writable varchar(1),
  addon_db_name varchar(64),
  PRIMARY KEY  (id)
);

insert into customized_snmp_oids (id,oid,display_name,mapped_field,filter_name,filter_expression,filter_node,is_writable,addon_db_name) values (1,'1.3.6.1.2.1.2.2.1.6.1','Mac address of first network interface',0,' ',' ',' ','0',' ');
insert into customized_snmp_oids (id,oid,display_name,mapped_field,filter_name,filter_expression,filter_node,is_writable,addon_db_name) values (2,'1.3.6.1.2.1.1.7.0','System services',2,' ',' ',' ','0',' ');
insert into customized_snmp_oids (id,oid,display_name,mapped_field,filter_name,filter_expression,filter_node,is_writable,addon_db_name) values (3,'1.3.6.1.2.1.1.1.0','System description',3,' ',' ',' ','0',' ');
insert into customized_snmp_oids (id,oid,display_name,mapped_field,filter_name,filter_expression,filter_node,is_writable,addon_db_name) values (4,'1.3.6.1.2.1.1.2.0','System object identifier',40,' ',' ',' ','0',' ');
insert into customized_snmp_oids (id,oid,display_name,mapped_field,filter_name,filter_expression,filter_node,is_writable,addon_db_name) values (5,'1.3.6.1.2.1.1.3.0','System up time',41,' ',' ',' ','0',' ');
insert into customized_snmp_oids (id,oid,display_name,mapped_field,filter_name,filter_expression,filter_node,is_writable,addon_db_name) values (6,'1.3.6.1.2.1.1.4.0','System contact',42,' ',' ',' ','1',' ');
insert into customized_snmp_oids (id,oid,display_name,mapped_field,filter_name,filter_expression,filter_node,is_writable,addon_db_name) values (7,'1.3.6.1.2.1.1.5.0','System name',1,' ',' ',' ','1',' ');
insert into customized_snmp_oids (id,oid,display_name,mapped_field,filter_name,filter_expression,filter_node,is_writable,addon_db_name) values (8,'1.3.6.1.2.1.1.6.0','System location',44,' ',' ',' ','1',' ');
insert into customized_snmp_oids (id,oid,display_name,mapped_field,filter_name,filter_expression,filter_node,is_writable,addon_db_name) values (9,'1.3.6.1.2.1.2.2.1.2','Description of first network interface',43,' ',' ',' ','0',' ');
alter table customized_snmp_oids alter column id restart with 100;

CREATE TABLE asset2ci (
  account_id varchar(32) NOT NULL,
  asset_field varchar(64) NOT NULL,
  ci_field varchar(64) NOT NULL,
  position int,
  PRIMARY KEY  (account_id,asset_field)
);

insert into asset2ci values ('account','a.serial','serial',1);
insert into asset2ci values ('account','c.computer_name','ci_name',2);
insert into asset2ci values ('account','c.location_idx','location',3);
insert into asset2ci values ('account','c.supplier','supplier',4);
insert into asset2ci values ('account','c.username','owner',5);

CREATE TABLE status_settings (
  id int NOT NULL,
  account_id varchar(32) NOT NULL,
  change_status  int NOT NULL,
  incident_status int NOT NULL,
  exclude_statuses varchar(255),
  PRIMARY KEY  (id)
);

CREATE TABLE user2ci (
  account_id varchar(32) NOT NULL ,
  user_name varchar(64) NOT NULL ,
  ci_id int NOT NULL ,
  PRIMARY KEY  (account_id,user_name,ci_id)
);

CREATE TABLE audit_log_lines (
  log_id int NOT NULL,
  line_id int NOT NULL,
  audit_date  TIMESTAMP NOT NULL,
  account_id varchar(32) NOT NULL,
  audit_info varchar(255),
  PRIMARY KEY  (log_id,line_id )
 );

CREATE TABLE faq_files (
  id int NOT NULL,
  account_id varchar(32) NOT NULL ,
  file_id varchar(64) NOT NULL,
  file_name varchar(255),
  file_date  TIMESTAMP,
  file_content blob (100M),
  real_file_name varchar(255),
  PRIMARY KEY  (account_id,id,file_id )
 );

 CREATE TABLE reminders (
  id int NOT NULL generated by default as identity,
  account_id varchar(32) NOT NULL ,
  reminder_name varchar(64) NOT NULL,
  notification varchar(64) NOT NULL,
  alert_before int NOT NULL,
  alert_time varchar(64) NOT NULL,
  filter_expression clob,
  filter_SQL clob,
  PRIMARY KEY  (id)
 );

CREATE TABLE automatic_texts (
  id int NOT NULL generated by default as identity,
  account_id varchar(32) NOT NULL default '',
  title varchar(255),
  description varchar(4000) default NULL,
  assigned_group varchar(64) default '',
  PRIMARY KEY (account_id, id)
);

CREATE TABLE user_favorites (
  id int NOT NULL generated by default as identity,
  account_id varchar(32) NOT NULL,
  caption varchar(64) NOT NULL,
  url_string varchar(255),
  user_name varchar(64),
  PRIMARY KEY(id)
 );

CREATE TABLE chat_active_sessions (
    session_id int NOT NULL generated by default as identity,
    chat_status int NOT NULL,
    request_user varchar(64) ,
    service_request int,
    queue  varchar(64) NOT NULL,
    assigned_user varchar(64) ,
    session_password varchar(64) NOT NULL,
    full_name varchar(255),
    email_address varchar(64) ,
    ip_address varchar(64) ,
    start_time  timestamp default NULL ,
    close_time  timestamp default NULL ,
    update_time  timestamp default NULL ,
    accept_time  timestamp default NULL ,
    account_id   varchar(64) default NULL ,
    line_count int ,
    session_text clob ,
    PRIMARY KEY  (session_id)
);

CREATE TABLE chat_closed_sessions (
    session_id int NOT NULL,
    chat_status int NOT NULL,
    request_user varchar(64) ,
    service_request int,
    queue  varchar(64) NOT NULL,
    assigned_user varchar(64) ,
    session_password varchar(64) NOT NULL,
    full_name varchar(255),
    email_address varchar(64) ,
    ip_address varchar(64) ,
    start_time  timestamp default NULL ,
    close_time  timestamp default NULL ,
    update_time  timestamp default NULL ,
    accept_time  timestamp default NULL ,
    account_id   varchar(64) default NULL ,
    line_count int ,
    session_text clob ,
    PRIMARY KEY  (session_id)
);

CREATE TABLE chat_queue (
    id int NOT NULL generated by default as identity,
    name varchar(64) NOT NULL,
    group_name varchar(64),
    welcome_message varchar(4000) ,
    welcome_message_from_agent varchar(4000) ,
    idle_message varchar(4000),
    operator_accept_message varchar(4000),
    operator_release_message varchar(4000),
    operator_replace_message varchar(4000),
    offline_image_url varchar(64) ,
    online_image_url varchar(64),
    add_hour_in_chat_session char(1),
    embed_in_site_script varchar(4000) ,
    time_before_idle  int,
    time_before_close int,
    allow_offline_chat char(1),
    submit_offline_chat_message varchar(4000) ,
    display_details_screen char(1)  ,
    email_address varchar(256) ,
    operator_close_message varchar(4000),
    PRIMARY KEY  (id)
);

insert into automatic_texts (account_id,title,description,assigned_group) values ('account', 'Dear Customer', 'Dear
I am contacting you regarding', 'all');


CREATE TABLE chat_queue_messages (
    id int NOT NULL generated by default as identity,
    title varchar(64) NOT NULL,
    message varchar(4000) NOT NULL,
    queue int NOT NULL ,
    PRIMARY KEY  (id)
);

insert into chat_queue  ( id, name, welcome_message, idle_message, operator_accept_message, operator_release_message, add_hour_in_chat_session, embed_in_site_script, time_before_idle, time_before_close, allow_offline_chat, submit_offline_chat_message, display_details_screen, welcome_message_from_agent,operator_close_message )
    values ( 1, 'Support', 'Please wait. A support representative will join shortly.', 'This chat session has been identified as inactive, it will soon be closed automatically.', 'Support representative has joined  this chat session.', 'The Support representative has left this chat session. A new representative will join shortly.', '1', '<img src=""/ChatImage?queue=1"" alt=""Chat with customer support rep."" style=""cursor:pointer"" onclick=""javascript:window.open(''ChatEnduserWelcomePage.jsp?queue=1'',''myWin'',''width=400px,height=660px,toolbar=no,resizable=no,directories=no,menubar=no,location=no'')"" />', 15, 20, '1', 'Thank you for submitting your request.<br />Our Support will try to assist as soon as possible.', '1','An operator set a request chatting with you, He will join this conversation shortly','This session has been closed by the support representative.');

alter table chat_queue alter column id restart with 2;

insert into chat_queue_messages ( id, title,  message, queue )
    values ( 1, 'Please wait...', 'Please wait a few minutes while I consult with my colleagues regarding your issue', 1 );

alter table chat_queue_messages alter column id restart with 2;

insert into chat_closed_sessions(account_id,session_id, chat_status, request_user, queue, assigned_user, session_password, full_name, email_address, ip_address, start_time, close_time, update_time, line_count, session_text)
    values (  'account',1, 4, 'John Doe', 'Support', 'SysAid', '123456789', 'John Doe', 'john@sysaid.com', '127.0.0.1', CURRENT_TIMESTAMP, CURRENT_TIMESTAMP, CURRENT_TIMESTAMP, 10, 'This is a sample chat session text');

alter table chat_active_sessions alter column session_id restart with 2;


CREATE TABLE share_and_compare(
   id int NOT NULL,
   row_index int NOT NULL,
   title varchar(255) NOT NULL ,
   validity_date TIMESTAMP,
   sql_stat1_1 varchar(4000) NOT NULL,
   sql_stat1_2 varchar(4000) NOT NULL,
   sql_stat2_1 varchar(4000) NOT NULL,
   sql_stat2_2 varchar(4000) NOT NULL,
   sql_stat3_1 varchar(4000) NOT NULL,
   sql_stat3_2 varchar(4000) NOT NULL,
   sql_stat4_1 varchar(4000) NOT NULL,
   sql_stat4_2 varchar(4000) NOT NULL,
   industries_list varchar(255),
   filter_name varchar(255),
   filter_expression varchar(255),
   filter_node varchar(4000),
   default_filter_name varchar(255),
   default_filter_expression varchar(255),
   default_filter_node varchar(4000),
   filter_type varchar(64),
   value float,
   min_value float,
   max_value float,
   share_stat char(1) default 'N',
   more_is_green char(1) default 'N',
   notes varchar(4000) NOT NULL ,
   info_url varchar(255) NOT NULL ,
   unit_type varchar(64),
   filter_relevance varchar(1),
   value_data_1 int,
   value_data_2 int,
   value_data_3 int,
   value_data_4 int,
   value_data_5 int,
   value_data_6 int,
   value_data_7 int,
   value_data_8 int,
   value_data_9 int,
   value_data_10 int,
   value_data_11 int,
   value_data_12 int,
   value_data_13 int,
   value_data_14 int,
   value_data_15 int,
   value_data_16 int,
   value_data_17 int,
   value_data_18 int,
   value_data_19 int,
   value_data_20 int,
   value_data_21 int,
   value_data_22 int,
   value_data_23 int,
   value_data_24 int,
   value_data_25 int,
   value_data_26 int,
   value_data_27 int,
   value_data_28 int,
   value_data_29 int,
   value_data_30 int,
   value_data_31 int,
   value_data_32 int,
   value_data_33 int,
   value_data_34 int,
   value_data_35 int,
   value_data_36 int,
   value_data_37 int,
   value_data_38 int,
   value_data_39 int,
   value_data_40 int,
   value_data_41 int,
   value_data_42 int,
   value_data_43 int,
   value_data_44 int,
   value_data_45 int,
   value_data_46 int,
   value_data_47 int,
   value_data_48 int,
   value_data_49 int,
   value_data_50 int,
   PRIMARY KEY  (id)
 );

CREATE TABLE statistics_data(
  id int NOT NULL,
  data_date varchar(64),
  current_month_data_1 int,
  current_month_data_2 int,
  last_month_data_1 int,
  last_month_data_2 int,
  current_year_data_1 int,
  current_year_data_2 int,
  last_year_data_1 int,
  last_year_data_2 int,
  PRIMARY KEY  (id,data_date)
 );

CREATE TABLE generic_messages (
    msg_id int NOT NULL generated by default as identity,
    account_id varchar(32) NOT NULL default '' ,
    title varchar(255),
    description varchar(4000),
    msg_type char(1),
    expiration_date TIMESTAMP default NULL,
    remaining_days int,
    disable char(1),
    identify varchar(64) NOT NULL,
    PRIMARY KEY  (msg_id)
 );

 insert into generic_messages (account_id,title,description,msg_type,IDENTIFY) values ('account','loginMessageWizard.title','loginMessageWizard.maintenance.about.to.expire','a','');

 insert into generic_messages (account_id,title,description,msg_type,IDENTIFY) values ('account','loginMessageWizard.title','loginMessageWizard.maintenance.expired','a','');

 insert into faq (account_id, id, title, question, answer, category, sub_category, third_level_category, publish, update_time, created_by) values ('account',1, 'Submitting a Service Record from the End-User Portal', 'How do I submit a service record from the End-User Portal?', '<p>Follow these steps:</p>  <p>      </p>  <p>      1.   Press F11 to open the End-User Portal. Alternatively, you may access the helpdesk URL from your browser.</p>  <p>      2.   Click <strong>Submit an Incident</strong> to open the form.</p> <p><img src="KB/Submit_an_Incident.png" alt="Submit_an_Incident.png" /></p>  <p>      3.   In the form, choose the relevant category, enter an appropriate title and description.</p> <p><img src="KB/Category_selection.png" alt="Category_selection.png" /></p>  <p>      4.   Add relevant attachments (optional).</p>  <p><img src="KB/Attachments.png" alt="Attachments.png" /></p> <p>      5.   Click the <strong>Submit</strong> button.</p>  <p> </p>  <p>You will be presented with the service record ID for future reference.</p>  <p> </p>', 'Basic Software', 'Other', 'How to?', 1, CURRENT_TIMESTAMP, 'SysAid');

update asset_types set default_file_name = 'printer_32.png' where computer_type = 'Printer';
update asset_types set default_file_name = 'pda_32.png' where computer_type = 'PDA';
update asset_types set default_file_name = 'workstation_32.png' where computer_type = 'Workstation';
update asset_types set default_file_name = 'other_32.png' where computer_type = 'Other';
update asset_types set default_file_name = 'server_32.png' where computer_type = 'Server';

create table sr_sub_tab_populate(
  account_id varchar(32) NOT NULL,
  sr_id int NOT NULL,
  tab_name varchar(64) NOT NULL,
  sub_tab_order int NOT NULL,
  field_name varchar(64) NOT NULL,
  source_tab_name varchar(64) NOT NULL,
  source_sub_tab_order int NOT NULL,
  source_field_name varchar(64) NOT NULL
  );

  create index sr_sub_tab_populate_idx1 on sr_sub_tab_populate(account_id,sr_id,tab_name,sub_tab_order);

  CREATE TABLE asset_notif_events(id int NOT NULL generated by default as identity, account_id varchar(32) NOT NULL, event_name varchar(64) NOT NULL, notification varchar(64) NOT NULL, filter_expression varchar(4000), filter_sql varchar(4000), PRIMARY KEY(id));

  create table measurements_lists (
    account_id varchar(32) NOT NULL,
    id int NOT NULL generated by default as identity,
    title varchar(255) NOT NULL,
    field_name varchar(64) NOT NULL,
    date_field varchar(64) NOT NULL,
    sr_types varchar(64),
    include_statuses varchar(4000),
    filter_sql varchar(4000),
    filter_xml varchar(4000),
    filter_expression varchar(4000),
  status_class int,
    version int NOT NULL,
    PRIMARY KEY(id)
    );

  create table measurements_lists_history (
    account_id varchar(32) NOT NULL,
    id int NOT NULL,
    title varchar(255) NOT NULL,
    field_name varchar(64) NOT NULL,
    date_field varchar(64) NOT NULL,
    sr_types varchar(64),
    include_statuses varchar(4000),
    filter_sql varchar(4000),
    filter_xml varchar(4000),
    filter_expression varchar(4000),
   status_class int,
    version int NOT NULL,
    change_time TIMESTAMP,
    changed_by varchar(64),
    PRIMARY KEY(id,version)
    );

create table measurements_def
(account_id  varchar(32) NOT NULL,
id int NOT NULL generated by default as identity,
title varchar(255) NOT NULL,
agreement_id int,
parent_id int,
weight int,
formula1 varchar(64),
list1_id int,
formula2 varchar(64),
list2_id int,
time_interval int,
units varchar(64),
critical_grade int,
warning_grade int,
optimum_grade int,
goal_critical int,
goal_warning int,
goal_optimum int,
sla_critical int,
sla_warning int,
sla_optomum int,
calculated char(1),
enabled char(1),
version int NOT NULL,
PRIMARY KEY( id)
);



create table measurements_def_history
(account_id  varchar(32) NOT NULL,
id int NOT NULL ,
title varchar(255) NOT NULL,
 agreement_id int,
parent_id int,
weight int,
formula1 varchar(64),
list1_id int,
formula2 varchar(64),
 list2_id int,
time_interval int,
units varchar(64),
critical_grade int,
warning_grade int,
optimum_grade int,
goal_critical int,
goal_warning int,
goal_optimum int,
sla_critical int,
sla_warning int,
sla_optomum int,
calculated char(1),
enabled char(1),
 version int NOT NULL,
 change_time TIMESTAMP,
 changed_by varchar(64),
PRIMARY KEY( account_id,id,version)
);

create table agreement
(account_id  varchar(32) NOT NULL,
id int NOT NULL generated by default as identity,
title varchar(255) NOT NULL,
PRIMARY KEY( account_id,id)
);

insert into agreement (account_id,id,title) values ('account',1,'DEFAULT SLA');
alter table agreement alter column id restart with 2;

create table custom_columns
(id int NOT NULL generated by default as identity,
account_id varchar(32) NOT NULL,
entity_type varchar(64) NOT NULL,
field_caption varchar(64) NOT NULL,
field_type varchar(64) NOT NULL,
attribute_name varchar(64) NOT NULL,
addon_db_name varchar(64) NOT NULL,
compatibility_mode char(1) DEFAULT 'N',
write_in_list clob,
write_in_form clob,
write_in_form_mobile clob,
read_data_from_form clob,
validation_in_form clob,
hidden_control_in_form clob,
upload_from_file char(1) DEFAULT 'N',
PRIMARY KEY(id)
);



CREATE TABLE online_users (
id int NOT NULL generated by default as identity,
account_id varchar(32) NOT NULL,
user_name varchar(64) NOT NULL,
computer_id varchar(64) NOT NULL,
computer_name varchar(64),
domain varchar(64) NOT NULL,
client_name varchar(64),
ip_address varchar(64),
session_id varchar(64),
last_update_date timestamp default NULL,
disconnected int default 0,
PRIMARY KEY  (id)
);
create index online_users_ind_1 on online_users (computer_id );
create index online_users_ind_2 on online_users (user_name );

CREATE TABLE survey_questions (
account_id varchar(32) NOT NULL,
id int NOT NULL generated by default as identity,
question_text varchar(4000) NOT NULL,
enabled char(1) NOT NULL,
display_comment char(1) NOT NULL,
position int NOT NULL,
PRIMARY KEY  (id)
);

CREATE TABLE survey_answers (
account_id varchar(32) NOT NULL,
question_id int  NOT NULL,
answer_id int  NOT NULL,
answer_text varchar(4000) NOT NULL,
PRIMARY KEY  (question_id,answer_id)
);

create table current_measurement_lists (
account_id  varchar(32) NOT NULL,
agreement int NOT NULL,
measurement int NOT NULL,
list int NOT NULL,
service_req_id int NOT NULL,
list_value float,
run_date TIMESTAMP,
PRIMARY KEY(account_id,agreement,measurement,list,service_req_id)
);

create table last_run_measurement_lists (
account_id  varchar(32) NOT NULL,
agreement int NOT NULL,
measurement int NOT NULL,
list int NOT NULL,
service_req_id int NOT NULL,
list_value float,
run_date TIMESTAMP,
PRIMARY KEY(account_id,agreement,measurement,list,service_req_id)
);

create table current_sla_results(
account_id varchar(32) NOT NULL,
measurement_id int NOT NULL,
current_result float,
sla_grade float,
internal_grade float,
run_date TIMESTAMP,
final_result char(1),
PRIMARY KEY(account_id,measurement_id,run_date)
);

create table custom_triggers(
account_id varchar(32) NOT NULL,
entity_type varchar(64) NOT NULL,
trigger_onload clob,
trigger_before_save clob,
trigger_after_save clob,
trigger_onload_lastlog clob,
trigger_before_save_lastlog clob,
trigger_after_save_lastlog clob,
compatibility_mode char(1) DEFAULT 'N',
PRIMARY KEY(account_id,entity_type)
);

CREATE TABLE sysaid_events (
account_id varchar(32) NOT NULL,
id int NOT NULL generated by default as identity,
title  varchar(255) NOT NULL,
description   clob  NOT NULL,
start_date TIMESTAMP ,
end_date TIMESTAMP,
available_groups  varchar(64),
create_user varchar(64),
PRIMARY KEY  (id)
);

CREATE TABLE traps_data (
  account_id varchar(32) NOT NULL,
  computer_id varchar(64) NOT NULL,
  trap_0 int NOT NULL,
  trap_1 int NOT NULL,
  trap_2 int NOT NULL,
  trap_3 int NOT NULL,
  trap_4 int NOT NULL,
  trap_5 int NOT NULL,
  trap_6 int NOT NULL,
  PRIMARY KEY(account_id,computer_id)
);

CREATE TABLE form_history (
 user_name varchar(64) NOT NULL default '',
 account_id varchar(32) NOT NULL default '',
 form_caption varchar(255)  NOT NULL default '',
 form_url varchar(255) NOT NULL default '',
 form_visit_time timestamp
);

CREATE TABLE uss_security_questions (
  id int NOT NULL generated by default as identity,
  account_id varchar(32) NOT NULL ,
  security_question varchar(255) NOT NULL ,
  visible varchar(1),
  mandatory varchar(1),
  PRIMARY KEY  (id)
) ;

INSERT INTO uss_security_questions (id,account_id,security_question,visible,mandatory) VALUES (1,'account','user.selfService.question.1','1','0');
INSERT INTO uss_security_questions (id,account_id,security_question,visible,mandatory) VALUES (2,'account','user.selfService.question.2','1','0');
INSERT INTO uss_security_questions (id,account_id,security_question,visible,mandatory) VALUES (3,'account','user.selfService.question.3','1','0');
INSERT INTO uss_security_questions (id,account_id,security_question,visible,mandatory) VALUES (4,'account','user.selfService.question.4','1','0');
INSERT INTO uss_security_questions (id,account_id,security_question,visible,mandatory) VALUES (5,'account','user.selfService.question.5','1','0');
INSERT INTO uss_security_questions (id,account_id,security_question,visible,mandatory) VALUES (6,'account','user.selfService.question.6','1','0');
INSERT INTO uss_security_questions (id,account_id,security_question,visible,mandatory) VALUES (7,'account','user.selfService.question.7','1','0');
INSERT INTO uss_security_questions (id,account_id,security_question,visible,mandatory) VALUES (8,'account','user.selfService.question.8','1','0');
INSERT INTO uss_security_questions (id,account_id,security_question,visible,mandatory) VALUES (9,'account','user.selfService.question.9','1','0');
INSERT INTO uss_security_questions (id,account_id,security_question,visible,mandatory) VALUES (10,'account','user.selfService.question.10','1','0');
INSERT INTO uss_security_questions (id,account_id,security_question,visible,mandatory) VALUES (11,'account','user.selfService.question.11','1','0');
INSERT INTO uss_security_questions (id,account_id,security_question,visible,mandatory) VALUES (12,'account','user.selfService.question.12','1','0');
INSERT INTO uss_security_questions (id,account_id,security_question,visible,mandatory) VALUES (13,'account','user.selfService.question.13','1','0');
INSERT INTO uss_security_questions (id,account_id,security_question,visible,mandatory) VALUES (14,'account','user.selfService.question.14','1','0');
INSERT INTO uss_security_questions (id,account_id,security_question,visible,mandatory) VALUES (15,'account','user.selfService.question.15','1','0');
INSERT INTO uss_security_questions (id,account_id,security_question,visible,mandatory) VALUES (16,'account','user.selfService.question.16','1','0');
INSERT INTO uss_security_questions (id,account_id,security_question,visible,mandatory) VALUES (17,'account','user.selfService.question.17','1','0');

alter table uss_security_questions alter column id restart with 20;

CREATE TABLE uss_notif_events(
id int NOT NULL generated by default as identity,
account_id varchar(32) NOT NULL,
event_name varchar(64) NOT NULL,
notification varchar(64) NOT NULL,
filter_expression varchar(4000),
filter_sql varchar(4000),
PRIMARY KEY(id));

CREATE TABLE online_users_history (
account_id varchar(32) NOT NULL,
id int NOT NULL ,
user_name varchar(64) NOT NULL,
computer_id varchar(64) NOT NULL,
computer_name varchar(64),
domain varchar(64) NOT NULL,
client_name varchar(64),
ip_address varchar(64),
session_id varchar(64),
login_time timestamp default NULL,
logout_time timestamp default NULL,
PRIMARY KEY  (id)
);

CREATE TABLE user_questions (
  account_id varchar(32) NOT NULL ,
  user_name varchar(64) NOT NULL ,
  question_id int NOT NULL,
  answer varchar(255) NOT NULL  ,
  PRIMARY KEY  (account_id,user_name,question_id)
);

CREATE TABLE user_answer_attempts (
  account_id varchar(32) NOT NULL ,
  user_name varchar(64) NOT NULL ,
  attempts int NOT NULL,
  lock_date TIMESTAMP,
  PRIMARY KEY  (account_id,user_name)
);

CREATE TABLE sysaid_user_push_enable (
  user_name varchar(64) NOT NULL ,
  account_id varchar(32) NOT NULL ,
  device_type varchar(64) NOT NULL,
  device_id varchar(255) NOT NULL,
  enable_date TIMESTAMP,
  is_production char(1),
  is_chat_online int default 0,
  PRIMARY KEY (account_id,user_name)
) ;

CREATE TABLE sysaid_user_push_notifications (
 push_id int,
 user_name varchar(64) NOT NULL ,
 account_id varchar(32) NOT NULL ,
 sr_id int,
 push_message varchar(255) NOT NULL default '',
 status int,
 push_date TIMESTAMP
);

CREATE TABLE online_assets (
  asset_id varchar(64) NOT NULL ,
  is_online int,
  last_update TIMESTAMP,
  PRIMARY KEY (asset_id)
);

CREATE TABLE asset_offline_log (
  asset_id varchar(64) NOT NULL ,
  offline_start_time  timestamp NOT NULL ,
  offline_end_time  timestamp default NULL ,
  offline_minutes  int ,
  PRIMARY KEY (asset_id,offline_start_time)
);

CREATE TABLE users_remote_assets (
  id int NOT NULL generated by default as identity ,
  user_name varchar(64) NOT NULL ,
  login_domain varchar(64) NOT NULL,
  login_user_upper varchar(64) NOT NULL,
  computer_id varchar(64) NOT NULL,
  description varchar(255),
  note varchar(255),
  PRIMARY KEY  (id)
);

CREATE TABLE remote_active_sessions (
  user_name varchar(64) NOT NULL,
  source_host varchar(64) NOT NULL,
  target_host varchar(64) NOT NULL,
  session_id varchar(64) NOT NULL,
  rcg varchar(64) NOT NULL,
  session_start_time bigint ,
  PRIMARY KEY  (session_id)
);

CREATE TABLE sysaid_user_permissions (
  user_name varchar(64) NOT NULL ,
  permission_conf clob,
  PRIMARY KEY (user_name)
);

CREATE TABLE priority_matrix_cust_values (
  disable int default 0,
  agreement_key int NOT NULL ,
  company_key int NOT NULL ,
  impact_key int NOT NULL ,
  urgency_key int NOT NULL ,
  priority_key int NOT NULL ,
  last_update timestamp
);
                            

CREATE TABLE custom_services (
  account_id varchar(64) NOT NULL ,
  service_name varchar(255)  NOT NULL ,
  service_class varchar(255)  NOT NULL ,
  service_interval  int NOT NULL    ,
  service_start_time    int NOT NULL
);

CREATE TABLE mdm_policy (
id int NOT NULL generated by default as identity,
name varchar(255) NOT NULL,
request_time timestamp ,
revision int,
enable_password char(1) ,
allow_simple_password char(1),
alphanumeric_password_req char(1),
min_password_length int,
min_complex_password int,
max_password_age int,
auto_lock int,
password_history int,
max_failed_password int,
email_type int,
account_name varchar(255),
path_prefix_imap varchar(255),
user_display_name varchar(255),
email_address varchar(64),
host_name varchar(64),
server_port varchar(32),
user_name varchar(64),
auth_type int,
use_ssl char(1) ,
outoging_host_name varchar(64),
outgoing_server_port varchar(32),
outgoing_user_name varchar(64),
outgoing_auth_type int,
outgoing_use_ssl char(1) ,
domain_name varchar(64),
sync_emails_date_range int,
passcode_grace_period int,
PRIMARY KEY  (id)
);

CREATE TABLE mdm_wifi_policy (
id int NOT NULL generated by default as identity,
policy_id int NOT NULL,
type int,
ssid varchar(255),
auto_join char(1) ,
hidden_network char(1),
encryption_key varchar(64),
revision int,
PRIMARY KEY  (id)
);

create table mdm_actions(
computer_id varchar(64) not null,
action_code int,
push_message varchar(255),
status int,
insert_time timestamp
 );

create index mdm_actions_index1 on mdm_actions (computer_id);

CREATE TABLE ui_menus (
mi_id int not null,
mi_name varchar(64),
mi_parent int,
mi_action_type varchar(32),
mi_action varchar(255),
mi_enabled char(1),
mi_ui_class varchar(64),
mi_module_id int,
mi_order int,
mi_permission int,
mi_edition int,
PRIMARY KEY (mi_id)
);

create unique index ui_menus_index1 on ui_menus (mi_name);

CREATE TABLE ui_menus2group (
  mi_id int NOT NULL,
  group_name varchar(64) NOT NULL,
  PRIMARY KEY  (mi_id,group_name)
);

INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1, 'main', null, 'url', '#', 'Y',null, null,0,0,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (2, 'home.servicedesk', 1, 'url', '#', 'Y','service-desk', null,0,0,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (6, 'home.helpdesk', 2, 'url', '#', 'Y',null, null,0,8,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (7, 'leftmenu_sr.listAll', 6, 'url', '#/HelpDesk.jsp?fromId=List', 'Y',null, null,0,8,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (8, 'leftmenu_sr.incidents', 6, 'url', '#/HelpDesk.jsp?fromId=IncidentsList', 'Y',null, 6,0,8,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (9, 'leftmenu_sr.requests', 6, 'url', '#/HelpDesk.jsp?fromId=RequestsList', 'Y',null, 6,0,8,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (10, 'leftmenu_sr.rfc', 6, 'url', '#/HelpDesk.jsp?fromId=ChangesList', 'Y',null, 6,0,8,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (11, 'leftmenu_sr.problems', 6, 'url', '#/HelpDesk.jsp?fromId=ProblemsList', 'Y',null, 6,0,8,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (12, 'leftmenu_sr.activities', 6, 'url', '#/SRActivities.jsp', 'Y',null, null,0,8,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (13, 'leftmenu_sr.subTabList', 6, 'url', '#/SubTabList.jsp', 'Y',null, 6,0,8,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (14, 'Sep14', 6, 'separator', '#', 'N',null, null,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (15, 'leftmenu_pr.helpdeskSettings', 6, 'settings', '#/Settings.jsp?selectedItem=HelpDeskSettings.jsp', 'Y',null, null,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (16, 'leftmenu_sr.knowledge.base', 2, 'url', '#', 'Y',null, null,0,8,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (17, 'kb.articles', 16, 'function', '#/function/loadKBFAQPage', 'Y',null, null,0,8,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (22, 'leftmenu.Chats', 2, 'url', '#', 'Y',null, 4,0,0,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (23, 'leftmenu.Chat.Console', 22, 'function', '#/function/openChatConsole', 'Y',null, 5,0,262144,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (24, 'leftmenu_sr.chats', 22, 'url', '#/ChatClosedChatsList.jsp', 'Y',null, 4,0,0,0);

INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (3, 'SystemList.jsp', 1, 'url', '#', 'Y','assets', null,0,0,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (25, 'leftmenu.system', 3, 'url', '#', 'Y',null, null,0,32,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (29, 'leftmenu_sys.assetManagementDashboard', 25, 'url', '#/AssetManagementDash.jsp', 'Y',null, null,0,32,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (30, 'leftmenu_sys.asset.list', 25, 'url', '#/SystemList.jsp', 'Y',null, null,10,32,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (31, 'leftmenu_sys.myNetworkAssets', 25, 'url', '#/System.jsp', 'Y',null, null,20,32,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (32, 'leftmenu_sys.software.list', 25, 'url', '#/SoftwareList.jsp', 'Y',null, null,30,32,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (90, 'leftmenu_sys.patchManagement', 25, 'url', '#/PatchManagementList.jsp', 'Y',null, 11,31,32,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (33, 'leftmenu_sys.catalog', 25, 'url', '#/CatalogList.jsp', 'Y',null, null,40,32,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (34, 'leftmenu_sys.availability', 25, 'url', '#/AvailabilityLog.jsp', 'Y',null, null,50,32,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (35, 'leftmenu_sys.supplier.list', 25, 'url', '#/SupplierList.jsp', 'Y',null, null,60,32,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (36, 'leftmenu_sys.onlineUsers.list', 25, 'url', '#/OnlineUsersList.jsp', 'Y',null, null,70,32,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (37, 'Sep37', 25, 'separator', '#', 'N',null, null,80,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (38, 'leftmenu_sys.settings', 25, 'settings', '#/Settings.jsp?selectedItem=AssetTypes.jsp', 'Y',null, null,90,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (26, 'leftmenu.monitoring', 3, 'url', '#', 'Y',null, 2,0,0,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (39, 'monitor.eventManager.alerts.title', 26, 'url', '#/Alerts.jsp', 'Y',null, 2,0,0,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (91, 'monitor.eventManager.eventLog.title', 26, 'url', '#/EventLog.jsp', 'Y',null, 2,1,0,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (92, 'monitor.eventManager.lastPoll.title', 26, 'url', '#/LastPoll.jsp', 'Y',null, 2,2,0,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (40, 'leftmenu.monitoring.workstations_configuration', 26, 'url', '#/MonitorConfiguration.jsp', 'Y',null, 2,3,0,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (41, 'leftmenu.monitoring.server_configuration', 26, 'url', '#/MonitorConfiguration.jsp?type=1', 'Y',null, 2,4,0,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (42, 'leftmenu.monitoring.network_devices_configuration', 26, 'url', '#/MonitorConfiguration.jsp?type=4', 'Y',null, 2,5,0,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (43, 'Sep43', 26, 'separator', '#', 'N',null, 2,6,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (44, 'leftmenu.monitoring.settings', 26, 'settings', '#/Settings.jsp?selectedItem=MonitorSettings.jsp', 'Y',null, 2,7,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (27, 'leftmenu.remote.access', 3, 'url', '#', 'Y',null, 9,0,32768,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (45, 'leftmenu.remote.main', 27, 'url', '#/RemoteAccessMainPage.jsp', 'Y',null, 9,0,32768,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (46, 'leftmenu.remote.access.active.sessions', 27, 'url', '#/RemoteAccessActiveSessions.jsp', 'Y',null, 9,0,32768,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (47, 'leftmenu.remote.access.accessible.users', 27, 'url', '#/RemoteAccessibleUsers.jsp', 'Y',null, 9,0,32768,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (48, 'leftmenu.remote.access.accessible.assets', 27, 'url', '#/RemoteAccessibleAssets.jsp', 'Y',null, 9,0,32768,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (49, 'leftmenu.remote.access.logs', 27, 'url', '#/RemoteAccessLog.jsp', 'Y',null, 9,0,32768,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (28, 'leftmenu.cmdb', 3, 'url', '#', 'Y',null, 3,0,65536,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (52, 'leftmenu.cmdb.ci_list', 28, 'url', '#/CIList.jsp', 'Y',null, 3,0,65536,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (53, 'Sep53', 28, 'separator', '#', 'N',null, 3,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (54, 'leftmenu_pr.cmdbSettings', 28, 'settings', '#/Settings.jsp?selectedItem=CITypeList.jsp', 'Y',null, 3,0,1,0);

INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (4, 'leftmenu.analytics', 1, 'url', '#', 'Y','analytics', null,0,0,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (55, 'leftmenu.analytics.overview', 4, 'url', '#', 'Y',null, null,0,0,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (57, 'leftmenu.admin.portal', 55, 'url', '#/Home.jsp', 'Y',null, null,0,0,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (59, 'leftmenu_sr.matrix', 55, 'url', '#/HelpMat.jsp', 'Y',null, null,0,8,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (60, 'portal.submenu.allReports', 55, 'url', '#/MnAnalyzer.jsp', 'Y',null, 10,0,0,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (96, 'portal.submenu.Reports', 55, 'url', '#/Analyzer.jsp', 'Y',null, 12,0,2,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (56, 'portal.report.management', 4, 'url', '#', 'Y',null, 10,0,0,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (58, 'leftmenu_pr.managerPortal', 56, 'url', '#/Dashboard.jsp', 'Y',null, 10,0,0,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (63, 'portal.submenu.myReports', 56, 'url', '#/MyReports.jsp', 'Y',null, 10,0,0,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (64, 'portal.submenu.recentReports', 56, 'url', '#/RecentReports.jsp', 'Y',null, 10,0,0,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (65, 'portal.menu.scheduler', 56, 'url', '#/SchedulerList.jsp', 'Y',null, 10,0,0,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (93, 'Sep93', 56, 'separator', '#', 'N',null, 10,0,0,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (94, 'portal.report.management.settings', 56, 'settings', '#/Settings.jsp?selectedItem=DashboardEdit.jsp', 'Y',null, 10,0,0,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (66, 'monitor.performance', 4, 'url', '#', 'Y',null, null,2,0,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (95, 'leftmenu.analytics.benchmark', 66, 'url', '#/Statistics.jsp', 'Y',null, null,0,0,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (18, 'sla', 4, 'url', '#', 'Y',null, 7,3,0,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (19, 'leftmenu.measurementData', 18, 'function', '#/function/openSLAWindow', 'Y',null, 7,0,8,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (20, 'Sep20', 18, 'separator', '#', 'N',null, 7,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (21, 'sla.settings', 18, 'settings', '#/Settings.jsp?selectedItem=AgreementList.jsp', 'Y',null, 7,0,1,0);

INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (5, 'leftmenu.tools', 1, 'url', '#', 'Y','tools', null,0,0,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (67, 'leftmenu.tasks.and.projects', 5, 'url', '#', 'Y',null, 1,0,1024,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (71, 'leftmenu_task.projects', 67, 'url', '#/ProjectList.jsp', 'Y',null, 1,0,1024,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (72, 'leftmenu_task.tasks', 67, 'url', '#/TaskList.jsp', 'Y',null, 1,0,1024,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (73, 'task.activities', 67, 'url', '#/TaskActivities.jsp', 'Y',null, 1,0,1024,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (74, 'Sep74', 67, 'separator', '#', 'N',null, 1,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (75, 'leftmenu_task_projects.settings', 67, 'settings', '#/Settings.jsp?selectedItem=ProjectSettings.jsp', 'Y',null, 1,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (68, 'leftmenu.user.self.service', 5, 'url', '#', 'Y',null, 8,0,8192,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (76, 'leftmenu.user.self.service.main', 68, 'url', '#/UserSelfService.jsp', 'Y',null, 8,0,8192,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (78, 'leftmenu.user.self.service.logs', 68, 'url', '#/UserSelfServiceLog.jsp', 'Y',null, 8,0,8192,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (79, 'Sep79', 68, 'separator', '#', 'N',null, 8,0,8192,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (80, 'leftmenu.user.self.service.settings', 68, 'settings', '#/Settings.jsp?selectedItem=UserSelfServiceSettings.jsp', 'Y',null, 8,0,8192,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (69, 'leftmenu.calendar', 5, 'url', '#', 'Y',null, null,0,0,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (81, 'leftmenu.my_calendar', 69, 'url', '#/SysAidCalendar.jsp', 'Y',null, null,0,0,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (82, 'menuItemSettings.calendarSettings', 69, 'url', '#/CalendarSettings.jsp', 'Y',null, null,0,0,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (70, 'leftmenu_pr.userManagement', 5, 'url', '#', 'Y',null, null,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (84, 'leftmenu_um.administrators', 70, 'url', '#/UserManager.jsp', 'Y',null, null,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (85, 'leftmenu_um.endusers', 70, 'url', '#/EndUserManager.jsp', 'Y',null, null,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (86, 'userGroups.title', 70, 'url', '#/UserGroups.jsp', 'Y',null, null,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (87, 'company.list', 70, 'url', '#/CompanyList.jsp', 'Y',null, null,0,1,1);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (88, 'Sep88', 70, 'separator', '#', 'N',null, null,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (89, 'leftmenu_um.settings', 70, 'settings', '#/Settings.jsp?selectedItem=ImportSysAidUsers.jsp', 'Y',null, null,0,1,0);

INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1000, 'settings', null, 'url', '#', 'Y',null, null,0,0,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1001, 'leftmenu.servicedesk', 1000, 'url', '#', 'Y','servicedesk-settings', null,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1002, 'menuItemSettings.helpDesk.general', 1001, 'url', 'HelpDeskSettings.jsp', 'Y',null, null,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1003, 'helpDeskSettings.categories', 1001, 'url', 'CategorySettings.jsp', 'Y',null, null,1,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1004, 'helpDeskSettings.routing',1001, 'url', 'RulesRouting.jsp', 'Y',null, null,2,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1005, 'helpDeskSettings.priorities',1001, 'url', 'RulesPriority.jsp', 'Y',null, null,3,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1006, 'helpDeskSettings.dueDates',1001, 'url', 'RulesDueDate.jsp', 'Y',null, null,4,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1007, 'alertsettings.title',1001, 'url', 'AlertSettings.jsp', 'Y',null, null,5,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1008, 'leftmenu_pr.escalation',1001, 'url', 'EscalationList.jsp', 'Y',null, null,6,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1009, 'operating.times.title',1001, 'url', 'OperatingTimes.jsp', 'Y',null, null,7,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1010, 'operating.timers.title',1001, 'url', 'RulesTimers.jsp', 'Y',null, null,8,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1011, 'changeProblemSettings.title',1001, 'url', 'ChangeProblemSettings.jsp', 'Y',null, 6,9,1,0);


INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1013, 'leftmenu.servicedesk.templates', 1000, 'url', '#', 'Y','templates-settings', null,0,0,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1014, 'leftmenu_pr.requestTemplates',1013, 'url', 'HelpDesk.jsp?fromId=reqtemp', 'Y',null, 6,11,2056,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1015, 'leftmenu_pr.rfcTemplates',1013, 'url', 'HelpDesk.jsp?fromId=rfc', 'Y',null, 6,12,2056,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1016, 'leftmenu_pr.pmTemplates',1013, 'url', 'HelpDesk.jsp?fromId=pm', 'Y',null, 6,13,2056,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1093, 'leftmenu_pr.incidentTemplates',1013, 'url', 'HelpDesk.jsp?fromId=inctemp', 'Y',null, null,10,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1094, 'rfc.subTypes',1013, 'url', 'SubTypeList.jsp', 'Y',null, null,14,2304,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1012, 'rfc.notifications',1013, 'url', 'RFCNotification.jsp', 'Y',null, 6,15,2048,0);

INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1017, 'menuItemSettings.sla', 1000, 'url', '#', 'Y','slaslm-settings', 7,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1018, 'leftmenu.agreementLists', 1017, 'url', 'AgreementList.jsp', 'Y',null, 7,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1019, 'leftmenu.measurements', 1017, 'url', 'Measurements.jsp', 'Y',null, 7,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1020, 'leftmenu.measurementLists', 1017, 'url', 'MeasurementLists.jsp', 'Y',null, 7,0,1,0);

INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1021, 'menuItemSettings.chat', 1000, 'url', '#', 'Y','chat-settings', 4,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1022, 'leftmenu_pr.chatQueue', 1021, 'url', 'ChatQueueList.jsp', 'Y',null, 4,0,1,0);

INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1023, 'leftmenu.asset.managment', 1000, 'url', '#', 'Y','asset-settings', null,0,0,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1024, 'leftmenu_pr.assetTypes', 1023, 'url', 'AssetTypes.jsp', 'Y',null, null,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1025, 'leftmenu_sys.importAssets', 1023, 'url', 'ImportAssets.jsp', 'Y',null, null,10,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1026, 'mdmTab', 1023, 'url', 'MDMSettings.jsp', 'Y',null, null,20,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1027, 'mdm.manageDevicePolicies', 1023, 'url', 'MDMPolicyList.jsp', 'Y',null, null,30,16384,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1028, 'leftmenu_pr.rc', 1023, 'url', 'RCSettings.jsp', 'Y',null, null,40,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1029, 'leftmenu.customized.snmp.oids', 1023, 'url', 'CustomizedSnmpOids.jsp', 'Y',null, null,50,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1030, 'leftmenu_pr.registryKeys', 1023, 'url', 'UpdateAssetRegistrySettings.jsp', 'Y',null, null,60,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1031, 'leftmenu_sys.notification', 1023, 'url', 'ReoccurringNotification.jsp?system=YES', 'Y',null, null,70,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1097, 'leftmenu_sys.events', 1023, 'url', 'SystemNotification.jsp', 'Y',null, null,70,1,0);

INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1032, 'leftmenu.discovery', 1000, 'url', '#', 'Y','networkdiscovery-settings', null,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1033, 'menuItemSettings.networkDiscovery.general', 1032, 'url', 'NetworkDiscovery.jsp', 'Y',null, null,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1034, 'discovery.snmp.wmi.title', 1032, 'url', 'WMIScan.jsp', 'Y',null, null,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1035, 'discovery.deploy.agents.title', 1032, 'url', 'DeployAgents.jsp', 'Y',null, null,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1036, 'discovery.snmp.scan.title', 1032, 'url', 'Discovery.jsp', 'Y',null, null,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1037, 'discovery.mdm.title', 1032, 'url', 'MdmEnrollment.jsp', 'Y',null, null,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1038, 'discovery.update.asset.data.title', 1032, 'url', 'UpdateAssetData.jsp', 'Y',null, null,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1039, 'discovery.upgrade.agents.version.title', 1032, 'url', 'UpgradeAgentsVersion.jsp', 'Y',null, null,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1098, 'discovery.rdsList.title', 1032, 'url', 'RDSList.jsp', 'Y',null, null,1,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1040, 'leftmenu.downloads', 1032, 'url', 'Download.jsp', 'Y',null, null,2,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1041, 'discovery.log.title', 1032, 'url', 'DiscoveryLog.jsp', 'Y',null, null,3,1,0);

INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1042, 'menuItemSettings.monitoring', 1000, 'url', '#', 'Y','monitoring-settings', 2,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1043, 'menuItemSettings.monitoringSettings', 1042, 'url', 'MonitorSettings.jsp', 'Y',null, 2,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1044, 'leftmenu.monitoring.templates.workstation', 1042, 'url', 'MonitorTemplates.jsp', 'Y',null, 2,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1045, 'leftmenu.monitoring.templates.server', 1042, 'url', 'MonitorTemplates.jsp?type=3', 'Y',null, 2,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1046, 'leftmenu.monitoring.notification', 1042, 'url', 'MonitorNotifications.jsp', 'Y',null, 2,0,1,0);

INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1047, 'menuItemSettings.cmdb', 1000, 'url', '#', 'Y','cmdb-settings', 3,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1048, 'leftmenu.cmdb.ci_type_list', 1047, 'url', 'CITypeList.jsp', 'Y',null, 3,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1049, 'leftmenu.cmdb.ci_sub_types', 1047, 'url', 'CISubTypes.jsp', 'Y',null, 3,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1050, 'leftmenu.cmdb.ci_relation_type_list', 1047, 'url', 'CIRelationTypeList.jsp', 'Y',null, 3,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1051, 'leftmenu.cmdb.ci_template', 1047, 'url', 'CITemplateList.jsp', 'Y',null, 3,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1052, 'cmdb.importSystmItems.title', 1047, 'url', 'CMDBImports.jsp', 'Y',null, 3,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1053, 'cmdb.importCIs.title', 1047, 'url', 'ImportCIs.jsp', 'Y',null, 3,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1054, 'cmdb.settings.tab.import', 1047, 'url', 'CMDBSettings.jsp', 'Y',null, 3,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1055, 'cmdb.settings.tab.asset2ci', 1047, 'url', 'ImportAsset2CISettings.jsp', 'Y',null, 3,0,1,0);

INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1056, 'menuItemSettings.analytics', 1000, 'url', '#', 'Y','analytics-settings', 10,0,0,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1057, 'portal.menu.dashboardDesign', 1056, 'url', 'DashboardEdit.jsp', 'Y',null, 10,0,0,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1058, 'portal.menu.reportsDesign', 1056, 'url', 'MnAnalyzerEdit.jsp', 'Y',null, 10,0,0,0);

INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1062, 'menuItemSettings.taskAndProject', 1000, 'url', '#', 'Y','tasks-settings', 1,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1063, 'leftmenu_pr.projectSettings', 1062, 'url', 'ProjectSettings.jsp', 'Y',null, 1,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1064, 'leftmenu_task.notification', 1062, 'url', 'ReoccurringNotification.jsp', 'Y',null, 1,0,1,0);

INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1067, 'menuItemSettings.user.self.service', 1000, 'url', '#', 'Y','password-settings', 8,0,8192,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1068, 'user.selfService.general.settings', 1067, 'url', 'UserSelfServiceSettings.jsp', 'Y',null, 8,0,8192,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1069, 'user.selfService.security.questions', 1067, 'url', 'SecurityQuestions.jsp', 'Y',null, 8,0,8192,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1070, 'leftmenu.user.self.service.notifications', 1067, 'url', 'UserSelfServiceNotifications.jsp', 'Y',null, 8,0,8192,0);

INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1071, 'menuItemSettings.userManagement', 1000, 'url', '#', 'Y','usermanagement-settings', null,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1072, 'importUsers.title', 1071, 'url', 'ImportSysAidUsers.jsp', 'Y',null, null,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1073, 'importCompanies.title', 1071, 'url', 'ImportCompanies.jsp', 'Y',null, null,0,1,1);

INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1080, 'menuItemSettings.general', 1000, 'url', '#', 'Y','general-settings', null,13,0,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1081, 'leftmenu_pr.defaults', 1080, 'url', 'AccountDefaults.jsp', 'Y',null, null,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1082, 'appearance', 1080, 'url', 'CustomizeAppearance.jsp', 'Y',null, null,1,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1083, 'translate.title', 1080, 'url', 'Translate.jsp', 'Y',null, null,2,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1084, 'leftmenu_customize.entities', 1080, 'url', 'CustomizeEntities.jsp', 'Y',null, null,3,1,2);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1085, 'customLists.title', 1080, 'url', 'CustomLists.jsp', 'Y',null, null,4,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1086, 'news.setting', 1080, 'url', 'News.jsp', 'Y',null, null,5,524288,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1061, 'menuItemSettings.survey.srSurvey', 1080, 'url', 'SurveyQuestionsList.jsp', 'Y',null, null,6,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1087, 'webForms', 1080, 'url', 'WebForms.jsp', 'Y',null, null,7,1,1);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1111, 'customForms.title', 1080, 'url', 'CustomForms.jsp', 'Y',null, null,8,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1088, 'automaticTexts.title', 1080, 'url', 'AutomaticTexts.jsp', 'Y',null, null,9,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1090, 'customNotifications.title', 1080, 'url', 'CustomNotifications.jsp', 'Y',null, null,10,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1091, 'reminders.title', 1080, 'url', 'RemindersList.jsp', 'Y',null, null,11,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1110, 'leftmenu_task.reminder_notification', 1080, 'url', 'ReoccurringNotification.jsp?reminders=YES', 'Y',null, null,13,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1092, 'log.menu', 1080, 'url', 'AuditLog.jsp', 'Y',null, null,12,1,0);

INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1074, 'integration', 1000, 'url', '#', 'Y','integration-settings', null,14,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1075, 'email', 1074, 'url', 'IntegrationEmail.jsp', 'Y',null, null,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1076, 'SMS', 1074, 'url', 'IntegrationSMS.jsp', 'Y',null, null,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1077, 'integration.ldap', 1074, 'url', 'IntegrationLDAP.jsp', 'Y',null, null,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1078, 'integration.backup', 1074, 'url', 'IntegrationBackup.jsp', 'Y',null, null,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1079, 'integration.exchange', 1074, 'url', 'IntegrationExchange.jsp', 'Y',null, null,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1099, 'leftmenu_customize.api', 1074, 'url', 'API.jsp', 'Y',null, null,0,1,2);

INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1100, 'leftmenu_pr.endUserPortal', 1000, 'url', '#', 'Y','eup-settings', null,15,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1101, 'endUserPortalSettings.title', 1100, 'url', 'EndUserPortalSettings.jsp', 'Y',null, null,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1102, 'leftmenu_sr.endUser', 1100, 'url', 'SREdit.jsp?id=0&end=yes&fromId=EndUser', 'Y',null, null,0,1,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1103, 'leftmenu_customize.endUser.request', 1100, 'url', 'SREdit.jsp?id=0&fromId=EndUserRequest', 'Y',null, 6,0,1,1);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (1104, 'leftmenu_sr.endUserSettingsForm', 1100, 'url', 'Preferences.jsp?EndUserSettings=CustomizeForm', 'Y',null, null,0,1,0);

INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (2000, 'persoanl-settings', null, 'url', '#', 'Y',null, null,0,0,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (2001, 'leftmenu_pr.mySettings', 2000, 'url', 'Preferences.jsp?fancyBox=true', 'Y',null, null,0,0,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (2002, 'menuItem.onlineAid', 2000, 'function', '#/function/openHelpWindow', 'Y',null, null,0,0,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (2003, 'menuItem.sysaidCommunity', 2000, 'url', 'http://www.sysaid.com/Sysforums/forums/home.page?newWin=true', 'Y',null, null,0,0,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (2004, 'compose.title',2000, 'function', '#/function/openSendMessage', 'Y',null, null,0,0,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (2005, 'menuItem.contactSysAid',2000, 'url', 'http://www.sysaid.com/contact-support.htm?newWin=true', 'Y',null, null,0,0,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (2006, 'leftmenu_pr.about',2000, 'url', 'About.jsp?fancyBox=true', 'Y',null, null,0,0,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (2007, 'menuItem.endUserPortal',2000, 'url', 'EndUserPortal.jsp', 'Y',null, null,0,0,0);
INSERT INTO ui_menus (mi_id, mi_name, mi_parent, mi_action_type, mi_action, mi_enabled,mi_ui_class, mi_module_id,mi_order,mi_permission,mi_edition) VALUES (2008, 'portal.menu.logout',2000, 'url', 'Logout.jsp', 'Y',null, null,0,0,0);

INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (2,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (3,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (4,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (5,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (6,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (7,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (8,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (9,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (10,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (11,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (12,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (13,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (14,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (15,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (16,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (17,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (18,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (19,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (20,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (21,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (22,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (23,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (24,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (25,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (26,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (27,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (28,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (29,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (30,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (31,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (32,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (33,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (34,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (35,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (36,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (37,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (38,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (39,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (40,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (41,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (42,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (43,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (44,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (45,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (46,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (47,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (48,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (49,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (52,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (53,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (54,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (55,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (56,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (57,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (58,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (59,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (60,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (61,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (62,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (63,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (64,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (65,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (66,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (67,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (68,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (69,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (70,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (71,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (72,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (73,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (74,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (75,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (76,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (78,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (79,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (80,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (81,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (82,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (84,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (85,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (86,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (87,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (88,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (89,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (91,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (92,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (93,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (94,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (95,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (96,'ALL_SYSAID_GROUPS');

INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1000,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1001,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1002,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1003,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1004,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1005,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1006,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1007,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1008,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1009,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1010,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1011,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1012,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1013,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1014,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1015,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1016,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1017,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1018,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1019,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1020,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1021,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1022,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1023,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1024,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1025,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1026,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1027,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1028,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1029,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1030,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1031,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1032,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1033,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1034,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1035,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1036,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1037,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1038,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1039,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1040,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1041,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1042,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1043,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1044,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1045,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1046,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1047,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1048,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1049,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1050,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1051,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1052,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1053,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1054,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1055,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1056,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1057,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1058,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1061,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1062,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1063,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1064,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1067,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1068,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1069,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1070,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1071,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1072,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1073,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1074,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1075,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1076,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1077,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1078,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1079,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1080,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1081,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1082,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1083,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1084,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1085,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1086,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1087,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1088,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1090,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1091,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1092,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1093,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1094,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1095,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1096,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1097,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1098,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1099,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1100,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1101,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1102,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1103,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1104,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1110,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (1111,'ALL_SYSAID_GROUPS');

INSERT INTO ui_menus2group (mi_id,group_name) VALUES (2000,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (2001,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (2002,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (2003,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (2004,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (2005,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (2006,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (2007,'ALL_SYSAID_GROUPS');
INSERT INTO ui_menus2group (mi_id,group_name) VALUES (2008,'ALL_SYSAID_GROUPS');